OC.L10N.register(
    "spreed",
    {
    "a conversation" : "comhrá",
    "(Duration %s)" : "(Ré %s)",
    "You attended a call with {user1}" : "D'fhreastail tú ar ghlao le {user1}",
    "_%n guest_::_%n guests_" : ["%n aoi","%n aíonna","%n aíonna","%n aíonna","%n aíonna"],
    "You attended a call with {user1} and {user2}" : "D'fhreastail tú ar ghlao le {user1} agus {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "D'fhreastail tú ar ghlao le {user1}, {user2} agus {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "D'fhreastail tú ar ghlao le {user1}, {user2}, {user3} agus {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "D'fhreastail tú ar ghlao le {user1}, {user2}, {user3}, {user4} agus {user5}",
    "_%n other_::_%n others_" : ["%n eile","%n eile","%n eile","%n eile","%n eile"],
    "{actor} invited you to {call}" : "Thug {actor} cuireadh duit {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Tugadh cuireadh duit chuig <strong>chomhrá</strong>nó bhí  <strong>glaoch</strong>agat",
    "Other activities" : "Gníomhaíochtaí eile",
    "Talk" : "Caint",
    "Guest" : "Aoi",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "##Fáilte go Nextcloud Talk!\nSa chomhrá seo cuirfear ar an eolas thú faoi ghnéithe nua atá ar fáil in Nextcloud Talk.",
    "## New in Talk %s" : "## Nua i gCaint %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Is féidir Microsoft Edge agus Safari a úsáid anois chun páirt a ghlacadh i nglaonna fuaime agus físe",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Bíonn comhráite duine le duine leanúnach anois agus ní féidir iad a iompú ina gcomhráite grúpa trí thimpiste a thuilleadh. Chomh maith leis sin nuair a fhágann duine de na rannpháirtithe an comhrá, ní scriostar an comhrá go huathoibríoch a thuilleadh. Ach amháin má fhágann an dá rannpháirtí, scriostar an comhrá ón bhfreastalaí",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Is féidir leat na rannpháirtithe go léir a chur ar an eolas anois trí \"@all\" a phostáil isteach sa chomhrá",
    "- With the \"arrow-up\" key you can repost your last message" : "- Leis an eochair \"arrow-up\" is féidir leat do theachtaireacht dheireanach a athphostáil",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Is féidir orduithe a bheith ag Talk anois, seol \"/help\" mar theachtaireacht chomhrá féachaint an bhfuil roinnt cumraithe ag do riarthóir",
    "- With projects you can create quick links between conversations, files and other items" : "- Le tionscadail is féidir leat naisc thapa a chruthú idir comhráite, comhaid agus míreanna eile",
    "- You can now mention guests in the chat" : "- Is féidir leat aíonna a lua sa chomhrá anois",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Is féidir stocaireacht a bheith ag comhráite anois. Tabharfaidh sé seo deis do mhodhnóirí a bheith páirteach sa chomhrá agus glaoch a chur orthu cheana féin chun an cruinniú a ullmhú, fad a bheidh ar úsáideoirí agus ar aíonna fanacht",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Is féidir leat anois freagra díreach a thabhairt ar theachtaireachtaí a thugann níos mó comhthéacs do na húsáideoirí eile cad faoi do theachtaireacht",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Déanfaidh cuardach do chomhráite agus do rannpháirtithe na comhráite atá agat cheana féin a scagadh freisin, rud a fhágfaidh go mbeidh sé i bhfad níos éasca teacht ar chomhráite roimhe seo",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Is féidir leat grúpaí úsáideoirí saincheaptha a chur le comhráite anois nuair a bhíonn an aip ciorcail suiteáilte",
    "- Check out the new grid and call view" : "- Amharc ar an eangach nua agus an radharc glaonna",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Is féidir leat comhaid a uaslódáil anois agus a tharraingt agus a scaoil go díreach ó do ghléas isteach sa chomhrá",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Osclaítear comhaid roinnte go díreach laistigh den radharc comhrá leis na haipeanna breathnóireachta",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Is féidir leat comhráite agus teachtaireachtaí a chuardach anois sa chuardach aontaithe sa bharra barr",
    "- Spice up your messages with emojis from the emoji picker" : "- Spice suas do theachtaireachtaí le emojis ón roghnóir emoji",
    "- You can now change your camera and microphone while being in a call" : "- Is féidir leat do cheamara agus micreafón a athrú anois agus tú ar ghlao",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Tabhair comhthéacs éigin le cur síos do do chuid comhráite agus oscail suas é ionas gur féidir le húsáideoirí logáilte isteach é a aimsiú agus dul isteach iontu féin",
    "- See a read status and send failed messages again" : "- Féach ar stádas léite agus seol teachtaireachtaí teipthe arís",
    "- Raise your hand in a call with the R key" : "- Ardaigh do lámh i nglao leis an eochair R",
    "- Join the same conversation and call from multiple devices" : "- Glac páirt sa chomhrá céanna agus glaoigh ó ilfheistí",
    "- Send voice messages, share your location or contact details" : "- Seol teachtaireachtaí gutha, roinn do shuíomh nó sonraí teagmhála",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Cuir grúpaí le comhrá agus cuirfear baill nua den ghrúpa leis go huathoibríoch mar rannpháirtithe",
    "- A preview of your audio and video is shown before joining a call" : "- Taispeántar réamhamharc ar do chuid fuaime agus físe sula nglacann tú páirt i nglao",
    "- You can now blur your background in the newly designed call view" : "- Is féidir leat do chúlra a gheamhú anois san amharc glaonna nua-dheartha",
    "- Moderators can now assign general and individual permissions to participants" : "- Is féidir le modhnóirí ceadanna ginearálta agus aonair a shannadh do rannpháirtithe anois",
    "- You can now react to chat messages" : "- Is féidir leat freagairt anois do theachtaireachtaí comhrá",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Sa bharra taoibh is féidir leat forbhreathnú a fháil anois ar na míreanna comhroinnte is déanaí",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Úsáid vótaíocht chun tuairimí daoine eile a bhailiú nó socrú ar dháta",
    "- Configure an expiration time for chat messages" : "- Cumraigh am éaga le haghaidh teachtaireachtaí comhrá",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Tosaigh glaonna gan daoine eile a chur ar an eolas i gcomhráite móra. Is féidir leat fógraí glaonna aonair a sheoladh nuair a bheidh an glao tosaithe.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Seol teachtaireachtaí comhrá gan fógra a thabhairt do na faighteoirí ar eagla nach bhfuil sé práinneach",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Seol teachtaireachtaí comhrá gan fógra a thabhairt do na faighteoirí ar eagla nach bhfuil sé práinneach",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Nasc míreanna éagsúla ag baint úsáide as an roghnóir cliste nua trí \"/\" a chlóscríobh",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Is féidir le modhnóirí seomraí ar leithligh a chruthú anois (tá an t-inneall Ardfheidhmíochta ag teastáil)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Is féidir glaonna a thaifeadadh anois (tá an t-Inneall Ardfheidhmíochta ag teastáil)",
    "- Conversations can now have an avatar or emoji as icon" : "- Is féidir avatar nó emoji a bheith mar dheilbhín anois ag comhráite",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Tá cúlraí fíorúla ar fáil anois chomh maith leis an gcúlra doiléir i bhfísghlaonna",
    "- Reactions are now available during calls" : "- Tá frithghníomhartha ar fáil anois le linn glaonna",
    "- Typing indicators show which users are currently typing a message" : "- Léiríonn táscairí clóscríofa cé na húsáideoirí atá ag clóscríobh teachtaireachta faoi láthair",
    "- Groups can now be mentioned in chats" : "- Is féidir grúpaí a lua anois i gcomhráite",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Déantar taifeadtaí glaonna a thrascríobh go huathoibríoch má tá aip soláthraí trascríobh cláraithe",
    "- Chat messages can be translated if a translation provider app is registered" : "- Is féidir teachtaireachtaí comhrá a aistriú má tá aip soláthraí aistriúcháin cláraithe",
    "- **Markdown** can now be used in _chat_ messages" : "- Is féidir **Markdown** a úsáid anois i dteachtaireachtaí _chat_",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Tá webooks ar fáil anois chun róbónna a chur i bhfeidhm. Féach an doiciméadú le haghaidh tuilleadh eolais https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Socraigh meabhrúchán ar theachtaireacht chomhrá le cur ar an eolas níos déanaí arís",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Úsáid an comhrá **Nóta le do thoil féin** chun nótaí a ghlacadh agus faisnéis a roinnt idir do ghléasanna",
    "- Captions allow to send a message with a file at the same time" : "- Ceadaíonn fotheidil teachtaireacht a sheoladh le comhad ag an am céanna",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Tá físeán an chainteora le feiceáil anois agus an scáileán á roinnt agus déantar freagairtí glaonna a bheochan",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Is féidir le húdair agus modhnóirí logáilte isteach teachtaireachtaí a chur in eagar anois ar feadh 6 huaire",
    "- Unsent message drafts are now saved in your browser" : "- Déantar dréachtaí teachtaireachta nár seoladh a shábháil i do bhrabhsálaí anois",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Is féidir comhrá téacs a dhéanamh anois ar bhealach cónasctha le freastalaithe Talk eile",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Is féidir le modhnóirí cuntais agus aíonna a thoirmeasc anois chun iad a chosc ó dhul isteach arís i gcomhrá",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Taispeántar glaonna atá le teacht ó imeachtaí féilire nasctha agus athsholáthairtí lasmuigh den oifig sna comhráite anois",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Is féidir glaonna a dhéanamh anois ar bhealach cónasctha le freastalaithe Talk eile (tá an t-inneall Ardfheidhmíochta ag teastáil)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Cliant deisce Nextcloud Talk do Windows, macOS agus Linux a thabhairt isteach: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Déan achoimre ar thaifeadtaí glaonna agus teachtaireachtaí neamhléite i gcomhráite leis an Nextcloud Assistant",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Cruinnithe feabhsaithe le haíonna a dtugtar cuireadh dóibh trína seoladh ríomhphoist, iompórtáil liostaí rannpháirtithe, dréachtaí le haghaidh pobalbhreithe agus íoslódáil liostaí rannpháirtithe glaonna",
    "- Archive conversations to stay focused" : "- Cuir comhráite sa chartlann chun fanacht dírithe",
    "- Schedule a meeting into your calendar from within a conversation" : "- Sceidealaigh cruinniú isteach i d'fhéilire ó laistigh de chomhrá",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Cuardaigh teachtaireachtaí an chomhrá reatha go díreach sa bharra taoibh ar dheis",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Féach ar níos mó comhrá ar an gcéad amharc leis an liosta dlúth nua (cumasaigh sna socruithe Talk)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Sioncrónaíonn comhráite cruinnithe an teideal agus an cur síos ón bhféilire anois agus folaítear iad le scagaire cuardaigh go dtí go mbíonn siad gar don tús.",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Marcáil comhráite mar íogair sna socruithe fógraí, chun ábhar an teachtaireachta a cheilt ón liosta comhráite agus ó na fógraí",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Chun fógraí brú a fháil le linn \"Ná cuir isteach\", marcáil comhráite mar thábhachtacha",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Cuir rannpháirtithe eile le glao duine le duine chun glao grúpa nua a chruthú láithreach",
    "- Use threads to keep your chat and discussions organized" : "- Bain úsáid as snáitheanna chun do chomhrá agus do phlé a choinneáil eagraithe",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Trascríbhinní beo ar fáil anois le linn an ghlao (éilíonn sé seo an ExApp tras-scríofa beo agus an cúltaca ardfheidhmíochta)",
    "- Moderators can now pin messages so they are kept at the top" : "- Is féidir le modhnóirí teachtaireachtaí a phionáil anois ionas go gcoimeádtar iad ag an mbarr",
    "- Schedule a message to send it at a later time" : "- Sceideal teachtaireacht le seoladh ag am níos déanaí",
    "- Conversation tags, grouping and sorting to organize the conversation list" : "- Clibeanna comhrá, grúpáil agus sórtáil chun an liosta comhrá a eagrú",
    "- Voice-rooms to connect spontaneously" : "- Seomraí gutha chun ceangal go spontáineach",
    "- Presets for quick conversation configuration during creation" : "- Réamhshocruithe le haghaidh cumraíocht chomhrá tapa le linn cruthaithe",
    "- Direct calls from profile menus for calls within other apps" : "- Glaonna díreacha ó roghchláir phróifíle le haghaidh glaonna laistigh d'aipeanna eile",
    "_All %n participant_::_All %n participants_" : ["Gach %n rannpháirtí","Gach %n rannpháirtí","Gach %n rannpháirtí","Gach %n rannpháirtí","Gach %n rannpháirtí"],
    "Talk updates ✅" : "Labhair nuashonruithe ✅",
    "Reaction deleted by author" : "An t-imoibriú scriosta ag an údar",
    "{actor} created the conversation" : "Chruthaigh {aisteoir} an comhrá",
    "You created the conversation" : "Chruthaigh tú an comhrá",
    "System created the conversation" : "Chruthaigh an córas an comhrá",
    "An administrator created the conversation" : "Chruthaigh riarthóir an comhrá",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "D'athainmnigh {actor} an comhrá ó \"%1$s\" go \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "D'athainmnigh tú an comhrá ó \"%1$s\" go \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "D'athainmnigh riarthóir an comhrá ó \"%1$s\" go \"%2$s\"",
    "{actor} set the description" : "socraigh {actor} an cur síos",
    "You set the description" : "Shocraigh tú an cur síos",
    "An administrator set the description" : "Shocraigh riarthóir an cur síos",
    "{actor} removed the description" : "bhain {actor} an cur síos",
    "You removed the description" : "Bhain tú an cur síos",
    "An administrator removed the description" : "Bhain riarthóir an cur síos",
    "You started a silent call" : "Chuir tú tús le glao ciúin",
    "Outgoing silent call" : "Glao ciúin amach",
    "{actor} started a silent call" : "chuir {actor} tús le glao ciúin",
    "Incoming silent call" : "Glao ciúin ag teacht isteach",
    "You started a call" : "Thosaigh tú glao",
    "Outgoing call" : "Glao amach",
    "{actor} started a call" : "Chuir {actor} tús le glao",
    "Incoming call" : "Glao ag teacht isteach",
    "{actor} joined the call" : "Chuaigh {actor} isteach sa ghlao",
    "You joined the call" : "Ghlac tú páirt sa ghlao",
    "{actor} left the call" : "D'fhág {actor} an glao",
    "You left the call" : "D'fhág tú an glao",
    "{actor} unlocked the conversation" : "Dhíghlasáil {actor} an comhrá",
    "You unlocked the conversation" : "Dhíghlasáil tú an comhrá",
    "An administrator unlocked the conversation" : "Dhíghlasáil riarthóir an comhrá",
    "{actor} locked the conversation" : "ghlas {actor} an comhrá",
    "You locked the conversation" : "Chuir tú glas ar an gcomhrá",
    "An administrator locked the conversation" : "Chuir riarthóir faoi ghlas an comhrá",
    "{actor} limited the conversation to the current participants" : "Chuir {actor} an comhrá teoranta do na rannpháirtithe reatha",
    "You limited the conversation to the current participants" : "Chuir tú teorainn leis an gcomhrá do na rannpháirtithe reatha",
    "An administrator limited the conversation to the current participants" : "Chuir riarthóir teorainn leis an gcomhrá do na rannpháirtithe reatha",
    "{actor} opened the conversation to registered users" : "D'oscail {actor} an comhrá d'úsáideoirí cláraithe",
    "You opened the conversation to registered users" : "D'oscail tú an comhrá d'úsáideoirí cláraithe",
    "An administrator opened the conversation to registered users" : "D'oscail riarthóir an comhrá d'úsáideoirí cláraithe",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "D'oscail {actor} an comhrá d'úsáideoirí cláraithe agus d'úsáideoirí a cruthaíodh leis an aip Guests",
    "You opened the conversation to registered users and users created with the Guests app" : "D’oscail tú an comhrá d’úsáideoirí cláraithe agus d’úsáideoirí a cruthaíodh leis an aip Guests",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "D’oscail riarthóir an comhrá d’úsáideoirí cláraithe agus d’úsáideoirí a cruthaíodh leis an aip Guests",
    "The conversation is now open to everyone" : "Tá an comhrá oscailte do chách anois",
    "{actor} opened the conversation to everyone" : "D'oscail {actor} an comhrá do gach duine",
    "You opened the conversation to everyone" : "D'oscail tú an comhrá do gach duine",
    "{actor} restricted the conversation to moderators" : "Chuir {actor} srian ar an gcomhrá do mhodhnóirí",
    "You restricted the conversation to moderators" : "Chuir tú srian ar an gcomhrá do mhodhnóirí",
    "{actor} started breakout rooms" : "Chuir {actor} tús le seomraí ar leithligh",
    "You started breakout rooms" : "Chuir tú tús le seomraí ar leithligh",
    "{actor} stopped breakout rooms" : "Chuir {aisteoir} seomraí ar leithligh stoptha",
    "You stopped breakout rooms" : "Chuir tú deireadh le seomraí ar leithligh",
    "{actor} allowed guests" : "Tá cead ag {aisteoir} aíonna",
    "You allowed guests" : "Cheadaigh tú aíonna",
    "An administrator allowed guests" : "Cheadaigh riarthóir aíonna",
    "{actor} disallowed guests" : "{aisteoir} aíonna dícheadaithe",
    "You disallowed guests" : "Dhícheadaigh tú aíonna",
    "An administrator disallowed guests" : "Dhícheadaigh riarthóir aíonna",
    "{actor} set a password" : "Shocraigh {aisteoir} pasfhocal",
    "You set a password" : "Shocraigh tú pasfhocal",
    "An administrator set a password" : "Shocraigh riarthóir pasfhocal",
    "{actor} removed the password" : "Bhain {actor} an pasfhocal",
    "You removed the password" : "Bhain tú an focal faire",
    "An administrator removed the password" : "Bhain riarthóir an focal faire",
    "{actor} added {user}" : "Chuir {actor} {user} leis",
    "You joined the conversation" : "Ghlac tú páirt sa chomhrá",
    "{actor} joined the conversation" : "Tháinig {actor} isteach sa chomhrá",
    "You added {user}" : "Chuir tú {user} leis",
    "{actor} added you" : "Chuir {actor} tú leis",
    "An administrator added you" : "Chuir riarthóir thú leis",
    "An administrator added {user}" : "Chuir riarthóir {user} leis",
    "You left the conversation" : "D'fhág tú an comhrá",
    "{actor} left the conversation" : "D'fhág {actor} an comhrá",
    "{actor} removed {user}" : "Bhain {actor} {user}",
    "You removed {user}" : "Bhain tú {user}",
    "{actor} removed you" : "Bhain {actor} thú",
    "An administrator removed you" : "Bhain riarthóir thú",
    "An administrator removed {user}" : "Bhain riarthóir {user}",
    "{actor} invited {federated_user}" : "Thug {actor} cuireadh do {federated_user}",
    "You invited {federated_user}" : "Thug tú cuireadh do {federated_user}",
    "You accepted the invitation" : "Ghlac tú leis an gcuireadh",
    "{actor} invited you" : "Thug {actor} cuireadh duit",
    "An administrator invited you" : "Thug riarthóir cuireadh duit",
    "An administrator invited {federated_user}" : "Thug riarthóir cuireadh do {federed_user}",
    "{federated_user} accepted the invitation" : "Ghlac {federed_user} leis an gcuireadh",
    "{actor} removed {federated_user}" : "Bhain {actor} {federated_user}",
    "You removed {federated_user}" : "Bhain tú {federated_user}",
    "You declined the invitation" : "Dhiúltaigh tú don chuireadh",
    "An administrator removed {federated_user}" : "Bhain riarthóir {federated_user}",
    "{federated_user} declined the invitation" : "Dhiúltaigh {federated_user} an cuireadh",
    "{actor} added group {group}" : "Chuir {actor} grúpa {group} leis",
    "You added group {group}" : "Chuir tú grúpa {group} leis",
    "An administrator added group {group}" : "Chuir riarthóir grúpa {group} leis",
    "{actor} removed group {group}" : "Bhain {actor} grúpa {group}",
    "You removed group {group}" : "Bhain tú grúpa {group}",
    "An administrator removed group {group}" : "Bhain riarthóir grúpa {group}",
    "{actor} added team {circle}" : "Chuir {aisteoir} foireann {circle} leis",
    "You added team {circle}" : "Chuir tú {circle} leis an bhfoireann",
    "An administrator added team {circle}" : "Chuir riarthóir foireann {circle} leis",
    "{actor} removed team {circle}" : "Bhain {actor} foireann {circle}",
    "You removed team {circle}" : "Bhain tú an fhoireann {circle}",
    "An administrator removed team {circle}" : "Bhain riarthóir foireann {circle}",
    "{actor} added {phone}" : "Chuir {actor} {phone} leis",
    "You added {phone}" : "Chuir tú {phone} leis",
    "An administrator added {phone}" : "Chuir riarthóir {phone} leis",
    "{actor} removed {phone}" : "Bhain {actor} {phone}",
    "You removed {phone}" : "Bhain tú {phone}",
    "An administrator removed {phone}" : "Bhain riarthóir {phone}",
    "{actor} promoted {user} to moderator" : "Chuir {actor} {user} chun cinn chuig modhnóir",
    "You promoted {user} to moderator" : "Chuir tú {user} chun cinn mar mhodhnóir",
    "{actor} promoted you to moderator" : "Thug {actor} ardú céime duit go modhnóir",
    "An administrator promoted you to moderator" : "Thug riarthóir ardú céime duit go modhnóir",
    "An administrator promoted {user} to moderator" : "Chuir riarthóir {user} chun cinn chuig modhnóir",
    "{actor} demoted {user} from moderator" : "Bhain {actor} {user} ón modhnóir",
    "You demoted {user} from moderator" : "Bhain tú síos {user} ón modhnóir",
    "{actor} demoted you from moderator" : "Dhírigh {actor} ón mhodhnóir tú",
    "An administrator demoted you from moderator" : "Dhealraigh riarthóir thú ón modhnóir",
    "An administrator demoted {user} from moderator" : "Bhain riarthóir {user} as an modhnóir",
    "{actor} shared a file which is no longer available" : "Roinn {actor} comhad nach bhfuil ar fáil a thuilleadh",
    "You shared a file which is no longer available" : "Roinn tú comhad nach bhfuil ar fáil a thuilleadh",
    "File shares are currently not supported in federated conversations" : "Ní thacaítear le comhroinnt comhaid i gcomhráite cónasctha faoi láthair",
    "The shared location is malformed" : "Tá an suíomh roinnte míchumtha",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "Shocraigh {actor} Matterbridge chun an comhrá seo a shioncronú le comhráite eile",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Shocraigh tú Matterbridge chun an comhrá seo a shioncronú le comhráite eile",
    "{actor} created thread {title}" : "Chruthaigh {actor} an snáithe {title}",
    "You created thread {title}" : "Chruthaigh tú snáithe {title}",
    "{actor} renamed thread {title}" : "athainmníodh an snáithe le {actor} mar {title}",
    "You renamed thread {title}" : "Athainmnigh tú an snáithe {title}",
    "{actor} updated the Matterbridge configuration" : "Nuashonraigh {actor} cumraíocht Matterbridge",
    "You updated the Matterbridge configuration" : "Nuashonraigh tú cumraíocht Matterbridge",
    "{actor} removed the Matterbridge configuration" : "Bhain {actor} cumraíocht Matterbridge",
    "You removed the Matterbridge configuration" : "Bhain tú cumraíocht Matterbridge",
    "{actor} started Matterbridge" : "Thosaigh {actor} Matterbridge",
    "You started Matterbridge" : "Thosaigh tú Matterbridge",
    "{actor} stopped Matterbridge" : "Chuir {actor} stop le Matterbridge",
    "You stopped Matterbridge" : "Stop tú Matterbridge",
    "{actor} deleted a message" : "Scrios {actor} teachtaireacht",
    "You deleted a message" : "Scrios tú teachtaireacht",
    "{actor} edited a message" : "Chuir {actor} teachtaireacht in eagar",
    "You edited a message" : "Chuir tú teachtaireacht in eagar",
    "{actor} pinned a message" : "Chuir {actor} teachtaireacht i bpriontáil",
    "You pinned a message" : "Chuir tú teachtaireacht i bpriontáil",
    "{actor} unpinned a message" : "Dhíphionáil {actor} teachtaireacht",
    "Message was automatically unpinned" : "Díphionáladh an teachtaireacht go huathoibríoch",
    "You unpinned a message" : "Dhíphionáil tú teachtaireacht",
    "{actor} deleted a reaction" : "Scrios {actor} imoibriú",
    "You deleted a reaction" : "Scrios tú imoibriú",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n seachtain","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n seachtainí","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n seachtainí","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n seachtainí","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n seachtainí"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n lá","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n laethanta","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n laethanta","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n laethanta","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n laethanta"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n uair an chloig","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n uaireanta an chloig","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n uaireanta an chloig","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n uaireanta an chloig","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n uaireanta an chloig"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n nóiméad","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n noiméid","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n noiméid","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n noiméid","Shocraigh tú go dtiocfadh deireadh leis an teachtaireacht i %n noiméid"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n seachtain","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n seachtainí","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n seachtainí","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n seachtainí","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n seachtainí"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n lá","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n laethanta","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n laethanta","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n laethanta","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n laethanta"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n uair an chloig","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n uaireanta an chloig","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n uaireanta an chloig","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n uaireanta an chloig","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n uaireanta an chloig"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n nóiméad","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n noiméid","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n noiméid","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n noiméid","Shocraigh {actor} go dtiocfadh deireadh leis an teachtaireacht i %n noiméid"],
    "{actor} disabled message expiration" : "Dhíchumasaigh {actor} teachtaireacht in éag",
    "You disabled message expiration" : "Dhíchumasaigh tú dul in éag na teachtaireachta",
    "{actor} cleared the history of the conversation" : "Ghlan {actor} stair an chomhrá",
    "You cleared the history of the conversation" : "Ghlan tú stair an chomhrá",
    "{actor} set the conversation picture" : "Socraigh {aisteoir} pictiúr an chomhrá",
    "You set the conversation picture" : "Shocraigh tú pictiúr an chomhrá",
    "{actor} removed the conversation picture" : "Bhain {actor} pictiúr an chomhrá",
    "You removed the conversation picture" : "Bhain tú an pictiúr comhrá",
    "{actor} ended the poll {poll}" : "Chuir {actor} deireadh leis an vótaíocht {poll}",
    "You ended the poll {poll}" : "Chuir tú deireadh leis an vótaíocht {poll}",
    "{actor} started the video recording" : "Chuir {actor} tús leis an bhfístaifeadadh",
    "You started the video recording" : "Chuir tú tús leis an bhfístaifeadadh",
    "{actor} stopped the video recording" : "Chuir {actor} stop leis an bhfístaifeadadh",
    "You stopped the video recording" : "Chuir tú stop leis an bhfístaifeadadh",
    "{actor} started the audio recording" : "Chuir {actor} tús leis an taifeadadh fuaime",
    "You started the audio recording" : "Chuir tú tús leis an taifeadadh fuaime",
    "{actor} stopped the audio recording" : "Chuir {actor} stop leis an taifeadadh fuaime",
    "You stopped the audio recording" : "Chuir tú stop leis an taifeadadh fuaime",
    "The recording failed" : "Theip ar an taifeadadh",
    "Someone voted on the poll {poll}" : "Vótáil duine éigin ar an vótaíocht {poll}",
    "Message deleted by author" : "Scrios an t-údar an teachtaireacht",
    "Message deleted by {actor}" : "Scrios {actor} an teachtaireacht",
    "Message deleted by you" : "Scrios tú an teachtaireacht",
    "Deleted user" : "Úsáideoir scriosta",
    "Unknown number" : "Uimhir anaithnid",
    "Administration" : "Riarachán",
    "System" : "Córas",
    "%s (guest)" : "%s (aoi)",
    "Missed call" : "Glao caillte",
    "Unanswered call" : "Glao gan freagra",
    "Call ended (Duration {duration})" : "Cuireadh deireadh leis an nglao (Fad {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Cuireadh deireadh leis an nglao, toisc gur shroich sé uasfhad an ghlao (Fad {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} chríochnaigh an glao (Fad {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Cuireadh deireadh leis an nglao le %n aoi, toisc gur shroich sé uasfhad an ghlao (Aga {duration})","Cuireadh deireadh leis an nglao le %n aoi, toisc gur shroich sé uasfhad an ghlao (Aga {duration})","Cuireadh deireadh leis an nglao le %n aoi, toisc gur shroich sé uasfhad an ghlao (Aga {duration})","Cuireadh deireadh leis an nglao le %n aoi, toisc gur shroich sé uasfhad an ghlao (Aga {duration})","Cuireadh deireadh leis an nglao le %n aoi, toisc gur shroich sé uasfhad an ghlao (Aga {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Cuireadh deireadh leis an nglao le%n aoi (Fad{duration})","Cuireadh deireadh leis an nglao le%n aoi (Fad {duration})","Cuireadh deireadh leis an nglao le%n aoi (Fad {duration})","Cuireadh deireadh leis an nglao le%n aoi (Fad {duration})","Cuireadh deireadh leis an nglao le%n aoi (Fad {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["Chuir {actor} deireadh leis an nglao le %n aoi (Fad {duration})","Chuir {actor} deireadh leis an nglao le %n aíonna (Fad {duration})","Chuir {actor} deireadh leis an nglao le %n aíonna (Fad {duration})","Chuir {actor} deireadh leis an nglao le %n aíonna (Fad {duration})","Chuir {actor} deireadh leis an nglao le %n aíonna (Fad {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Cuireadh deireadh leis an nglao le {user1}, toisc gur shroich sé uasfhad an ghlao (Aga {duration})",
    "Call with {user1} ended (Duration {duration})" : "Cuireadh deireadh leis an nglao le {user1} (Fad {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "Chuir {actor} deireadh leis an nglao le {user1} (Fad {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Cuireadh deireadh leis an nglao le {user1} agus {user2} toisc gur shroich sé uasfhad an ghlao (Aga {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Cuireadh deireadh leis an nglao le{user1}agus{user2} (Fad {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "Chuir {actor} deireadh leis an nglao le {user1} agus {user2} (Fad {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Cuireadh deireadh leis an nglao le {user1}, {user2} agus {user3} toisc gur shroich sé uasfhad an ghlao (Fad {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Cuireadh deireadh leis an nglao le{user1},{user2} agus{user3} (Fad{duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "Chuir {actor} deireadh leis an nglao le {user1}, {user2} agus {user3} (Fad {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Cuireadh deireadh leis an nglao le {user1}, {user2}, {user3} agus {user4}, toisc gur shroich sé uasfhad an ghlao (Fad {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Cuireadh deireadh leis an nglao le{user1},{user2},{user3} agus{user4} (Fad{duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Chuir {actor} deireadh leis an nglao le {user1}, {user2}, {user3} agus {user4} (Fad {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Cuireadh deireadh leis an nglao le {user1}, {user2}, {user3}, {user4} agus {user5}, toisc gur shroich sé uasfhad an ghlao (Aga {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Cuireadh deireadh leis an nglao le{user1},{user2},{user3},{user4} agus{user5} (Fad {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Chuir {actor} deireadh leis an nglao le {user1}, {user2}, {user3}, {user4} agus {user5} (Fad {duration})",
    "Message of {user} in {conversation}" : "Teachtaireacht ó {user} i {conversation}",
    "Message of {user}" : "Teachtaireacht ó {user}",
    "Message of a deleted user in {conversation}" : "Teachtaireacht ó úsáideora scriosta i {conversation}",
    "Talk conversations" : "Déan comhráite",
    "Call %s" : "Glaoigh ar %s",
    "Chat with %s" : "Comhrá le %s",
    "An error occurred. Please contact your administrator." : "Tharla earráid. Déan teagmháil le do riarthóir le do thoil.",
    "App disabled" : "Aip díchumasaithe",
    "Conversation subfolders are disabled" : "Tá fo-fhillteáin chomhráite díchumasaithe",
    "Storage quota exceeded" : "Sáraíodh an cuóta stórála",
    "Could not prepare conversation folder" : "Níorbh fhéidir fillteán comhrá a ullmhú",
    "File not found" : "Comhad gan aimsiú",
    "Path must point to a file" : "Caithfidh an cosán pointeáil chuig comhad",
    "File is not inside the conversation draft folder for this room" : "Níl an comhad laistigh den fhillteán dréachta comhrá don seomra seo",
    "File is not shared, or shared but not with the user" : "Níl an comhad roinnte, nó roinnte ach ní leis an úsáideoir",
    "No account available to delete." : "Níl aon chuntas ar fáil le scriosadh.",
    "Poll" : "Vótaíocht",
    "Password needs to be set" : "Ní mór pasfhocal a shocrú",
    "Uploading the file failed" : "Theip ar uaslódáil an chomhaid",
    "No image file provided" : "Níor soláthraíodh aon chomhad íomhá",
    "File is too big" : "Tá an comhad ró-mhór.",
    "Invalid file provided" : "Comhad neamhbhailí curtha ar fáil",
    "Invalid image" : "Íomhá neamhbhailí",
    "Unknown filetype" : "Cineál comhaid anaithnid",
    "Talk mentions" : "Luann caint",
    "More conversations" : "Tuilleadh comhráite",
    "Say hi to your friends and colleagues!" : "Abair Dia duit a chairde agus a chomhghleacaithe!",
    "No unread mentions" : "Uimh tagairtí neamhléite",
    "Call in progress" : "Glao ar siúl",
    "You were mentioned" : "Bhí tú luaite",
    "Write to conversation" : "Scríobh chuig comhrá",
    "Writes event information into a conversation of your choice" : "Scríobhann sé faisnéis imeachtaí isteach i gcomhrá de do rogha féin",
    "Missing email field in header line" : "Réimse ríomhphoist in easnamh sa líne ceanntásca",
    "Following lines are invalid: %s" : "Tá na línte seo a leanas neamhbhailí: %s",
    "%1$s invited you to conversation \"%2$s\"." : "Thug %1$s cuireadh duit chuig comhrá \"%2$s\".",
    "You were invited to conversation \"%s\"." : "Tugadh cuireadh duit chuig comhrá \"%s\".",
    "Conversation invitation" : "Cuireadh comhrá",
    "Scheduled time" : "Am sceidealta",
    "Description" : "Cur síos",
    "You can also dial-in via phone with the following details" : "Is féidir leat scairt a chur ar an bhfón freisin leis na sonraí seo a leanas",
    "Dial-in information" : "Diailiú isteach faisnéise",
    "Meeting ID" : "Aitheantas an chruinnithe",
    "Your PIN" : "Do UAP",
    "Click the button below to join the lobby now." : "Cliceáil an cnaipe thíos chun páirt a ghlacadh sa stocaireacht anois.",
    "Click the link below to join the lobby now." : "Cliceáil ar an nasc thíos chun páirt a ghlacadh sa stocaireacht anois.",
    "Join lobby for \"%s\"" : "Glac páirt sa stocaireacht le haghaidh \"%s\"",
    "Click the button below to join the conversation now." : "Cliceáil ar an gcnaipe thíos chun páirt a ghlacadh sa chomhrá anois.",
    "Click the link below to join the conversation now." : "Cliceáil ar an nasc thíos chun páirt a ghlacadh sa chomhrá anois.",
    "Join \"%s\"" : "Glac páirt i \"%s\"",
    "Meeting" : "Cruinniú",
    "Password request: %s" : "Iarratas pasfhocail: %s",
    "Private conversation" : "Comhrá príobháideach",
    "Deleted user (%s)" : "Úsáideoir scriosta (%s)",
    "Failed to upload call recording" : "Theip ar thaifeadadh glaonna a uaslódáil",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Theip ar an bhfreastalaí taifeadta taifeadadh an ghlao {call} a uaslódáil. Déan teagmháil leis an riarachán le do thoil.",
    "Share to chat" : "Roinn le comhrá",
    "Dismiss notification" : "Déan an fógra a dhíbhe",
    "Call recording now available" : "Taifeadadh glaonna ar fáil anois",
    "The recording for the call in {call} was uploaded to {file}." : "Uaslódáladh an taifeadadh don ghlao i {call} chuig {file}.",
    "Transcript now available" : "Athscríbhinn ar fáil anois",
    "The transcript for the call in {call} was uploaded to {file}." : "Uaslódáladh an tras-scríbhinn don ghlao i {call} chuig {file}.",
    "Failed to transcript call recording" : "Theip ar thaifeadadh na nglaonna a thrascríobh",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Theip ar an bhfreastalaí an taifeadadh a thrascríobh ag {file} don ghlao i {call}. Déan teagmháil leis an riarachán le do thoil.",
    "Call summary now available" : "Achoimre glaonna ar fáil anois",
    "The summary for the call in {call} was uploaded to {file}." : "Uaslódáladh an achoimre don ghlao i{call} chuig {file}.",
    "Failed to summarize call recording" : "Theip ar an taifeadadh glaonna a achoimriú",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Theip ar an bhfreastalaí achoimre a dhéanamh ar an taifeadadh ag {file} don ghlao i{call}. Déan teagmháil leis an riarachán le do thoil.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "Thug {user1} cuireadh duit páirt a ghlacadh in {roomName} ar {remoteServer}",
    "Accept" : "Glac",
    "Decline" : "Meath",
    "{user1} invited you to a federated conversation" : "Thug {user1} cuireadh duit chuig comhrá cónasctha",
    "Someone reacted" : "D’fhreagair duine éigin",
    "New message" : "Teachtaireacht nua",
    "Reminder" : "Meabhrúchán",
    "Someone mentioned you" : "Luaigh duine éigin thú",
    "Notification" : "Fógraí",
    "Someone reacted in a private conversation" : "D’fhreagair duine éigin i gcomhrá príobháideach",
    "You received a message in a private conversation" : "Fuair ​​tú teachtaireacht i gcomhrá príobháideach",
    "Reminder in a private conversation" : "Meabhrúchán i gcomhrá príobháideach",
    "Someone mentioned you in a private conversation" : "Luaigh duine éigin thú i gcomhrá príobháideach",
    "Notification in a private conversation" : "Fógra i gcomhrá príobháideach",
    "Reminder: You in {call}" : "Meabhrúchán: Tú i {call}",
    "Reminder: {user} in {call}" : "Meabhrúchán: {user} i {call}",
    "Reminder: Deleted user in {call}" : "Meabhrúchán: úsáideoir scriosta i {call}",
    "Reminder: {guest} (guest) in {call}" : "Meabhrúchán: {guest} (aoi) i {call}",
    "Reminder: Guest in {call}" : "Meabhrúchán: Aoi i {call}",
    "{user} reacted with {reaction}" : "D'fhreagair {user} le {reaction}",
    "{user} reacted with {reaction} in {call}" : "D'fhreagair {user} le {reaction} i {call}",
    "Deleted user reacted with {reaction} in {call}" : "D'fhreagair úsáideoir scriosta le {reaction} i {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "D'fhreagair {guest} (aoi) le {reaction} i {call}",
    "Guest reacted with {reaction} in {call}" : "D'fhreagair an t-aoi le {reaction} i {call}",
    "{user} in {call}" : "{user} i {call}",
    "Deleted user in {call}" : "Scriosadh an t-úsáideoir i {call}",
    "{guest} (guest) in {call}" : "{guest} (aoi) i {call}",
    "Guest in {call}" : "Aoi i {call}",
    "{user} sent you a private message" : "Sheol {user} teachtaireacht phríobháideach chugat",
    "{user} sent a message in conversation {call}" : "Sheol {user} teachtaireacht i gcomhrá {call}",
    "A deleted user sent a message in conversation {call}" : "Sheol úsáideoir scriosta teachtaireacht i gcomhrá {call}",
    "{guest} (guest) sent a message in conversation {call}" : "Sheol {guest} (aoi) teachtaireacht i gcomhrá {call}",
    "A guest sent a message in conversation {call}" : "Sheol aoi teachtaireacht i gcomhrá {call}",
    "{user} replied to your private message" : "D'fhreagair {úsáideoir} do theachtaireacht phríobháideach",
    "{user} replied to your message in conversation {call}" : "D'fhreagair {user} do theachtaireacht i gcomhrá {call}",
    "A deleted user replied to your message in conversation {call}" : "D'fhreagair úsáideoir scriosta do theachtaireacht i gcomhrá {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "D'fhreagair {guest} (aoi) do theachtaireacht i gcomhrá {call}",
    "A guest replied to your message in conversation {call}" : "D'fhreagair aoi do theachtaireacht i gcomhrá {call}",
    "Reminder: You in private conversation {call}" : "Meabhrúchán: Tú i gcomhrá príobháideach {call}",
    "Reminder: A deleted user in private conversation {call}" : "Meabhrúchán: Úsáideoir scriosta i gcomhrá príobháideach {call}",
    "Reminder: {user} in private conversation" : "Meabhrúchán: {user} i gcomhrá príobháideach",
    "Reminder: You in conversation {call}" : "Meabhrúchán: Tú i gcomhrá {call}",
    "Reminder: {user} in conversation {call}" : "Meabhrúchán: {user} i gcomhrá {call}",
    "Reminder: A deleted user in conversation {call}" : "Meabhrúchán: Úsáideoir scriosta i gcomhrá {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Meabhrúchán: {guest} (aoi) i gcomhrá {call}",
    "Reminder: A guest in conversation {call}" : "Meabhrúchán: Aoi i gcomhrá {call}",
    "{user} reacted with {reaction} to your private message" : "D'fhreagair {user} le {reaction} do do theachtaireacht phríobháideach",
    "{user} reacted with {reaction} to your message in conversation {call}" : "D'fhreagair {user} le {reaction} do do theachtaireacht i gcomhrá {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "D'fhreagair úsáideoir scriosta le {reaction} do do theachtaireacht i gcomhrá {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "D'fhreagair {guest} (aoi) le {reaction} le do theachtaireacht i gcomhrá {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "D'fhreagair aoi le {reaction} do do theachtaireacht i gcomhrá {call}",
    "{user} mentioned you in a private conversation" : "Luaigh {user} tú i gcomhrá príobháideach",
    "{user} mentioned group {group} in conversation {call}" : "Luaigh {user} grúpa {group} i gcomhrá {call}",
    "{user} mentioned team {team} in conversation {call}" : "Luaigh {user}foireann {team}i gcomhrá {call}",
    "{user} mentioned everyone in conversation {call}" : "Luaigh {user} gach duine sa chomhrá {call}",
    "{user} mentioned you in conversation {call}" : "Luaigh {user} tú sa chomhrá {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Luaigh úsáideoir scriosta grúpa {group} i gcomhrá {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Luaigh úsáideoir scriosta foireann {team} i gcomhrá {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Luaigh úsáideoir scriosta gach duine sa chomhrá {call}",
    "A deleted user mentioned you in conversation {call}" : "Luaigh úsáideoir scriosta tú sa chomhrá {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "Luaigh {guest} (aoi) grúpa {group} i gcomhrá {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "Luaigh{guest} (aoi) foireann {team}i gcomhrá{call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "Luaigh {guest} (aoi) gach duine i gcomhrá {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "Luaigh {guest} (aoi) tú i gcomhrá {call}",
    "A guest mentioned group {group} in conversation {call}" : "Luaigh aoi grúpa {group} i gcomhrá {call}",
    "A guest mentioned team {team} in conversation {call}" : "Luaigh aoi foireann {team} i gcomhrá {call}",
    "A guest mentioned everyone in conversation {call}" : "Luaigh aoi gach duine sa chomhrá {call}",
    "A guest mentioned you in conversation {call}" : "Luaigh aoi tú i gcomhrá {call}",
    "View message" : "Féach ar an teachtaireacht",
    "Dismiss reminder" : "Ruaig meabhrúchán",
    "View chat" : "Féach ar an gcomhrá",
    "{user} invited you to a group conversation: {call}" : "Thug {user} cuireadh duit chuig comhrá grúpa: {call}",
    "Join call" : "Glac páirt sa ghlao",
    "Answer call" : "Freagair glao",
    "{user} would like to talk with you" : "Ba mhaith le {user} labhairt leat",
    "Call back" : "Glaoch ar ais",
    "You missed a call from {user}" : "Chaill tú glao ó {user}",
    "Accept call" : "Glac leis an nglao",
    "Incoming phone call from {call}" : "Glao gutháin isteach ó {call}",
    "You missed a phone call from {call}" : "Chaill tú glao gutháin ó {call}",
    "A group call has started in {call}" : "Cuireadh tús le glao grúpa i {call}",
    "You missed a group call in {call}" : "Chaill tú glao grúpa i {call}",
    "{email} is requesting the password to access {file}" : "Tá an pasfhocal á iarraidh ag {email} chun {file} a rochtain",
    "{email} tried to request the password to access {file}" : "Rinne {email} iarracht an pasfhocal a iarraidh chun rochtain a fháil ar {file}",
    "Someone is requesting the password to access {file}" : "Tá an pasfhocal á iarraidh ag duine éigin chun {file} a rochtain",
    "Someone tried to request the password to access {file}" : "Rinne duine éigin iarracht an pasfhocal a iarraidh chun {file} a rochtain",
    "Open settings" : "Oscail socruithe",
    "Hosted signaling server added" : "Cuireadh freastalaí comharthaíochta óstáilte leis",
    "The hosted signaling server is now configured and will be used." : "Tá an freastalaí comharthaíochta óstáilte cumraithe anois agus úsáidfear é.",
    "Hosted signaling server removed" : "Baineadh an freastalaí comharthaíochta óstáilte",
    "The hosted signaling server was removed and will not be used anymore." : "Baineadh an freastalaí comharthaíochta óstáilte agus ní úsáidfear é a thuilleadh.",
    "Hosted signaling server changed" : "Athraíodh an freastalaí comharthaíochta óstáilte",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "D'athraigh cuntas an fhreastalaí comharthaíochta óstáilte an stádas ó \"{oldstatus}\" go \"{newstatus}\".",
    "pending" : "ar feitheamh",
    "active" : "gníomhach",
    "expired" : "imithe in éag",
    "blocked" : "bac",
    "error" : "earráid",
    "The certificate of {host} expires in {days} days" : "Rachaidh teastas {host} in éag i gceann {days} lá",
    "The certificate of {host} expired" : "Chuaigh teastas {host} in éag",
    "Contact via Talk" : "Déan teagmháil trí Talk",
    "Open Talk" : "Caint Oscailte",
    "Call via Talk" : "Glaoigh trí Chomhrá",
    "Default" : "Réamhshocrú",
    "Send messages, create threads, and start voice and video calls." : "Seol teachtaireachtaí, cruthaigh snáitheanna, agus cuir tús le glaonna gutha agus físe.",
    "Presentation" : "Cur i láthair",
    "Restricted conversation for internal presentations." : "Comhrá srianta le haghaidh cur i láthair inmheánacha.",
    "Voice room" : "Seomra gutha",
    "Directly join the call, ideal for catch-ups or spontaneous meetings." : "Glac páirt go díreach sa ghlao, rud atá iontach maith le haghaidh comhráite nó cruinnithe spontáineacha.",
    "Webinar" : "webinar",
    "Restricted conversation with lobby enabled, ideal for public webinars." : "Comhrá srianta leis an stocaireacht cumasaithe, oiriúnach do sheimineáir ghréasáin phoiblí.",
    "Conversations" : "Comhráite",
    "Messages in current conversation" : "Teachtaireachtaí sa chomhrá reatha",
    "{user}" : "{user}",
    "Messages" : "Teachtaireachtaí",
    "{user} in {conversation}" : "{user} i {conversation}",
    "Messages in other conversations" : "Teachtaireachtaí i gcomhráite eile",
    "One-to-one rooms always need to show the other users avatar" : "Ní mór do sheomraí duine le duine avatar na n-úsáideoirí eile a thaispeáint i gcónaí",
    "Invalid emoji character" : "Carachtar emoji neamhbhailí",
    "Invalid background color" : "Dath cúlra neamhbhailí",
    "Avatar image is not square" : "Níl an íomhá avatar cearnach",
    "Room {number}" : "Seomra {number}",
    "Favorites" : "Ceanáin",
    "Other" : "Eile",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Theip ar thriail a iarraidh toisc nach féidir teacht ar an bhfreastalaí trialach. Bain triail eile as ar ball le do thoil.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Tá fadhb ann le fíordheimhniú an ásc seo. B'fhéidir nach bhfuil sé inrochtana ón taobh amuigh chun a URL a fhíorú.",
    "Something unexpected happened." : "Tharla rud gan choinne.",
    "The URL is invalid." : "Tá an URL neamhbhailí.",
    "An HTTPS URL is required." : "Tá URL HTTPS ag teastáil.",
    "The email address is invalid." : "Tá an seoladh ríomhphoist neamhbhailí.",
    "The language is invalid." : "Tá an teanga neamhbhailí.",
    "The country is invalid." : "Tá an tír neamhbhailí.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Tá fadhb ann le hiarratas na trialach. Seiceáil do logaí le haghaidh tuilleadh eolais.",
    "Too many requests are send from your servers address. Please try again later." : "Seoltar an iomarca iarratas ó do sheoladh freastalaithe. Bain triail eile as ar ball le do thoil.",
    "There is already a trial registered for this Nextcloud instance." : "Tá triail cláraithe cheana féin don ásc Nextcloud seo.",
    "Something unexpected happened. Please try again later." : "Tharla rud gan choinne. Bain triail eile as ar ball le do thoil.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Theip ar thriail a iarraidh toisc gur iompar mícheart é an freastalaí trialach. Bain triail eile as ar ball le do thoil.",
    "Trial requested but failed to get account information. Please check back later." : "Iarradh an triail ach níor éirigh leis faisnéis chuntais a fháil. Seiceáil ar ais ar ball le do thoil.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Tá fadhb ann le fíordheimhniú an iarratais seo. B'fhéidir nach bhfuil sé inrochtana ón taobh amuigh chun a URL a fhíorú.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Níorbh fhéidir faisnéis chuntais a fháil toisc gur iompar mícheart é an freastalaí trialach. Seiceáil ar ais ar ball le do thoil.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Tá fadhb ann le faisnéis an chuntais a fháil. Seiceáil do logaí le haghaidh tuilleadh eolais.",
    "There is no such account registered." : "Níl aon chuntas den sórt sin cláraithe.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Níorbh fhéidir faisnéis chuntais a fháil toisc nach féidir teacht ar an bhfreastalaí trialach. Seiceáil ar ais ar ball le do thoil.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Theip ar scriosadh an chuntais freastalaí comharthaíochta óstáilte. Seiceáil ar ais ar ball le do thoil.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Theip ar an gcuntas a scriosadh toisc gur iompar mícheart é an freastalaí trialach. Seiceáil ar ais ar ball le do thoil.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Tá fadhb ann leis an gcuntas a scriosadh. Seiceáil do logaí le haghaidh tuilleadh eolais.",
    "Too many requests are sent from your servers address. Please try again later." : "Seoltar an iomarca iarratas ó do sheoladh freastalaithe. Bain triail eile as ar ball le do thoil.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Theip ar an gcuntas a scriosadh toisc nach féidir teacht ar an bhfreastalaí trialach. Seiceáil ar ais ar ball le do thoil.",
    "Note to self" : "Nóta dó féin",
    "A place for your private notes, thoughts and ideas" : "Áit le haghaidh do chuid nótaí príobháideacha, smaointe agus smaointe",
    "Transcript is AI generated and may contain mistakes" : "Gintear AI an tras-scríbhinn agus d’fhéadfadh botúin a bheith ann",
    "Summary is AI generated and may contain mistakes" : "Gintear achoimre ar AI agus d’fhéadfadh botúin a bheith ann",
    "Let's get started!" : "Cuirimis tús leis!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "Is ardán cumarsáide slán féin-óstach é **Nextcloud Talk** a chomhtháthaíonn gan uaim le héiceachóras Nextcloud.\n\n#### Príomhghnéithe de Nextcloud Talk:\n\n* Comhrá agus teachtaireachtaí i gcomhráite príobháideacha agus grúpa\n* Glaonna gutha agus físe\n* Comhroinnt agus comhtháthú le haipeanna eile Nextcloud\n* Socruithe comhrá saincheaptha, modhnóireacht agus rialuithe príobháideachais\n* Gréasán, deasc agus soghluaiste (iOS agus Android)\n* Cumarsáid phríobháideach agus shlán\n\nFaigh tuilleadh eolais sa [dhoiciméadú úsáideora](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Fáilte go Nextcloud Talk\n\nIs aip teachtaireachtaí príobháideach agus cumhachtach é Nextcloud Talk a chomhtháthaíonn le Nextcloud. Déan comhrá i gcomhráite príobháideacha nó grúpa, comhoibrigh thar ghlaonna gutha agus físe, eagraigh seimineáir agus imeachtaí, saincheap do chomhráite agus go leor eile.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Formáidigh téacsanna chun teachtaireachtaí saibhir a chruthú\n\nIn Nextcloud Talk, is féidir leat comhréir Markdown a úsáid chun do theachtaireachtaí a fhormáidiú. Mar shampla, cuir formáidiú **trom** nó *iodálach* i bhfeidhm, nó 'béim ar théacsanna mar chód`. Is féidir leat fiú táblaí a chruthú agus ceannteidil a chur le do théacs.\n\nAn gá clóscríobh a shocrú nó formáidiú a athrú? Cuir do theachtaireacht in eagar trí \"Cuir teachtaireacht in eagar\" a chliceáil sa roghchlár teachtaireachta.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Cuir ceangaltáin agus naisc leis\n\nCeangail comhaid ó do Mhol Nextcloud ag baint úsáide as an gcnaipe \"+\". Comhroinn míreanna ó Chomhaid agus aipeanna éagsúla Nextcloud. Tacaíonn roinnt apps fiú le giuirléidí idirghníomhacha, mar shampla, an app Téacs.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Lig do na comhráite sreabhadh: luaigh úsáideoirí, freagair do theachtaireachtaí agus tuilleadh\n\nIs féidir leat gach duine sa chomhrá a lua trí %s a úsáid nó rannpháirtithe sonracha a lua trí \"@\" a chlóscríobh agus a n-ainm a roghnú ón liosta.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Is féidir leat freagra a thabhairt ar theachtaireachtaí, iad a chur ar aghaidh chuig comhráite agus daoine eile, nó ábhar na teachtaireachta a chóipeáil.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Déan níos mó le Smart Picker\n\nNíl ort ach clóscríobh \"/\" nó téigh go dtí an roghchlár \"+\" chun an Piocálaí Cliste a oscailt áit ar féidir leat ábhar éagsúla a cheangal le do theachtaireachtaí. Is féidir leat an Roghnóir Cliste a chumrú le bheith in ann míreanna a chur leis ó aipeanna Nextcloud, GIFs, láithreacha léarscáileanna, ábhar a ghintear le AI agus go leor eile.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Bainistigh socruithe comhrá\n\nSa roghchlár comhrá, is féidir leat rochtain a fháil ar shocruithe éagsúla chun do chomhráite a bhainistiú, mar shampla:\n* Cuir eolas an chomhrá in eagar\n* Bainistigh fógraí\n* Cuir go leor rialacha modhnóireachta i bhfeidhm\n* Cumraigh rochtain agus slándáil\n* Cumasaigh róbónna\n* agus níos mó!",
    "Andorra" : "Andóra",
    "United Arab Emirates" : "Aontas na nÉimíríochtaí Arabacha",
    "Afghanistan" : "Afganastáin",
    "Antigua and Barbuda" : "Antigua agus Barbúda",
    "Anguilla" : "Anguilla",
    "Albania" : "an Albáin",
    "Armenia" : "Airméin",
    "Angola" : "Angóla",
    "Antarctica" : "Antartaice",
    "Argentina" : "an Airgintín",
    "American Samoa" : "Samó Meiriceánach",
    "Austria" : "Ostair",
    "Australia" : "Astráil",
    "Aruba" : "Aruba",
    "Åland Islands" : "Oileáin Åland",
    "Azerbaijan" : "Asarbaiseáin",
    "Bosnia and Herzegovina" : "An Bhoisnia agus an Heirseagaivéin",
    "Barbados" : "Barbadós",
    "Bangladesh" : "Bhanglaidéis",
    "Belgium" : "an Bheilg",
    "Burkina Faso" : "Buircíne Fasó",
    "Bulgaria" : "an Bhulgáir",
    "Bahrain" : "Bairéin",
    "Burundi" : "An Bhurúin",
    "Benin" : "Beinin",
    "Saint Barthélemy" : "Naomh Barthélemy",
    "Bermuda" : "Beirmiúda",
    "Brunei Darussalam" : "Brúiné Dárasalám",
    "Bolivia, Plurinational State of" : "An Bholaiv, Stát Iolrnáisiúnta na",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius agus Saba",
    "Brazil" : "an Bhrasaíl",
    "Bahamas" : "Bahámaí",
    "Bhutan" : "Bhútáin",
    "Bouvet Island" : "Oileán Bouvet",
    "Botswana" : "Bhotsuáin",
    "Belarus" : "Bhealarúis",
    "Belize" : "Bheilís",
    "Canada" : "Ceanada",
    "Cocos (Keeling) Islands" : "Oileáin Cocos (Keeling).",
    "Congo, the Democratic Republic of the" : "an Chongó, Poblacht Dhaonlathach an",
    "Central African Republic" : "Poblacht na hAfraice Láir",
    "Congo" : "Chongó",
    "Switzerland" : "Eilvéis",
    "Côte d'Ivoire" : "Cósta Eabhair",
    "Cook Islands" : "Oileáin Cook",
    "Chile" : "an tSile",
    "Cameroon" : "Camarún",
    "China" : "tSín",
    "Colombia" : "an Cholóim",
    "Costa Rica" : "Cósta Ríce",
    "Cuba" : "Cúba",
    "Cabo Verde" : "Rinn Verde",
    "Curaçao" : "Curacao",
    "Christmas Island" : "Oileán na Nollag",
    "Cyprus" : "an Chipir",
    "Czechia" : "Seicis",
    "Germany" : "an Ghearmáin",
    "Djibouti" : "Djibútí",
    "Denmark" : "an Danmhairg",
    "Dominica" : "Doiminic",
    "Dominican Republic" : "An Phoblacht Dhoiminiceach",
    "Algeria" : "Ailgéir",
    "Ecuador" : "Eacuadór",
    "Estonia" : "an Eastóin",
    "Egypt" : "Éigipt",
    "Western Sahara" : "Sahára Thiar",
    "Eritrea" : "Eiritré",
    "Spain" : "an Spáinn",
    "Ethiopia" : "Aetóip",
    "Finland" : "an Fhionlainn",
    "Fiji" : "Fidsí",
    "Falkland Islands (Malvinas)" : "Oileáin Fháclainne (Malvinas)",
    "Micronesia, Federated States of" : "Micrinéise, Stáit Chónaidhme na",
    "Faroe Islands" : "Oileáin Fharó",
    "France" : "Fhrainc",
    "Gabon" : "Ghabúin",
    "United Kingdom of Great Britain and Northern Ireland" : "Ríocht Aontaithe na Breataine Móire agus Thuaisceart Éireann",
    "Grenada" : "Greanáda",
    "Georgia" : "An tSeoirsia",
    "French Guiana" : "Guáin na Fraince",
    "Guernsey" : "Geansaí",
    "Ghana" : "Gána",
    "Gibraltar" : "Giobráltar",
    "Greenland" : "Ghraonlainn",
    "Gambia" : "An Ghaimbia",
    "Guinea" : "Ghuine",
    "Guadeloupe" : "Guadalúip",
    "Equatorial Guinea" : "An Ghuine Mheánchriosach",
    "Greece" : "an Ghréig",
    "South Georgia and the South Sandwich Islands" : "An tSeoirsia Theas agus na hOileáin Sandwich Theas",
    "Guatemala" : "Guatamala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guine Bhissau",
    "Guyana" : "Ghuáin",
    "Hong Kong" : "Hong Cong",
    "Heard Island and McDonald Islands" : "Oileán Heard agus Oileáin McDonald",
    "Honduras" : "Hondúras",
    "Croatia" : "an Chróit",
    "Haiti" : "Háití",
    "Hungary" : "an Ungáir",
    "Indonesia" : "Indinéis",
    "Ireland" : "Éire",
    "Israel" : "Iosrael",
    "Isle of Man" : "Oileán Mhanann",
    "India" : "India",
    "British Indian Ocean Territory" : "Críoch Aigéan Indiach na Breataine",
    "Iraq" : "Iaráic",
    "Iran, Islamic Republic of" : "Iaráin, Poblacht Ioslamach na",
    "Iceland" : "Íoslainn",
    "Italy" : "an Iodáil",
    "Jersey" : "Geirsí",
    "Jamaica" : "Iamáice",
    "Jordan" : "an Iordáin",
    "Japan" : "an tSeapáin",
    "Kenya" : "an Chéinia",
    "Kyrgyzstan" : "Chirgeastáin",
    "Cambodia" : "an Chambóid",
    "Kiribati" : "Ciribeas",
    "Comoros" : "Oileáin Chomóra",
    "Saint Kitts and Nevis" : "San Críostóir-Nimheas",
    "Korea, Democratic People's Republic of" : "An Chóiré, Daon-Phoblacht Dhaonlathach na",
    "Korea, Republic of" : "An Chóiré, Poblacht na",
    "Kuwait" : "Cuáit",
    "Cayman Islands" : "Oileáin Cayman",
    "Kazakhstan" : "Chasacstáin",
    "Lao People's Democratic Republic" : "Daon-Phoblacht Dhaonlathach Lao",
    "Lebanon" : "an Liobáin",
    "Saint Lucia" : "Naomh Lucia",
    "Liechtenstein" : "Lichtinstéin",
    "Sri Lanka" : "Srí Lanca",
    "Liberia" : "Libéir",
    "Lesotho" : "Leosóta",
    "Lithuania" : "an Liotuáin",
    "Luxembourg" : "Lucsamburg",
    "Latvia" : "an Laitvia",
    "Libya" : "Libia",
    "Morocco" : "Maracó",
    "Monaco" : "Monacó",
    "Moldova, Republic of" : "Mholdóiv, Poblacht na",
    "Montenegro" : "Montainéagró",
    "Saint Martin (French part)" : "Naomh Máirtín (cuid Fraincise)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Oileáin Mharshall",
    "North Macedonia" : "An Mhacadóin Thuaidh",
    "Mali" : "Mailí",
    "Myanmar" : "Maenmar",
    "Mongolia" : "an Mhongóil",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Oileáin Mariana Thuaidh",
    "Martinique" : "Mairtíreach",
    "Mauritania" : "Mháratáin",
    "Montserrat" : "Montsarat",
    "Malta" : "an Mhálta",
    "Mauritius" : "Oileán Mhuirís",
    "Maldives" : "Oileáin Mhaildíve",
    "Malawi" : "an Mhaláiv",
    "Mexico" : "Meicsiceo",
    "Malaysia" : "Mhalaeisia",
    "Mozambique" : "Mósaimbíc",
    "Namibia" : "Namaib",
    "New Caledonia" : "An Nua-Chaladóin",
    "Niger" : "Nígir",
    "Norfolk Island" : "Oileán Norfolk",
    "Nigeria" : "Nigéir",
    "Nicaragua" : "Nicearagua",
    "Netherlands" : "an Ísiltír",
    "Norway" : "an Iorua",
    "Nepal" : "Neipeal",
    "Nauru" : "Nárú",
    "Niue" : "Niue",
    "New Zealand" : "An Nua-Shéalainn",
    "Oman" : "Óman",
    "Panama" : "Panama",
    "Peru" : "Peiriú",
    "French Polynesia" : "Polainéis na Fraince",
    "Papua New Guinea" : "Nua-Ghuine Phapua",
    "Philippines" : "hOileáin Fhilipíneacha",
    "Pakistan" : "an Phacastáin",
    "Poland" : "an Pholainn",
    "Saint Pierre and Miquelon" : "Naomh Pierre agus Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Pórtó Ríce",
    "Palestine, State of" : "Phalaistín, Stát",
    "Portugal" : "an Phortaingéil",
    "Palau" : "Palau",
    "Paraguay" : "Paragua",
    "Qatar" : "Catar",
    "Réunion" : "Réunion",
    "Romania" : " an Rómáin",
    "Serbia" : "an tSeirbia",
    "Russian Federation" : "Cónaidhm na Rúise",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "An Araib Shádach",
    "Solomon Islands" : "Oileáin Sholamón",
    "Seychelles" : "Na Séiséil",
    "Sudan" : "an tSúdáin",
    "Sweden" : "an tSualainn",
    "Singapore" : "Singeapór",
    "Saint Helena, Ascension and Tristan da Cunha" : "San Héilin, Ascension agus Tristan da Cunha",
    "Slovenia" : "an tSlóivéin",
    "Svalbard and Jan Mayen" : "Svalbard agus Jan Mayen",
    "Slovakia" : "an tSlóvaic",
    "Sierra Leone" : "Siarra Leon",
    "San Marino" : "San Mairíne",
    "Senegal" : "an tSeineagáil",
    "Somalia" : "an tSomáil",
    "Suriname" : "Suranam",
    "South Sudan" : "an tSúdáin Theas",
    "Sao Tome and Principe" : "Sao Tome agus Principe",
    "El Salvador" : "an tSalvadóir",
    "Sint Maarten (Dutch part)" : "Sint Maarten (an chuid Ollainnis)",
    "Syrian Arab Republic" : "Poblacht Arabach na Siria",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Oileáin na dTurcach agus na Caicos",
    "Chad" : "Sead",
    "French Southern Territories" : "Críocha Theas na Fraince",
    "Togo" : "Tóga",
    "Thailand" : "an Téalainn",
    "Tajikistan" : "Táidsíceastáin",
    "Tokelau" : "Tócalainn",
    "Timor-Leste" : "Tíomór-Leste",
    "Turkmenistan" : "Tuircméanastáin",
    "Tunisia" : "an Túinéis",
    "Tonga" : "Tonga",
    "Turkey" : "n Tuirc",
    "Trinidad and Tobago" : "Oileán na Tríonóide agus Tobága",
    "Tuvalu" : "Túvalú",
    "Taiwan, Province of China" : "Taiwan, Cúige na Síne",
    "Tanzania, United Republic of" : "An Tansáin, Poblacht Aontaithe na",
    "Ukraine" : "an Úcráin",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Mionoileáin Imeallacha na Stát Aontaithe",
    "United States of America" : "Stáit Aontaithe Mhéiriceá",
    "Uruguay" : "Uragua",
    "Uzbekistan" : "Úisbéiceastáin",
    "Holy See" : "Suí Naofa",
    "Saint Vincent and the Grenadines" : "San Uinseann agus na Greanáidíní",
    "Venezuela, Bolivarian Republic of" : "Veiniséala, Poblacht Bolivarian na",
    "Virgin Islands, British" : "Oileáin na Maighdean, na Breataine",
    "Virgin Islands, U.S." : "Oileáin na Maighdean, U.S.",
    "Viet Nam" : "Vítneam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis agus Futúna",
    "Samoa" : "Samó",
    "Yemen" : "Éimin",
    "Mayotte" : "Maigh Eo",
    "South Africa" : "an Afraic Theas",
    "Zambia" : "an tSaimbia",
    "Zimbabwe" : "An tSiombáib",
    "Background blur" : "Geamhú an chúlra",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Níorbh fhéidir tacaíocht lódála WASM a sheiceáil. Seiceáil le do thoil de láimh an bhfreastalaíonn do fhreastalaí gréasáin ar chomhaid `.wasm`.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Níl do fhreastalaí gréasáin socraithe i gceart chun comhaid `.wasm` a sheachadadh. De ghnáth is saincheist é seo le cumraíocht Nginx. Le haghaidh doiléir an chúlra ní mór é a choigeartú chun comhaid `.wasm` a sheachadadh freisin. Déan do chumraíocht Nginx a chur i gcomparáid leis an gcumraíocht mholta inár gcáipéisíocht.",
    "Talk configuration values" : "Labhair luachanna cumraíochta",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Ní thacaítear ach le córas cron a chur iallach ar ghlao. Cumasaigh cron an chórais nó bain an chumraíocht `max_call_dration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Níl luachanna beaga `max_call_duration` (socraithe go%dfaoi láthair) infheidhmithe de bharr srianta teicniúla. Ní dhéantar an post cúlra ach amháin gach 5 nóiméad, mar sin bain úsáid as ar do phriacal féin.",
    "Federation" : "Cónaidhm",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Moltar go mór \"memcache.locking\" a chumrú nuair atá Talk Federation cumasaithe.",
    "High-performance backend" : "Inneall ardfheidhmíochta",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Gan Inneall Ardfheidhmíochta cumraithe - Nextcloud Talk a Rith gan na scálaí Inneall Ardfheidhmíochta amháin le haghaidh glaonna an-bheag (2-3 rannpháirtí ar a mhéad). Socraigh le do thoil an t-Inneall Ardfheidhmíochta chun a chinntiú go n-oibríonn glaonna le rannpháirtithe iolracha gan stró.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Ní cheadaítear an modh \"conversation_cluster\" Inneall Ardfheidhmíochta a rith agus ní thacófar leis a thuilleadh sa leagan atá le teacht. Tacaíonn an t-Inneall Ardfheidhmíochta le fíorchnuasaigh sa lá atá inniu ann ar cheart a úsáid ina ionad.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Ní dhéanfar aon inneall ardfheidhmíochta iolrach a shainiú agus ní thacófar leis a thuilleadh sa leagan atá le teacht. Ina áit sin ba cheart cothromóir ualaigh a shocrú in éineacht le freastalaithe comharthaíochta cnuasaithe agus é a chumrú sna socruithe Plé.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "Ní hionann an eochair phoiblí stóráilte don algartam %1$s a úsáideadh agus an eochair phríobháideach stóráilte. Rith %2$s chun an fhadhb a réiteach.",
    "High-performance backend not configured correctly. Run %s for details." : "Níl an cúltaca ardfheidhmíochta cumraithe i gceart. Rith %s le haghaidh sonraí.",
    "High-performance backend not configured correctly" : "Inneall ardfheidhmíochta gan a bheith cumraithe i gceart",
    "Error: Cannot connect to server" : "Earráid: Ní féidir ceangal leis an bhfreastalaí",
    "Error: Server did not respond with proper JSON" : "Earráid: Níor fhreagair an freastalaí leis an JSON cuí",
    "Error: Certificate expired" : "Earráid: Deimhniú imithe in éag",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Earráid: Níl amanna córais fhreastalaí Nextcloud agus freastalaí Inneall Ardfheidhmíochta as sioncronú. Cinntigh le do thoil go bhfuil an dá fhreastalaí ceangailte le freastalaí ama nó sioncrónaigh a gcuid ama de láimh.",
    "Could not get version" : "Níorbh fhéidir an leagan a fháil",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Earráid: Leagan rith: {version}; Ní mór an freastalaí a nuashonrú le bheith comhoiriúnach leis an leagan seo de Talk",
    "Error: Server responded with: {error}" : "Earráid: D'fhreagair an freastalaí le: {error}",
    "Error: Unknown error occurred" : "Earráid: Tharla earráid anaithnid",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Rabhadh: Leagan reatha: {version}; Ní thacaíonn an freastalaí le gach gné den leagan Talk seo, tá gnéithe in easnamh: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Moltar go mór taisce cuimhne a chumrú agus Nextcloud Talk á rith le hInneall Ardfheidhmíochta.",
    "Client Push" : "Brúigh Cliant",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "Tá Client Push suiteáilte, feabhsaíonn sé seo poncúlacht fógraí Talk.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "Níl {notify_push} suiteáilte. D’fhéadfadh sé seo moill a chur ar fhógraí Talk.",
    "Recording backend" : "Inneall taifeadta",
    "Using the recording backend requires a High-performance backend." : "Teastaíonn inneall Ardfheidhmíochta chun an t-inneall taifeadta a úsáid.",
    "No recording backend configured" : "Níl aon inneall taifeadta cumraithe",
    "SIP configuration" : "Cumraíocht SIP",
    "Using the SIP functionality requires a High-performance backend." : "Teastaíonn inneall Ardfheidhmíochta chun feidhmiúlacht SIP a úsáid.",
    "Assigned Talk phone numbers must not start with + or 0. Please remove or update the following numbers:\n{list}" : "Ní féidir uimhreacha gutháin Sannta Comhrá a thosú le + ná 0. Bain nó nuashonraigh na huimhreacha seo a leanas le do thoil:\n{list}",
    "No SIP backend configured" : "Níl aon inneall SIP cumraithe",
    "Invalid date, date format must be YYYY-MM-DD" : "Dáta neamhbhailí, caithfidh formáid an dáta a bheith BBBB-MM-DD",
    "Conversation not found" : "Comhrá gan aimsiú",
    "Path is already shared with this conversation" : "Tá an chonair roinnte leis an gcomhrá seo cheana féin",
    "Chat, video & audio-conferencing using WebRTC" : "Comhrá, físchomhdháil & closchomhdháil ag úsáid WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Comhrá, físchomhdháil & closchomhdháil ag úsáid WebRTC\n\n* 💬 **Comhrá** Tagann Nextcloud Talk le comhrá téacs simplí, a ligeann duit comhaid a roinnt nó a uaslódáil ó d’aip nó do ghléas áitiúil Nextcloud Files agus rannpháirtithe eile a lua.\n* 👥 **Glaonna príobháideacha, grúpa, poiblí agus cosanta ag pasfhocal!** Tabhair cuireadh do dhuine éigin, do ghrúpa iomlán nó seol nasc poiblí chun cuireadh a thabhairt do ghlao.\n* 🌐 **Comhráite Cónaidhme** Déan comhrá le húsáideoirí eile Nextcloud ar a bhfreastalaithe\n* 💻 **Scáileán a roinnt!** Roinn do scáileán le rannpháirtithe do ghlao.\n* 🚀 ** Comhtháthú le haipeanna Nextcloud eile** cosúil le Comhaid, Féilire, Stádas Úsáideora, Painéal na nIonstraimí, Sreabhadh, Léarscáileanna, Roghnóir Cliste, Teagmhálacha, Deic, agus go leor eile.\n* 🌉 **Sioncronaigh le réitigh chomhrá eile** Agus [Matterbridge](https://github.com/42wim/matterbridge/) á chomhtháthú in Talk, is féidir leat go leor réitigh comhrá eile a shioncronú go héasca le Nextcloud Talk agus vice- versa.",
    "Leave call" : "Fág glaoch",
    "Navigating away from the page will leave the call in {conversation}" : "Má sheolann tú amach ón leathanach fágfar an glao i {conversation}",
    "Stay in call" : "Fan ar glaoch",
    "Error occurred when getting the conversation information" : "Tharla earráid agus faisnéis an chomhrá á fáil",
    "Duplicate session" : "Seisiún dúblach",
    "Discuss this file" : "Pléigh an comhad seo",
    "Loading …" : "Á lódáil…",
    "Share this file with others to discuss it" : "Roinn an comhad seo le daoine eile chun é a phlé",
    "Join conversation" : "Glac páirt sa chomhrá",
    "Share this file" : "Roinn an comhad seo",
    "Error occurred when joining the conversation" : "Tharla earráid agus tú ag glacadh páirte sa chomhrá",
    "Open in full application" : "Oscail san fheidhmchlár iomlán",
    "This conversation is password-protected." : "Tá an comhrá seo cosanta ag pasfhocal.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Bhraitheamar go leor iarrachtaí pasfhocail neamhbhailí ó do IP. Dá bhrí sin tá do chéad iarracht eile throttled suas go dtí 30 soicind.",
    "The password is wrong. Try again." : "Tá an focal faire mícheart. Déan iarracht arís.",
    "Password" : "Pasfhocal",
    "Submit" : "Cuir isteach",
    "Error requesting the password." : "Earráid agus an focal faire á iarraidh.",
    "Request password" : "Iarr pasfhocal",
    "This conversation has ended" : "Tá deireadh leis an gcomhrá seo",
    "Close Talk sidebar" : "Dún an barra taoibh Talk",
    "Open Talk sidebar" : "Oscail barra taoibh Talk",
    "Everyone" : "Gach duine",
    "Users and moderators" : "Úsáideoirí agus modhnóirí",
    "Moderators only" : "Modhnóirí amháin",
    "Disable calls" : "Díchumasaigh glaonna",
    "Save changes" : "Sabháil na hathruithe",
    "Saving …" : "Shábháil …",
    "Saved!" : "Shábháil!",
    "Limit to groups" : "Teorainn do ghrúpaí",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Nuair a roghnaítear grúpa amháin ar a laghad, ní féidir ach le daoine de na grúpaí liostaithe a bheith mar chuid de chomhráite.",
    "Guests can still join public conversations." : "Is féidir le haíonna páirt a ghlacadh i gcomhráite poiblí fós.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Déanfar úsáideoirí nach bhfuil in ann Plé a úsáid a thuilleadh a liostú mar rannpháirtithe ina gcomhráite roimhe seo agus coimeádfar a dteachtaireachtaí comhrá freisin.",
    "Limit using Talk" : "Teorainn ag baint úsáide as Talk",
    "Limit creating a public and group conversation" : "Cuir teorainn le comhrá poiblí agus comhrá grúpa a chruthú",
    "Limit creating conversations" : "Cuir teorainn le cruthú comhráite",
    "Limit starting a call" : "Cuir teorainn le glao a thosú",
    "Limit starting calls" : "Cuir teorainn le glaonna tosaithe",
    "When a call has started, everyone with access to the conversation can join the call." : "Nuair a chuirtear tús le glao, is féidir le gach duine a bhfuil rochtain acu ar an gcomhrá páirt a ghlacadh sa ghlao.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Tá na róbónna seo a leanas suiteáilte ar an bhfreastalaí seo. Sna doiciméid is féidir leat sonraí a fháil maidir le conas {linkstart1}do bhota féin a thógáil{linkend} nó {linkstart2}liosta róbónna{linkend} le cumasú ar do fhreastalaí.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Níl aon róbónna suiteáilte ar an bhfreastalaí seo. Sna doiciméid is féidir leat sonraí a fháil maidir le conas {linkstart1}do bhota féin a thógáil{linkend} nó {linkstart2}liosta róbónna{linkend} le cumasú ar do fhreastalaí.",
    "Description is not provided" : "Ní thugtar tuairisc",
    "Locked for moderators" : "Faoi ghlas le haghaidh modhnóirí",
    "Enabled" : "Cumasaithe",
    "Disabled" : "Faoi mhíchumas",
    "Bots settings" : "Socruithe róbónna",
    "State" : "Stáit",
    "Name" : "Ainm",
    "Last error" : "Earráid dheireanach",
    "Total errors count" : "Áireamh earráidí iomlána",
    "Find more bots" : "Faigh tuilleadh róbónna",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Is féidir freastalaithe iontaofa a chumrú ag {linkstart}Leathanach na socruithe a roinnt{linkedin}.",
    "Beta" : "Béite",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Oibríonn comhráite agus glaonna cónaidhme cheana féin. Tá láimhseáil ceangaltán ag teacht i leagan amach anseo.",
    "Enable Federation in Talk app" : "Cumasaigh Federation in Talk aip",
    "Permissions" : "Ceadanna",
    "Allow users to be invited to federated conversations" : "Ceadaigh cuireadh a thabhairt d'úsáideoirí chuig comhráite cónasctha",
    "Allow users to invite federated users into conversation" : "Lig d'úsáideoirí cuireadh a thabhairt d'úsáideoirí cónasctha chun comhrá a dhéanamh",
    "Only allow to federate with trusted servers" : "Ná ceadaigh ach cónascadh le freastalaithe iontaofa",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Nuair a roghnaítear grúpa amháin ar a laghad, ní féidir ach le daoine de na grúpaí liostaithe cuireadh a thabhairt d’úsáideoirí cónasctha chuig comhráite.",
    "Groups allowed to invite federated users" : "Tá cead ag grúpaí cuireadh a thabhairt d'úsáideoirí cónasctha",
    "Select groups …" : "Roghnaigh grúpaí…",
    "All messages" : "Gach teachtaireacht",
    "@-mentions only" : "@-luaite amháin",
    "Off" : "as",
    "General settings" : "Socruithe Ginearálta",
    "Default notification settings" : "Socruithe fógra réamhshocraithe",
    "Default group notification" : "Fógra grúpa réamhshocraithe",
    "Default group notification for new groups" : "Fógra grúpa réamhshocraithe do ghrúpaí nua",
    "Integration into other apps" : "Comhtháthú le haipeanna eile",
    "Allow conversations on files" : "Ceadaigh comhráite ar chomhaid",
    "Allow conversations on public shares for files" : "Ceadaigh comhráite ar scaireanna poiblí do chomhaid",
    "End-to-end encrypted calls" : "Glaonna criptithe ó cheann go ceann",
    "Enable encryption" : "Cumasaigh criptiú",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Teastaíonn leagan níos nuaí den Inneall Ardfheidhmíochta agus droichead SIP le glaonna criptithe ceann go ceann le droichead SIP cumraithe.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Ní thacaíonn cliaint shoghluaiste le glaonna criptithe ceann go ceann faoi láthair.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Trí chliceáil ar an gcnaipe thuas seoltar an fhaisnéis san fhoirm chuig freastalaithe Struktur AG. Is féidir leat tuilleadh faisnéise a fháil ag {linkstart}spreed.eu{linkend}.",
    "Pending" : "Ar feitheamh",
    "Error" : "Earráid",
    "Blocked" : "Bactha",
    "Active" : "Gníomhach",
    "Expired" : "Imithe in éag",
    "Never" : "Riamh",
    "The trial could not be requested. Please try again later." : "Níorbh fhéidir an triail a iarraidh. Bain triail eile as ar ball le do thoil.",
    "The account could not be deleted. Please try again later." : "Níorbh fhéidir an cuntas a scriosadh. Bain triail eile as ar ball le do thoil.",
    "Hosted High-performance backend" : "Inneall Ardfheidhmíochta arna óstáil",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Soláthraíonn ár gcomhpháirtí Struktur AG seirbhís inar féidir freastalaí comharthaíochta óstáilte a iarraidh. Chuige seo ní gá duit ach an fhoirm thíos a líonadh agus iarrfaidh do Nextcloud í. Nuair a bheidh an freastalaí socraithe duit líonfar na dintiúir go huathoibríoch. Forscríobhfaidh sé seo na socruithe freastalaí comharthaíochta atá ann cheana féin.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Má tá feidhmiúlacht STUN agus/nó TURN i do chuntas cúil ardfheidhmíochta, déanfar na socruithe a nuashonrú dá réir.",
    "URL of this Nextcloud instance" : "URL an ásc Nextcloud seo",
    "Full name of the user requesting the trial" : "Ainm iomlán an úsáideora a iarrann an triail",
    "Email of the user" : "Ríomhphost an úsáideora",
    "Language" : "Teanga",
    "Country" : "Tír",
    "Request signaling server trial" : "Iarr triail freastalaí comharthaíochta",
    "You can see the current status of your hosted signaling server in the following table." : "Is féidir leat stádas reatha do fhreastalaí comharthaíochta óstáilte a fheiceáil sa tábla seo a leanas.",
    "Status" : "Stádas",
    "Created at" : "Cruthaithe ag",
    "Expires at" : "In éag ag",
    "Limits" : "Teorainneacha",
    "STUN included" : "STUN san áireamh",
    "Yes" : "Tá",
    "No" : "Níl",
    "TURN included" : "TURN san áireamh",
    "Delete the signaling server account" : "Scrios an cuntas freastalaí comharthaíochta",
    "_%n user_::_%n users_" : ["%n úsáideoir","%n úsáideoirí","%n úsáideoirí","%n úsáideoirí","%n úsáideoirí"],
    "Installed version: {version}" : "Leagan suiteáilte: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Is féidir leat an Matterbridge a shuiteáil chun Nextcloud Talk a nascadh le roinnt seirbhísí eile, tabhair cuairt ar a {linkstart1}leathanach GitHub{linkend} le haghaidh tuilleadh sonraí. Is féidir go dtógfaidh sé tamall an aip a íoslódáil agus a shuiteáil. Ar eagla go mbeidh teorainn leis, suiteáil de láimh é ón {linkstart2}Nextcloud Siopa Aip{linkend} le do thoil.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Tá ceadanna míchearta ag dénártha Matterbridge. Cinntigh le do thoil gur leis an úsáideoir ceart an comhad dénártha Matterbridge agus gur féidir é a fhorghníomhú. Is féidir é a fháil in \"/…/nextcloud/apps/talk_matterbridge/bin/\".",
    "Matterbridge binary was not found or couldn't be executed." : "Níor aimsíodh dénártha Matterbridge nó níorbh fhéidir é a fhorghníomhú.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Is féidir leat an cosán chuig dénártha Matterbridge a shocrú de láimh freisin tríd an config. Seiceáil an {linkstart}doiciméadú comhtháthú Matterbridge{linkend} le haghaidh tuilleadh faisnéise.",
    "Downloading …" : "Ag íosluchtú…",
    "Install Talk Matterbridge" : "Suiteáil Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Tharla earráid agus an aip Matterbridge á shuiteáil",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Tharla earráid agus an Talk Matterbridge á shuiteáil. Suiteáil de láimh é le do thoil",
    "Failed to execute Matterbridge binary." : "Theip ar dhénártha Matterbridge a rith.",
    "Matterbridge integration" : "Comhtháthú Matterbridge",
    "Enable Matterbridge integration" : "Cumasaigh comhtháthú Matterbridge",
    "Status: Checking connection" : "Stádas: Ag seiceáil an nasc",
    "OK: Running version: {version}" : "OK: Leagan reatha: {version}",
    "Error: Server seems to be a Signaling server" : "Earráid: Is cosúil gur freastalaí Comharthaíochta é an freastalaí",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Earráid: Níl amanna córais fhreastalaí Nextcloud agus freastalaí Inneall Taifeadta as sioncronú. Cinntigh le do thoil go bhfuil an dá fhreastalaí ceangailte le freastalaí ama nó sioncrónaigh a gcuid ama de láimh.",
    "Recording backend URL" : "URL inneall taifeadta",
    "Validate SSL certificate" : "Bailíochtaigh teastas SSL",
    "Delete this server" : "Scrios an freastalaí seo",
    "Test this server" : "Tástáil an freastalaí seo",
    "Disabled for all calls" : "Díchumasaithe do gach glaoch",
    "Enabled for all calls" : "Cumasaithe do gach glao",
    "Configurable on conversation level by moderators" : "Cumraithe ag modhnóirí ar leibhéal an chomhrá",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "Ní cheadóidh na socruithe PHP \"upload_max_filesize\" nó \"post_max_size\" ach comhaid suas go dtí {maxUpload} a uaslódáil.",
    "Recording backend settings saved" : "Sábháladh socruithe inneall taifeadta",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Beidh cead ag modhnóirí toiliú a chumasú ar leibhéal an chomhrá. Beidh toiliú le taifeadadh ag teastáil ó gach rannpháirtí sula nglacann siad le gach glao sa chomhrá seo.",
    "The consent to be recorded will be required for each participant before joining every call." : "Beidh toiliú le taifeadadh ag teastáil ó gach rannpháirtí sula nglacfaidh sé páirt i ngach glao.",
    "The consent to be recorded is not required." : "Níl an toiliú le taifeadadh riachtanach.",
    "Recording backend configuration is only possible with a High-performance backend." : "Ní féidir cumraíocht inneall a thaifeadadh ach le hInneall Ardfheidhmíochta.",
    "Add a new recording backend server" : "Cuir freastalaí inneall taifeadta nua leis",
    "Shared secret" : "Rún comhroinnte",
    "Recording consent" : "Toiliú taifeadta",
    "Recording transcription" : "Trascríobh taifeadta",
    "Automatically transcribe call recordings with a transcription provider" : "Trascríobh taifeadtaí glaonna go huathoibríoch le soláthraí trascríobh",
    "Automatically summarize call recordings with transcription and summary providers" : "Déan achoimre uathoibríoch ar thaifeadtaí glaonna le soláthraithe trascríobh agus achoimre",
    "SIP configuration saved!" : "Cumraíocht SIP sábháilte!",
    "SIP configuration is only possible with a High-performance backend." : "Ní féidir cumraíocht SIP a dhéanamh ach amháin le hInneall Ardfheidhmíochta.",
    "Enable SIP Dial-out option" : "Cumasaigh an rogha Dial Amach SIP",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Ní mór an freastalaí comharthaíochta a nuashonrú go dtí an ghné Dial Amach SIP a fhaigheann tacaíocht.",
    "Do not show SIP Dial-out caller number" : "Ná taispeáin uimhir ghlaoiteora SIP Dial-out",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Ba chóir uimhir gan ainm a bheith le feiceáil mar \"anaithnid\" nó \"uimhir faoi cheilt\" chun glaoch ar an bhfaighteoir",
    "Dial-out number" : "Uimhir dhiailiú amach",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Uimhir fhormáidithe E164 a úsáidtear mar uimhir ghlaoiteora taca le haghaidh glaonna amach",
    "Dial-out prefix" : "Réimír dial-amach",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Réimír chuig uimhir úsáideora cumraithe le haghaidh glaonna amach (is é `+` an réamhshocrú)",
    "Restrict SIP configuration" : "Srian a chur ar chumraíocht SIP",
    "Enable SIP configuration" : "Cumasaigh cumraíocht SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Ní féidir ach le húsáideoirí na ngrúpaí seo a leanas SIP a chumasú i gcomhráite a mhodhnóidh siad",
    "Phone number (Country)" : "Uimhir ghutháin (Tír)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Seoltar an fhaisnéis seo i ríomhphoist cuireadh agus taispeántar í sa bharra taoibh chuig gach rannpháirtí.",
    "Nextcloud base URL" : "URL bonn Nextcloud",
    "Talk Backend URL" : "URL Cúil an Chórais Comhrá",
    "WebSocket URL" : "URL WebSocket",
    "Available features" : "Gnéithe atá ar fáil",
    "Error: Websocket connection failed" : "Earráid: Theip ar nasc Websocket",
    "Error code" : "Cód earráide",
    "Error message" : "Teachtaireacht earráide",
    "Error: Websocket connection failed. Check browser console" : "Earráid: Theip ar cheangal Websocket. Seiceáil consól brabhsálaí",
    "High-performance backend URL" : "URL inneall ardfheidhmíochta",
    "Missing High-performance backend warning hidden" : "Rabhadh inneall ardfheidhmíochta ar iarraidh i bhfolach",
    "High-performance backend settings saved" : "Sábháladh socruithe inneall ardfheidhmíochta",
    "Nextcloud Talk setup not complete" : "Níl socrú Nextcloud Talk críochnaithe",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Tabhair faoi deara le do thoil, i nglaonna le níos mó ná 2 rannpháirtí gan an t-Inneall Ardfheidhmíochta, is dóichí go mbeidh fadhbanna nascachta ag rannpháirtithe agus go mbeidh siad ina gcúis le hualach ard ar ghléasanna rannpháirteacha.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Suiteáil an t-Inneall Ardfheidhmíochta chun a chinntiú go n-oibríonn glaonna le rannpháirtithe iolracha gan uaim.",
    "Nextcloud portal" : "Tairseach Nextcloud",
    "Quick installation guide" : "Treoir suiteála tapa",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Tá an t-inneall Ardfheidhmíochta ag teastáil le haghaidh glaonna agus comhráite le rannpháirtithe iolracha. Gan an t-innill, caithfidh na rannpháirtithe go léir a bhfíseán féin a uaslódáil ina n-aonar le haghaidh gach rannpháirtí eile, rud is dócha a bheidh ina chúis le saincheisteanna nascachta agus ualach ard ar ghléasanna rannpháirteacha.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Moltar go mór taisce dáilte a chur ar bun agus Nextcloud Talk ag baint úsáide as inneall ardfheidhmíochta.",
    "Add High-performance backend server" : "Cuir freastalaí inneall Ardfheidhmíochta leis",
    "Warn about connectivity issues in calls with more than 2 participants" : "Tabhair rabhadh faoi cheisteanna nascachta i nglaonna le níos mó ná 2 rannpháirtí",
    "STUN server URL" : "URL an fhreastalaí STUN",
    "The server address is invalid" : "Tá seoladh an fhreastalaí neamhbhailí",
    "STUN settings saved" : "Socruithe STUN sábháilte",
    "STUN servers" : "Freastalaithe STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Úsáidtear freastalaí STUN chun seoladh IP poiblí na rannpháirtithe taobh thiar de ródaire a chinneadh.",
    "Add a new STUN server" : "Cuir freastalaí STUN nua leis",
    "{schema} scheme must be used with a domain" : "Ní mór scéim {schema} a úsáid le fearann",
    "{option1} and {option2}" : "{option1} agus {option2}",
    "{option} only" : "{option} amháin",
    "OK: Successful ICE candidates returned by the TURN server" : "Ceart go leor: Chuir an freastalaí TURN na hiarrthóirí rathúla ICE ar ais",
    "Error: No working ICE candidates returned by the TURN server" : "Earráid: Níor chuir an freastalaí TURN iarrthóirí ICE ar ais",
    "Testing whether the TURN server returns ICE candidates" : "Ag tástáil cibé an dtugann an freastalaí TURN iarrthóirí ICE ar ais",
    "TURN server schemes" : "TURN scéimeanna freastalaí",
    "TURN server URL" : "TURN URL an fhreastalaí",
    "TURN server secret" : "TURN rúnda freastalaí",
    "TURN server protocols" : "TURN prótacail freastalaí",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Úsáidtear freastalaí TURN chun seachfhreastalaí a dhéanamh ar an trácht ó rannpháirtithe taobh thiar de bhalla dóiteáin. Murar féidir le rannpháirtithe aonair nascadh le daoine eile is dócha go mbeidh freastalaí TURN ag teastáil. Féach {linkstart}an doiciméadú seo{linkend} le haghaidh treoracha cumraíochta.",
    "TURN settings saved" : "TURN socruithe sábháilte",
    "TURN servers" : "TURN freastalaithe",
    "Add a new TURN server" : "Cuir freastalaí TURN nua leis",
    "Failed" : "Theip",
    "OK" : "Ceart go leor",
    "Checking …" : "Ag seiceáil…",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Theip: tá WebAssembly díchumasaithe nó ní thacaítear leis sa bhrabhsálaí seo. Cumasaigh WebAssembly le do thoil nó bain úsáid as brabhsálaí a thacaíonn leis chun an tseiceáil a dhéanamh.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Theip: níor chuir an freastalaí gréasáin comhaid \".wasm\" agus \".tflite\" ar ais i gceart. Seiceáil le do thoil an rannán \"Riachtanais chórais\" i gcáipéisíocht Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: chuir an freastalaí gréasáin comhaid \".wasm\" agus \".tflite\" ar ais i gceart.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Dealraíonn sé nach bhfuil cumraíocht PHP agus Apache comhoiriúnach. Tabhair faoi deara nach féidir PHP a úsáid ach leis an modúl MPM_PREFORK agus ní féidir PHP-FPM a úsáid ach leis an modúl MPM_EVENT.",
    "Web server setup checks" : "Seiceálacha socruithe freastalaí gréasáin",
    "Files required for virtual background can be loaded" : "Is féidir comhaid a theastaíonn le haghaidh cúlra fíorúil a luchtú",
    "Federated user" : "Úsáideoir cónaidhme",
    "Assign participants to rooms" : "Rannpháirtithe a shannadh do seomraí",
    "Configure breakout rooms" : "Cumraigh seomraí ar leithligh",
    "Number of breakout rooms" : "Líon na seomraí ar leithligh",
    "You can create from 1 to 20 breakout rooms." : "Is féidir leat idir 1 agus 20 seomra ar leithligh a chruthú.",
    "Assignment method" : "Modh sannta",
    "Automatically assign participants" : "Rannpháirtithe a shannadh go huathoibríoch",
    "Manually assign participants" : "Rannpháirtithe a shannadh de láimh",
    "Allow participants to choose" : "Lig do rannpháirtithe rogha a dhéanamh",
    "Create rooms" : "Cruthaigh seomraí",
    "Confirm" : "Deimhnigh",
    "Create breakout rooms" : "Cruthaigh seomraí ar leithligh",
    "Reset" : "Athshocraigh",
    "Delete breakout rooms" : "Scrios seomraí ar leithligh",
    "Room {roomNumber}" : "Seomra {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Caillfear seomraí ar leithligh agus socruithe reatha",
    "Cancel" : "Cealaigh",
    "Unassigned participants" : "Rannpháirtithe neamhshannta",
    "Back" : "Ar ais",
    "Assign" : "Sann",
    "Add participant \"{user}\"" : "Cuir rannpháirtí \"{user}\" leis",
    "Now" : "Anois",
    "Invalid calendar selected" : "Féilire neamhbhailí roghnaithe",
    "Invalid start time selected" : "Am tosaithe neamhbhailí roghnaithe",
    "Invalid end time selected" : "Am críochnaithe neamhbhailí roghnaithe",
    "Unknown error occurred" : "Tharla earráid anaithnid",
    "Sending no invitations" : "Gan aon chuirí a sheoladh",
    "{participant0} will receive an invitation" : "{participant0} gheobhaidh sé cuireadh",
    "{participant0} and {participant1} will receive invitations" : "Gheobhaidh{participant0} agus {participant1} cuirí",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["Gheobhaidh{participant0}, {participant1} agus %n eile cuirí","Gheobhaidh{participant0}, {participant1} agus %n duine eile cuirí","Gheobhaidh{participant0}, {participant1} agus %n duine eile cuirí","Gheobhaidh{participant0}, {participant1} agus %n duine eile cuirí","Gheobhaidh{participant0}, {participant1} agus %n duine eile cuirí"],
    "Invite {user}" : "Cuireadh {user}",
    "Invite all users and emails in this conversation" : "Tabhair cuireadh do gach úsáideoir agus ríomhphost sa chomhrá seo",
    "Meeting created" : "Cruthaíodh cruinniú",
    "Upcoming meetings" : "Cruinnithe le teacht",
    "No upcoming meetings" : "Gan aon chruinnithe atá le teacht",
    "Schedule a meeting" : "Cruinniú a sceidealú",
    "Meeting title" : "Teideal an chruinnithe",
    "From" : "Ó",
    "To" : "Chun",
    "Calendar" : "Féilire",
    "Attendees" : "Lucht freastail",
    "No other participants to send invitations to." : "Níl aon rannpháirtí eile chun cuirí a sheoladh chucu.",
    "Add attendees" : "Cuir lucht freastail leis",
    "Save" : "Sábháil",
    "Search participants" : "Cuardaigh rannpháirtithe",
    "No results" : "Gan torthaí",
    "Done" : "Déanta",
    "Disable live transcription" : "Díchumasaigh trascríobh beo",
    "Enable live transcription (generated by AI)" : "Cumasaigh trascríobh beo (ginte ag AI)",
    "Enable live transcription (Live transcriptions app is not installed)" : "Cumasaigh trascríobh beo (Níl an aip trascríobh beo suiteáilte)",
    "Disable live translation" : "Díchumasaigh aistriúchán beo",
    "Enable live translation (generated by AI)" : "Cumasaigh aistriúchán beo (ginte ag AI)",
    "Original language" : "Teanga bhunaidh",
    "Live translations app is not installed" : "Níl an aip aistriúcháin bheo suiteáilte",
    "Original language: {languageName}" : "Teanga bhunaidh: {languageName}",
    "Translated language" : "Teanga aistrithe",
    "Translated language: {languageName}" : "Teanga aistrithe: {languageName}",
    "Exit full screen (F)" : "Scoir scáileán iomlán (F)",
    "Full screen (F)" : "Scáileán iomlán (F)",
    "Speaker view" : "Amharc cainteoir",
    "Grid view" : "Radharc greille",
    "Error when trying to load the available live transcription languages" : "Earráid agus iarracht á déanamh na teangacha trascríobh beo atá ar fáil a luchtú",
    "Failed to enable live transcription" : "Theip ar thrascríobh beo a chumasú",
    "Failed to enable live translations" : "Theip ar aistriúcháin bheo a chumasú",
    "Failed to disable live translations" : "Theip ar aistriúcháin bheo a dhíchumasú",
    "Recording consent is required" : "Tá toiliú taifeadta ag teastáil",
    "This conversation is read-only" : "Tá an comhrá seo inléite amháin",
    "Conversation not found or not joined" : "Níor aimsíodh an comhrá nó níor cuireadh isteach ann é",
    "Lobby is still active and you're not a moderator" : "Tá an stocaireacht fós gníomhach agus ní modhnóir tú",
    "Connection failed" : "Theip ar an gceangal",
    "Reload" : "Athlódáil",
    "{nickName} raised their hand." : "D'ardaigh {nickName} a lámh.",
    "A participant raised their hand." : "D'ardaigh rannpháirtí a lámh.",
    "Collapse stripe" : "Laghdaigh stríoc",
    "Expand stripe" : "Leathnaigh stríoc",
    "Previous page of videos" : "An leathanach físeáin roimhe seo",
    "Next page of videos" : "An chéad leathanach eile d'fhíseáin",
    "Connecting …" : "Ag nascadh…",
    "Calling …" : "Ag glaoch…",
    "Waiting for {user} to join the call" : "Ag fanacht le {user} páirt a ghlacadh sa ghlao",
    "Waiting for others to join the call …" : "Ag fanacht le daoine eile a bheith páirteach sa ghlao…",
    "You can invite others in the participant tab of the sidebar" : "Is féidir leat cuireadh a thabhairt do dhaoine eile sa chluaisín rannpháirtí ar an mbarra taoibh",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Is féidir leat cuireadh a thabhairt do dhaoine eile sa chluaisín rannpháirtí ar an mbarra taoibh nó an nasc seo a roinnt chun cuireadh a thabhairt do dhaoine eile!",
    "Share this link to invite others!" : "Roinn an nasc seo le cuireadh a thabhairt do dhaoine eile!",
    "Copy link" : "Cóipeáil an nasc",
    "You are not allowed to enable audio" : "Níl cead agat fuaim a chumasú",
    "No audio. Click to select device" : "Gan fuaim. Cliceáil chun gléas a roghnú",
    "Mute audio" : "Balbhaigh fuaime",
    "Mute audio (M)" : "Balbhaigh an fhuaim (M)",
    "Unmute audio" : "Díbhalbhaigh an fhuaim",
    "Unmute audio (M)" : "Díbhalbhaigh an fhuaim (M)",
    "None" : "aon cheann",
    "Select a microphone" : "Roghnaigh micreafón",
    "Select a speaker" : "Roghnaigh cainteoir",
    "Microphone settings" : "Socruithe micreafóin",
    "Check devices" : "Seiceáil gléasanna",
    "Access to camera was denied" : "Diúltaíodh rochtain ar cheamara",
    "Error while accessing camera: It is likely in use by another program" : "Earráid agus tú ag rochtain ceamara: Is dócha go mbeidh sé in úsáid ag ríomhchlár eile",
    "Error while accessing camera" : "Earráid agus an ceamara á rochtain",
    "You have been muted by a moderator" : "Tá modhnóir balbhaithe thú",
    "Hide presenter video" : "Folaigh físeán an láithreoir",
    "You are not allowed to enable video" : "Níl cead agat físeáin a chumasú",
    "No video. Click to select device" : "Gan físeán. Cliceáil chun gléas a roghnú",
    "Disable video" : "Físeán a dhíchumasú",
    "Disable video (V)" : "Díchumasaigh an físeán (V)",
    "Enable video" : "Cumasaigh físeán",
    "Enable video (V)" : "Cumasaigh físeán (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Cumasaigh físeán - Cuirfear isteach go hachomair ar do nasc agus an físeán á chumasú den chéad uair",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Cumasaigh físeán (V) - Cuirfear isteach go hachomair ar do nasc agus an físeán á chumasú den chéad uair",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Cumasaigh físeán. Cuirfear isteach ar do nasc go hachomair agus an físeán á chumasú den chéad uair",
    "Select a video device" : "Roghnaigh gléas físe",
    "Show presenter" : "Taispeáin láithreoir",
    "You" : "tu",
    "Mute" : "Balbhaigh",
    "Muted" : "Balbhaithe",
    "Show screen" : "Taispeáin scáileán",
    "Stop following" : "Stop ag leanúint",
    "Connection could not be established …" : "Níorbh fhéidir ceangal a bhunú…",
    "Connection was lost and could not be re-established …" : "Cailleadh an nasc agus níorbh fhéidir é a athbhunú …",
    "Connection could not be established. Trying again …" : "Níorbh fhéidir ceangal a bhunú. Ag iarraidh arís…",
    "Connection lost. Trying to reconnect …" : "Ceangal caillte. Ag iarraidh athcheangail…",
    "Connection problems …" : "Fadhbanna ceangail…",
    "Collapse" : "Laghdaigh",
    "Expand" : "Leathnaigh",
    "You need to be logged in to upload files" : "Ní mór duit a bheith logáilte isteach chun comhaid a uaslódáil",
    "Drop your files to upload" : "Scaoil do chuid comhad le huaslódáil",
    "Conversation messages" : "Teachtaireachtaí comhrá",
    "Scroll to bottom" : "Scrollaigh go bun",
    "Post message" : "Teachtaireacht a phostáil",
    "Federated conversation" : "Comhrá cónaidhme",
    "Public conversation" : "Comhrá poiblí",
    "Favorite" : "is fearr leat",
    "Banned users" : "Úsáideoirí toirmiscthe",
    "Manage the list of banned users in this conversation." : "Bainistigh liosta na n-úsáideoirí toirmiscthe sa chomhrá seo.",
    "Manage bans" : "Bainistigh toirmisc",
    "No banned users" : "Uimh úsáideoirí toirmeasc",
    "Banned by:" : "Toirmiscthe ag:",
    "Date:" : "Dáta:",
    "Note:" : "Nóta:",
    "Hide details" : "Folaigh sonraí",
    "Show details" : "Sonraí a thaispeáint",
    "Unban" : "Dícosc",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Is féidir leat an teideal agus an cur síos a athrú i {linkstart}Féilire ↗{linkend}.",
    "Error while updating conversation name" : "Earráid agus ainm an chomhrá á nuashonrú",
    "Error while updating conversation description" : "Earráid agus cur síos an chomhrá á nuashonrú",
    "Enter a name for this conversation" : "Cuir isteach ainm don chomhrá seo",
    "Edit conversation name" : "Cuir ainm an chomhrá in eagar",
    "Edit conversation description" : "Cuir cur síos ar an gcomhrá in eagar",
    "Enter a description for this conversation" : "Cuir isteach cur síos ar an gcomhrá seo",
    "Picture" : "Pictiúr",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Is féidir na róbónna seo a leanas a chumasú sa chomhrá seo. Déan teagmháil le do riarachán chun tuilleadh róbónna a shuiteáil ar an bhfreastalaí seo.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Níl aon róbónna suiteáilte ar an bhfreastalaí seo. Déan teagmháil le do riarachán chun róbónna a shuiteáil ar an bhfreastalaí seo.",
    "Disable" : "Díchumasaigh",
    "Enable" : "Cumasaigh",
    "The bot is not available anymore" : "Níl an bot ar fáil a thuilleadh",
    "Breakout rooms" : "Seomraí ar leithligh",
    "Manage breakout rooms" : "Bainistigh seomraí ar leithligh",
    "Set up breakout rooms for this conversation" : "Socraigh seomraí ar leithligh don chomhrá seo",
    "Please select a valid PNG or JPG file" : "Roghnaigh comhad bailí PNG nó JPG le do thoil",
    "Choose your conversation picture" : "Roghnaigh do phictiúr comhrá",
    "Choose" : "Roghnaigh",
    "Error setting conversation picture" : "Earráid agus pictiúr an chomhrá á shocrú",
    "Could not set the conversation picture: {error}" : "Níorbh fhéidir pictiúr an chomhrá a shocrú: {error}",
    "Error cropping conversation picture" : "Earráid agus pictiúr an chomhrá á bhearradh",
    "Error removing conversation picture" : "Earráid agus an pictiúr comhrá á bhaint",
    "Set emoji as conversation picture" : "Socraigh emoji mar phictiúr comhrá",
    "Set background color for conversation picture" : "Socraigh dath cúlra le haghaidh pictiúr comhrá",
    "Upload conversation picture" : "Íosluchtaigh pictiúr comhráite",
    "Choose conversation picture from files" : "Roghnaigh pictiúr comhrá ó chomhaid",
    "Remove conversation picture" : "Bain pictiúr an chomhrá",
    "The file must be a PNG or JPG" : "Caithfidh an comhad a bheith ina PNG nó JPG",
    "Set picture" : "Socraigh pictiúr",
    "Default permissions modified for {conversationName}" : "Athraíodh na ceadanna réamhshocraithe le haghaidh {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Níorbh fhéidir na ceadanna réamhshocraithe do {conversationName} a mhionathrú",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Cuir na ceadanna réamhshocraithe do rannpháirtithe sa chomhrá seo in eagar. Ní chuireann na socruithe seo isteach ar mhodhnóirí.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Gach uair a athraítear ceadanna sa chuid seo, caillfear ceadanna saincheaptha a tugadh do rannpháirtithe aonair roimhe seo.",
    "All permissions" : "Gach cead",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Tá cead ag rannpháirtithe glao a thosú, páirt a ghlacadh i nglao, fuaim agus físeáin a chumasú, agus scáileán a roinnt.",
    "Participants can use all available features." : "Is féidir le rannpháirtithe gach gné atá ar fáil a úsáid.",
    "Restricted" : "Srianta",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Is féidir le rannpháirtithe páirt a ghlacadh i nglaonna, ach ní féidir leo fuaime ná físe a chumasú ná scáileán a chomhroinnt go dtí go dtugann modhnóir ceadanna de láimh dóibh.",
    "Participants get a reduced feature set until a moderator manually grants additional permissions." : "Gheobhaidh rannpháirtithe sraith gnéithe laghdaithe go dtí go dtabharfaidh modhnóir ceadanna breise de láimh.",
    "Advanced permissions" : "Ceadanna chun cinn",
    "Edit permissions" : "Cuir ceadanna in eagar",
    "Conversation settings" : "Socruithe comhrá",
    "Basic Info" : "Eolas Bunúsach",
    "Personal" : "Pearsanta",
    "Moderation" : "Measarthacht",
    "Setup overview" : "Forbhreathnú ar an socrú",
    "Live transcription" : "Tras-scríobh beo",
    "Live transcriptions app is not installed" : "Níl an aip trascríbhinní beo suiteáilte",
    "Enable live transcription" : "Cumasaigh trascríobh beo",
    "Breakout Rooms" : "Seomraí ar leithligh",
    "Matterbridge" : "Droichead an Mhatha",
    "Bots" : "Róbónna",
    "Danger zone" : "Crios contúirte",
    "Archive conversation" : "Comhrá cartlainne",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Tá comhráite cartlainne folaithe ón liosta comhráite de réir réamhshocraithe. Mar sin féin, beidh siad fós le feiceáil nuair a chuardaíonn tú ainm an chomhrá nó nuair a gheobhaidh tú rochtain ar liosta de chomhráite cartlainne.",
    "Do you really want to leave \"{displayName}\"?" : "An bhfuil tú cinnte gur mhaith leat \"{displayName}\" a fhágáil?",
    "You can archive this conversation instead." : "Is féidir leat an comhrá seo a chur i gcartlann ina ionad sin.",
    "Leave conversation" : "Fág an comhrá",
    "You need to promote a new moderator before you can leave the conversation" : "Ní mór duit modhnóir nua a chur chun cinn sula bhféadfaidh tú an comhrá a fhágáil",
    "Delete conversation" : "Scrios an comhrá",
    "Do you really want to delete \"{displayName}\"?" : "An bhfuil tú cinnte gur mhaith leat \"{displayName}\" a scriosadh?",
    "Error while deleting conversation" : "Earráid agus an comhrá á scriosadh",
    "Delete all chat messages" : "Scrios gach teachtaireacht comhrá",
    "Do you really want to delete all messages in \"{displayName}\"?" : "An bhfuil tú cinnte gur mhaith leat gach teachtaireacht i \"{displayName}\" a scriosadh?",
    "Error while clearing chat history" : "Earráid agus stair comhrá á glanadh",
    "Be careful, these actions cannot be undone." : "Bí cúramach, ní féidir na gníomhartha seo a chealú.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Nuair atá comhrá fágtha, chun páirt a ghlacadh arís i gcomhrá dúnta, tá cuireadh ag teastáil. Is féidir páirt a ghlacadh arís i gcomhrá oscailte am ar bith.",
    "Permanently delete this conversation." : "Scrios an comhrá seo go buan.",
    "Delete chat messages" : "Scrios teachtaireachtaí comhrá",
    "Permanently delete all the messages in this conversation." : "Scrios go buan gach teachtaireacht sa chomhrá seo.",
    "Custom expiration time" : "Am éaga saincheaptha",
    "Message expiration disabled" : "Díchumasaíodh dul in éag na teachtaireachta",
    "Message expiration set: {duration}" : "Socraigh dul in éag na teachtaireachta: {duration}",
    "Error when trying to set message expiration" : "Earráid agus iarracht á dhéanamh dul in éag na teachtaireachta a shocrú",
    "Message expiration" : "Teachtaireacht in éag",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Is féidir teachtaireachtaí comhrá a bheith imithe in éag tar éis am áirithe. Nóta: Ní scriosfar comhaid a roinntear sa chomhrá don úinéir, ach ní roinnfear iad sa chomhrá a thuilleadh.",
    "Set message expiration" : "Socraigh éag na teachtaireachta",
    "Current message expiration" : "Tá an teachtaireacht reatha imithe in éag",
    "Password copied to clipboard" : "Cóipeáladh an pasfhocal chuig an ngearrthaisce",
    "Password could not be copied" : "Níorbh fhéidir an pasfhocal a chóipeáil",
    "Guest access" : "Rochtain aoi",
    "Breakout rooms are not allowed in public conversations." : "Ní cheadaítear seomraí ar leithligh i gcomhráite poiblí.",
    "Allow guests to join this conversation via link" : "Lig d'aíonna páirt a ghlacadh sa chomhrá seo trí nasc",
    "Password protection" : "Cosaint pasfhocal",
    "This conversation is password-protected. Guests need password to join" : "Tá an comhrá seo cosanta ag pasfhocal. Teastaíonn pasfhocal ó aíonna le bheith páirteach",
    "Password protection is needed for public conversations" : "Tá cosaint pasfhocail ag teastáil le haghaidh comhráite poiblí",
    "Set a password" : "Socraigh focal faire",
    "Change password" : "Athraigh do phasfhocal",
    "Enter new password" : "Cuir isteach pasfhocal nua",
    "Save password" : "Sábháil pasfhocal",
    "Copy password" : "Cóipeáil pasfhocal",
    "Guests are allowed to join this conversation via link" : "Tá cead ag aíonna páirt a ghlacadh sa chomhrá seo trí nasc",
    "Guests are not allowed to join this conversation" : "Níl cead ag aíonna páirt a ghlacadh sa chomhrá seo",
    "Resend invitations" : "Cuir cuirí ar ais",
    "This conversation is open to both registered users and users created with the Guests app" : "Tá an comhrá seo oscailte d’úsáideoirí cláraithe agus d’úsáideoirí a cruthaíodh leis an aip Aíonna",
    "This conversation is open to registered users" : "Tá an comhrá seo oscailte d'úsáideoirí cláraithe",
    "This conversation is limited to the current participants" : "Tá an comhrá seo teoranta do na rannpháirtithe reatha",
    "You opened the conversation to both registered users and users created with the Guests app" : "D’oscail tú an comhrá d’úsáideoirí cláraithe agus d’úsáideoirí a cruthaíodh leis an aip Aíonna",
    "Error occurred when opening or limiting the conversation" : "Tharla earráid agus an comhrá á oscailt nó á theorannú",
    "Open conversation to registered users, showing it in search results" : "Oscail an comhrá d'úsáideoirí cláraithe, agus é á thaispeáint i dtorthaí cuardaigh",
    "Also open to users created with the Guests app" : "Ar oscailt freisin d'úsáideoirí a cruthaíodh leis an aip Aíonna",
    "Open conversation" : "Oscail comhrá",
    "Set language spoken in calls" : "Socraigh an teanga a labhraítear i nglaonna",
    "Languages could not be loaded" : "Níorbh fhéidir teangacha a luchtú",
    "Loading languages …" : "Teangacha á lódáil …",
    "Invalid language" : "Teanga neamhbhailí",
    "Default language (English)" : "Teanga réamhshocraithe (Béarla)",
    "Default live transcription language set" : "Socrú teanga réamhshocraithe trascríobh beo",
    "Live transcription language set: {languageName}" : "Tacar teanga trascríobh beo: {languageName}",
    "Error when trying to set live transcription language" : "Earráid agus iarracht á déanamh teanga trascríobh beo a shocrú",
    "Start time: {date}" : "Am tosaithe: {date}",
    "Start time has been updated" : "Nuashonraíodh an t-am tosaithe",
    "Error occurred while updating start time" : "Tharla earráid agus an t-am tosaithe á nuashonrú",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Má dhéantar an brústocaireacht a chumasú, bainfear daoine nach modhnóirí iad den ghlao leanúnach.",
    "Enable lobby, restricting the conversation to moderators" : "Cumasaigh stocaireacht, ag srianadh an chomhrá do mhodhnóirí",
    "Meeting start time" : "Am tosaithe cruinnithe",
    "Start time (optional)" : "Am tosaithe (roghnach)",
    "Import email participants" : "Iompórtáil rannpháirtithe ríomhphoist",
    "You can import a list of email participants from a CSV file." : "Is féidir leat liosta rannpháirtithe ríomhphoist a allmhairiú ó chomhad CSV.",
    "Poll drafts" : "Dréachtanna vótaíochta",
    "Browse poll drafts" : "Brabhsáil dréachtaí vótaíochta",
    "Error occurred when locking the conversation" : "Tharla earráid agus an comhrá á ghlasáil",
    "Error occurred when unlocking the conversation" : "Tharla earráid agus an comhrá á dhíghlasáil",
    "Lock conversation" : "Cuir glas ar an gcomhrá",
    "This will also terminate the ongoing call." : "Cuirfidh sé seo deireadh leis an nglao leanúnach freisin.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Cuir glas ar an gcomhrá chun cosc ​​a chur ar aon duine teachtaireachtaí a phostáil nó glaonna a thosú",
    "Edit" : "Cuir in eagar",
    "More information" : "Tuilleadh eolais",
    "Delete" : "Scrios",
    "Add new bridged channel to current conversation" : "Cuir cainéal nua droichid leis an gcomhrá reatha",
    "unknown state" : "Stát anaithnid",
    "running" : "Ag rith",
    "not running, check Matterbridge log" : "Nach bhfuil ag rith, seiceáil logáil Matterbridge",
    "not running" : "Gan rith",
    "Bridge saved" : "Droichead shábháil",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Is féidir leat cainéil ó chórais teachtaireachtaí meandracha éagsúla a dhroicheadú le Matterbridge.",
    "More info on Matterbridge" : "Tuilleadh eolais ar Matterbridge",
    "Messaging systems" : "Córais teachtaireachta",
    "Enable bridge" : "Cumasaigh droichead",
    "Show Matterbridge log" : "Taispeáin loga Matterbridge",
    "Log content" : "Ábhar logála",
    "Only moderators are allowed to mention @all" : "Ní cheadaítear ach do mhodhnóirí @all a lua",
    "All participants are allowed to mention @all" : "Tá cead ag gach rannpháirtí @all a lua",
    "Participants are now allowed to mention @all." : "Tá cead anois ag rannpháirtithe @all a lua.",
    "Mentioning @all has been limited to moderators." : "Tá tagairt do @all teoranta do mhodhnóirí.",
    "Allow participants to mention @all" : "Lig do rannpháirtithe @all a lua",
    "Mention permissions" : "Luaigh ceadanna",
    "Notifications" : "Fógraí",
    "Notify about calls in this conversation" : "Cuir glaonna ar an eolas sa chomhrá seo",
    "Important conversation" : "Comhrá tábhachtach",
    "\"Do not disturb\" user status is ignored for important conversations" : "Déantar neamhaird ar stádas an úsáideora \"Ná cuir isteach\" i gcás comhráite tábhachtacha",
    "Sensitive conversation" : "Comhrá íogair",
    "Message preview will be disabled in conversation list and notifications" : "Díchumasófar réamhamharc teachtaireachta sa liosta comhráite agus sna fógraí",
    "Recording consent is required for calls in this conversation" : "Tá toiliú taifeadta ag teastáil le haghaidh glaonna sa chomhrá seo",
    "Recording consent is not required for calls in this conversation" : "Níl toiliú taifeadta ag teastáil le haghaidh glaonna sa chomhrá seo",
    "Recording consent requirement was updated" : "Nuashonraíodh an riachtanas um thoiliú taifeadta",
    "Error occurred while updating recording consent" : "Tharla earráid agus an toiliú taifeadta á nuashonrú",
    "Recording Consent" : "Toiliú Taifeadta",
    "Recording consent cannot be changed once a call or breakout session has started." : "Ní féidir toiliú taifeadta a athrú nuair a bheidh glao nó seisiún ar leithligh tosaithe.",
    "Require recording consent before joining call in this conversation" : "Teastaíonn toiliú taifeadta sula nglacann tú páirt sa ghlao seo",
    "Recording consent is required for all calls" : "Tá toiliú taifeadta ag teastáil le haghaidh gach glao",
    "SIP dial-in is now possible without PIN requirement" : "Is féidir SIP a dhiailiú isteach anois gan riachtanas PIN",
    "SIP dial-in is now enabled" : "Tá diail isteach SIP cumasaithe anois",
    "SIP dial-in is now disabled" : "Tá an dhiailiú isteach SIP díchumasaithe anois",
    "Error occurred when enabling SIP dial-in" : "Tharla earráid agus an diail-isteach SIP á chumasú",
    "Error occurred when disabling SIP dial-in" : "Tharla earráid agus an dhiailiú isteach SIP á dhíchumasú",
    "Phone and SIP dial-in" : "Fón agus SIP dhiailiú-i",
    "Enable phone and SIP dial-in" : "Cumasaigh guthán agus SIP diailithe",
    "Allow to dial-in without a PIN" : "Ceadaigh diailiú isteach gan UAP",
    "Ongoing" : "Ar siúl",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n duine glactha","%n duine glactha","%n duine glactha","%n duine glactha","%n duine glactha"],
    "_%n person declined_::_%n people declined_" : ["Dhiúltaigh %n duine","Dhiúltaigh %n duine","Dhiúltaigh %n duine","Dhiúltaigh %n duine","Dhiúltaigh %n duine"],
    "_and %n other attachment_::_and %n other attachments_" : ["agus %n ceangaltán eile","agus %n ceangaltán eile","agus %n ceangaltán eile","agus %n ceangaltán eile","agus %n ceangaltán eile"],
    "With {displayName}" : "Le {displayName}",
    "In {conversation}" : "I {conversation}",
    "View attachment" : "Féach ar an gceangaltán",
    "Join" : "Glac páirt",
    "View conversation" : "Féach ar an gcomhrá",
    "View event on Calendar" : "Féach ar an imeacht ar an bhFéilire",
    "Error while creating the conversation" : "Earráid agus an comhrá á chruthú",
    "Hello, {displayName}" : "Haigh, {displayName}",
    "Start meeting now" : "Tosaigh ag cruinniú anois",
    "Give your meeting a title" : "Tabhair teideal do do chruinniú",
    "Create and copy link" : "Cruthaigh agus cóipeáil nasc",
    "Create a new conversation" : "Cruthaigh comhrá nua",
    "Join open conversations" : "Glac páirt i gcomhráite oscailte",
    "Call a phone number" : "Cuir glaoch ar uimhir theileafóin",
    "Scroll backward" : "Scrollaigh siar",
    "Scroll forward" : "Scrollaigh ar aghaidh",
    "Schedule meetings" : "Sceideal cruinnithe",
    "You don't have any upcoming meetings" : "Níl aon chruinnithe atá le teacht agat",
    "Calendar events with a conversation link as the location are shown here" : "Taispeántar imeachtaí féilire le nasc comhrá mar shuíomh anseo",
    "Open calendar" : "Oscail an féilire",
    "Unread mentions" : "Luaite gan léamh",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Beidh teachtaireachtaí inar luadh thú le feiceáil anseo. Is féidir leat daoine a lua trí @ a chlóscríobh agus a n-ainm ina dhiaidh sin",
    "Upcoming reminders" : "Meabhrúcháin atá le teacht",
    "Message reminders" : "Meabhrúcháin teachtaireachtaí",
    "Set a reminder on a message to be notified" : "Socraigh meabhrúchán ar theachtaireacht le fógra a fháil",
    "Start a group conversation" : "Cuir tús le comhrá grúpa",
    "Create conversation" : "Cruthaigh comhrá",
    "Enter your name" : "Cuir isteach d'ainm",
    "Submit name and join" : "Cuir isteach ainm agus páirt a ghlacadh",
    "Do you already have an account?" : "An bhfuil cuntas agat cheana féin?",
    "Log in" : "Logáil isteach",
    "Error while verifying uploaded file" : "Earráid agus an comhad uaslódáilte á fhíorú",
    "Uploaded file is verified" : "Tá an comhad uaslódáilte fíoraithe",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Is éard atá i bhformáid ábhair ná luachanna camógdheighilte (CSV):<br/>- Tá líne ceanntásca ag teastáil agus ní mór <samp>\"ainm\",\"ríomhphost\"</samp> nó díreach <samp>\"ríomhphost\"</samp><br/>- Iontráil amháin in aghaidh an líne a mheaitseáil (m.sh. <samp>\"John Doe\",\"john@example.tld\"</samp>)",
    "Participants added successfully" : "D'éirigh leis na rannpháirtithe a chur leis",
    "Error while adding participants" : "Earráid agus rannpháirtithe á gcur leis",
    "Import a file" : "Iompórtáil comhad",
    "Browse" : "Brabhsáil",
    "Verifying uploaded file …" : "Comhad uaslódáilte á fhíorú…",
    "This might take a moment" : "Seans go dtógfaidh sé seo nóiméad",
    "Send invitations" : "Seol cuirí",
    "_%n invalid email_::_%n invalid emails_" : ["%n ríomhphost neamhbhailí","%n ríomhphost neamhbhailí","%n ríomhphost neamhbhailí","%n ríomhphost neamhbhailí","%n ríomhphost neamhbhailí"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["Tá %n ríomhphost iompórtáilte cheana nó ina dhúblach","Tá %n ríomhphost iompórtáilte nó dúblach cheana","Tá %n ríomhphost iompórtáilte nó dúblach cheana","Tá %n ríomhphost iompórtáilte nó dúblach cheana","Tá %n ríomhphost iompórtáilte nó dúblach cheana"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["Is féidir %n cuireadh a sheoladh","Is féidir %n cuireadh a sheoladh","Is féidir %n cuireadh a sheoladh","Is féidir %n cuireadh a sheoladh","Is féidir %n cuireadh a sheoladh"],
    "An error occurred while calling a phone number" : "Tharla earráid agus glaoch ar uimhir theileafóin",
    "Phone number could not be called: {error}" : "Níorbh fhéidir uimhir theileafóin a ghlaoch: {error}",
    "Phone number could not be called" : "Níorbh fhéidir uimhir theileafóin a ghlaoch",
    "Search participants or phone numbers" : "Cuardaigh rannpháirtithe nó uimhreacha gutháin",
    "Creating the conversation …" : "Ag cruthú an chomhrá…",
    "Mark as read" : "Marcáil mar léite",
    "Mark as unread" : "Marcáil mar neamhléite",
    "Remove from favorites" : "Bain ó cheanáin",
    "Add to favorites" : "Cuir le ceanáin",
    "Unarchive conversation" : "Comhrá gan chartlann",
    "Ignore \"Do not disturb\"" : "Déan neamhaird de \"Ná cuir isteach\"",
    "You need to promote a new moderator before you can leave the conversation." : "Ní mór duit modhnóir nua a chur chun cinn sula bhféadfaidh tú an comhrá a fhágáil.",
    "New tag" : "Clib nua",
    "Tag name" : "Ainm chlib",
    "Conversation actions" : "Gníomhartha comhrá",
    "Tags" : "Clibeanna",
    "Notify about calls" : "Fógra a thabhairt faoi ghlaonna",
    "Hide message text" : "Folaigh téacs an teachtaireachta",
    "Remove all tags" : "Bain na clibeanna go léir",
    "Rename tag" : "Athainmnigh an clib",
    "Delete tag" : "Scrios clib",
    "Do you really want to delete \"{name}\"? Conversations with this tag will be moved to \"Other\"." : "An bhfuil tú cinnte gur mhaith leat \"{name}\" a scriosadh? Bogfar comhráite leis an gclib seo go \"Eile\".",
    "Move up" : "Éirí suas",
    "Move down" : "Bog síos",
    "Pending invitations" : "Cuirí ar feitheamh",
    "Join conversations from other servers" : "Glac páirt i gcomhráite ó fhreastalaithe eile",
    "From {user} at {remoteServer}" : "Ó {user} ag {remoteServer}",
    "Decline invitation" : "Diúltaigh cuireadh",
    "Accept invitation" : "Glac le cuireadh",
    "No pending invitations" : "Níl aon chuirí ar feitheamh",
    "Home" : "Baile",
    "Unread" : "Neamhléite",
    "Mentions" : "Luann",
    "Meetings" : "Cruinnithe",
    "Sort conversations" : "Sórtáil comhráite",
    "By recent activity" : "De réir gníomhaíochta le déanaí",
    "Alphabetically" : "In ord aibítre",
    "Do not group by type" : "Ná grúpáil de réir cineáil",
    "Show private ones first" : "Taispeáin cinn phríobháideacha ar dtús",
    "Show group ones first" : "Taispeáin cinn na ngrúpaí ar dtús",
    "No followed threads" : "Gan aon snáitheanna le leanúint",
    "No matches found" : "Níor aimsíodh aon mheaitseáil",
    "No conversations found" : "Níor aimsíodh aon chomhrá",
    "You have no archived conversations." : "Níl aon chomhráite sa chartlann agat.",
    "Subscribe to an existing thread or start your own." : "Liostáil le snáithe atá ann cheana féin nó tosaigh do cheann féin.",
    "You have no unread mentions." : "Níl aon tagairtí neamhléite agat.",
    "You have no unread messages." : "Níl aon teachtaireachtaí neamhléite agat.",
    "An error occurred while performing the search" : "Tharla earráid agus an cuardach á dhéanamh",
    "Conversation list" : "Liosta comhráite",
    "Filter conversations by" : "Scag comhráite de réir",
    "Unread messages" : "Teachtaireachtaí gan léamh",
    "Meeting conversations" : "Comhráite cruinnithe",
    "Clear filters" : "Glan na scagairí",
    "New personal note" : "Nóta pearsanta nua",
    "SIP backend is not installed" : "Níl an cúltaca SIP suiteáilte",
    "Back to conversations" : "Ar ais chuig comhráite",
    "Threads" : "Snáitheanna",
    "Archived conversations" : "Comhráite cartlainne",
    "Clear filter" : "Glan an scagaire",
    "Show more threads" : "Taispeáin níos mó snáitheanna",
    "App settings" : "Socruithe aip",
    "Users" : "Úsáideoirí",
    "Groups" : "Grúpaí",
    "Teams" : "Foirne",
    "Federated users" : "Úsáideoirí Cónaidhme",
    "New private conversation" : "Comhrá príobháideach nua",
    "Other sources" : "Foinsí eile",
    "Open conversations" : "Oscail comhráite",
    "No search results" : "Gan torthaí cuardaigh",
    "Users, groups and teams" : "Úsáideoirí, grúpaí agus foirne",
    "Users and groups" : "Úsáideoirí agus grúpaí",
    "Users and teams" : "Úsáideoirí agus foirne",
    "Groups and teams" : "Grúpaí agus foirne",
    "New group conversation" : "Comhrá grúpa nua",
    "The meeting will start soon" : "Cuirfear tús leis an gcruinniú go luath",
    "This meeting is scheduled for {startTime}" : "Tá an cruinniú seo sceidealaithe le haghaidh {startTime}",
    "You are currently waiting in the lobby" : "Tá tú ag fanacht sa stocaireacht faoi láthair",
    "Enable noise suppression" : "Cumasaigh cosc ​​torainn",
    "Reduce background noises for better voice quality" : "Laghdaigh torann cúlra le haghaidh caighdeán gutha níos fearr",
    "Basic" : "Bunúsach",
    "Advanced" : "Casta",
    "Enable echo cancellation" : "Cumasaigh cealú macalla",
    "Minimize echo effect from own surrounding" : "Íoslaghdaigh éifeacht macalla ón timpeallacht féin",
    "Enable auto gain control" : "Cumasaigh rialú uathoibríoch gnóthachain",
    "Dynamically adjust microphone volume for consistent level" : "Coigeartaigh toirt an mhicreafóin go dinimiciúil le haghaidh leibhéal comhsheasmhach",
    "Select microphone" : "Roghnaigh micreafón",
    "No microphone available" : "Níl micreafón ar fáil",
    "Select speaker" : "Roghnaigh cainteoir",
    "No speaker available" : "Níl aon chainteoir ar fáil",
    "Select camera" : "Roghnaigh ceamara",
    "No camera available" : "Níl ceamara ar fáil",
    "Select a device" : "Roghnaigh gléas",
    "Playing …" : "Ag imirt…",
    "Test speakers" : "Cainteoirí tástála",
    "Test" : "Scrúdú",
    "Devices" : "Gléasanna",
    "Backgrounds" : "Cúlra",
    "No audio" : "Gan fuaim",
    "No camera" : "Gan ceamara",
    "Display video as you will see it (mirrored)" : "Taispeáin físeán mar a fheicfidh tú é (scáthánaithe)",
    "Display video as others will see it" : "Taispeáin físeán mar a fheicfidh daoine eile é",
    "Calls are not supported in your browser" : "Ní thacaítear le glaonna i do bhrabhsálaí",
    "Access to microphone is only possible with HTTPS" : "Ní féidir rochtain ar mhicreafón ach amháin le HTTPS",
    "Access to microphone was denied" : "Diúltaíodh rochtain ar mhicreafón",
    "Error while accessing microphone" : "Earráid agus an micreafón á rochtain",
    "Access to camera is only possible with HTTPS" : "Ní féidir rochtain ar cheamara ach amháin le HTTPS",
    "The call is being recorded." : "Tá an glao á thaifeadadh.",
    "The call might be recorded." : "Seans go ndéanfar an glao a thaifeadadh.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Seans go gcuimseodh an taifeadadh do ghuth, físeáin ó cheamara, agus comhroinnt scáileáin. Tá do thoiliú ag teastáil sula nglacann tú páirt sa ghlao.",
    "Give consent to the recording of this call" : "Toiliú le taifeadadh an ghlao seo",
    "You can only join a voice room via a call." : "Ní féidir leat dul isteach i seomra gutha ach trí ghlao.",
    "Show more info" : "Taispeáin tuilleadh eolais",
    "Audio is not available" : "Níl fuaim ar fáil",
    "Video is not available" : "Níl físeán ar fáil",
    "Start recording immediately with the call" : "Tosaigh ag taifeadadh láithreach leis an nglao",
    "Recording backend is not installed" : "Níl an chúltaca taifeadta suiteáilte",
    "Notify all participants about this call" : "Cuir na rannpháirtithe uile ar an eolas faoin nglao seo",
    "Apply settings" : "Cuir socruithe i bhfeidhm",
    "Select virtual office background" : "Roghnaigh cúlra oifige fíorúil",
    "Select virtual home background" : "Roghnaigh cúlra baile fíorúil",
    "Select virtual abstract background" : "Roghnaigh cúlra teibí fíorúil",
    "Select virtual beach background" : "Roghnaigh cúlra trá fíorúil",
    "Select virtual park background" : "Roghnaigh cúlra páirce fíorúil",
    "Select virtual theater background" : "Roghnaigh cúlra amharclainne fíorúil",
    "Select virtual library background" : "Roghnaigh cúlra leabharlainne fíorúil",
    "Select virtual space station background" : "Roghnaigh cúlra stáisiún spáis fíorúil",
    "Error while uploading the file" : "Earráid agus an comhad á uaslódáil",
    "Select a file" : "Roghnaigh comhad",
    "Invalid path selected" : "Conair neamhbhailí roghnaithe",
    "Select virtual background from file {fileName}" : "Roghnaigh cúlra fíorúil ó chomhad {fileName}",
    "Blur" : "Doiléirigh",
    "Upload" : "Uaslódáil",
    "Files" : "Comhaid",
    "(editing)" : "(eagarthóireacht)",
    "(edited)" : "(in eagar)",
    "The message has expired or has been deleted" : "Tá an teachtaireacht imithe in éag nó scriosta",
    "Cancel quote" : "Cealaigh an luachan",
    "24 hours" : "24 huaire",
    "7 days" : "7 lá",
    "30 days" : "30 lá",
    "Until unpin" : "Go dtí go ndíphionálfar",
    "Clear reminder – {timeLocale}" : "Glan meabhrúchán - {timeLocale}",
    "Edited by {actor}" : "Arna chur in eagar ag {actor}",
    "Pinned by you" : "Bioránta agatsa",
    "Pinned by {actor}" : "Bioránta ag {actor}",
    "Until {absoluteDate}" : "Go dtí {absoluteDate}",
    "Message text copied to clipboard" : "Cóipeáladh téacs na teachtaireachta chuig an ngearrthaisce",
    "Message text could not be copied" : "Níorbh fhéidir téacs na teachtaireachta a chóipeáil",
    "Message forwarded to \"Note to self\"" : "Cuireadh an teachtaireacht ar aghaidh chuig \"Nóta duit féin\"",
    "Error while forwarding message to \"Note to self\"" : "Earráid agus teachtaireacht á cur ar aghaidh chuig \"Nóta duit féin\"",
    "A reminder was successfully removed" : "Baineadh meabhrúchán go rathúil",
    "Error occurred when removing a reminder" : "Tharla earráid agus meabhrúchán á bhaint",
    "A reminder was successfully set at {datetime}" : "Socraíodh meabhrúchán ag {datetime}",
    "Error occurred when creating a reminder" : "Tharla earráid agus meabhrúchán á chruthú",
    "Add a reaction to this message" : "Cuir imoibriú leis an teachtaireacht seo",
    "Reply" : "Freagra",
    "More actions" : "Tuilleadh gníomhartha",
    "Set reminder" : "Socraigh meabhrúchán",
    "Pin message" : "Teachtaireacht bioráin",
    "Unpin message" : "Bain teachtaireacht den bhiorán ",
    "Reply privately" : "Freagair go príobháideach",
    "Edit message" : "Cuir teachtaireacht in eagar",
    "Copy message" : "Cóipeáil teachtaireacht",
    "Copy message link" : "Cóipeáil nasc na teachtaireachta",
    "Go to file" : "Téigh go dtí an comhad",
    "Download file" : "Íoslódáil an comhad",
    "Go to thread" : "Téigh go dtí an snáithe",
    "Edit thread details" : "Cuir sonraí an snáithe in eagar",
    "Forward message" : "Teachtaireacht ar aghaidh",
    "Translate" : "Aistrigh",
    "Set custom reminder" : "Socraigh meabhrúchán saincheaptha",
    "Keep pinned for" : "Coinnigh bioránta le haghaidh",
    "Set custom period" : "Socraigh tréimhse saincheaptha",
    "Close reactions menu" : "Dún an roghchlár imoibrithe",
    "React with {emoji}" : "Freagair le {emoji}",
    "React with another emoji" : "Freagair le emoji eile",
    "Choose a conversation to forward the selected message." : "Roghnaigh comhrá chun an teachtaireacht roghnaithe a chur ar aghaidh.",
    "Error while forwarding message" : "Earráid agus an teachtaireacht á cur ar aghaidh",
    "The message has been forwarded to {selectedConversationName}" : "Cuireadh an teachtaireacht ar aghaidh chuig {selectedConversationName}",
    "Dismiss" : "Díbhe",
    "Go to conversation" : "Téigh chuig comhrá",
    "Detect language" : "Braith teanga",
    "The message could not be translated" : "Níorbh fhéidir an teachtaireacht a aistriú",
    "Translation copied to clipboard" : "Cóipeáladh an t-aistriúchán chuig an ngearrthaisce",
    "Translation could not be copied" : "Níorbh fhéidir an t-aistriúchán a chóipeáil",
    "Translate message" : "Aistrigh teachtaireacht",
    "Source language to translate from" : "Teanga foinse le haistriú uaidh",
    "Translate from" : "Aistrigh ó",
    "Target language to translate into" : "Sprioctheanga le haistriú go",
    "Translate to" : "Aistrigh go",
    "Translating" : "Ag aistriú",
    "This translation is AI generated and may contain mistakes." : "Is aistriúchán ginte ag hintleacht shaorga é seo agus d’fhéadfadh botúin a bheith ann.",
    "Copy translated text" : "Cóipeáil téacs aistrithe",
    "Error when scheduling the message" : "Earráid agus an teachtaireacht á sceidealú",
    "Reschedule" : "Athsceidealú",
    "Send now" : "Seol anois",
    "Choose a time" : "Roghnaigh am",
    "Send at custom time" : "Seol ag am saincheaptha",
    "Will be sent without notification" : "Seolfar gan fógra",
    "Message read by everyone who shares their reading status" : "Teachtaireacht léite ag gach duine a roinneann a stádas léitheoireachta",
    "Message sent" : "Teachtaireacht seolta",
    "Sent without notification" : "Seolta gan fógra",
    "Deleting message" : "Teachtaireacht á scriosadh",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "D'éirigh leis an teachtaireacht a scriosadh, ach tá bot nó Matterbridge cumraithe agus seans go mbeidh an teachtaireacht scaipthe cheana féin ar sheirbhísí eile",
    "Message deleted successfully" : "D'éirigh leis an teachtaireacht a scriosadh",
    "Message could not be deleted because it is too old" : "Níorbh fhéidir an teachtaireacht a scriosadh toisc go bhfuil sé ró-shean",
    "Only normal chat messages can be deleted" : "Ní féidir ach gnáth-theachtaireachtaí comhrá a scriosadh",
    "An error occurred while deleting the message" : "Tharla earráid agus an teachtaireacht á scriosadh",
    "Pinned" : "Bioránta",
    "Your browser does not support playing audio files" : "Ní thacaíonn do bhrabhsálaí le comhaid fuaime a sheinm",
    "Contact" : "Teagmháil",
    "{stack} in {board}" : "{stack} in {board}",
    "Deck Card" : "Cárta Deic",
    "Remove {fileName}" : "Bain {fileName}",
    "Open this location in OpenStreetMap" : "Oscail an suíomh seo in OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n freagra","%n freagraí","%n freagraí","%n freagraí","%n freagraí"],
    "Sending message" : "Teachtaireacht á seoladh",
    "Failed to send the message. Click to try again" : "Theip ar an teachtaireacht a sheoladh. Cliceáil chun triail eile a bhaint as",
    "Not enough free space to upload file" : "Níl go leor spás saor chun an comhad a uaslódáil",
    "You cannot send messages to this conversation at the moment" : "Ní féidir leat teachtaireachtaí a sheoladh chuig an gcomhrá seo faoi láthair",
    "Could not update the message" : "Níorbh fhéidir an teachtaireacht a nuashonrú",
    "Reply to thread \"{threadTitle}\"" : "Freagra ar an snáithe \"{threadTitle}\"",
    "_You voted • %n vote_::_You voted • %n votes_" : ["Vótáil tú • %n vóta","Vótáil tú • %n vótaí","Vótáil tú • %n vótaí","Vótáil tú • %n vótaí","Vótáil tú • %n vótaí"],
    "You voted" : "Vótáil tú",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["Cliceáil chun vótáil • %n vóta","Cliceáil chun vótáil • %n vótaí","Cliceáil chun vótáil • %n vótaí","Cliceáil chun vótáil • %n vótaí","Cliceáil chun vótáil • %n vótaí"],
    "Click to vote" : "Cliceáil chun vótáil",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Dréacht vótaíochta • %n rogha","Dréacht vótaíochta • %n rogha","Dréacht vótaíochta • %n rogha","Dréacht vótaíochta • %n rogha","Dréacht vótaíochta • %n rogha"],
    "_%n vote_::_%n votes_" : ["%n vóta","%n vótaí","%n vótaí","%n vótaí","%n vótaí"],
    "Edit poll draft" : "Cuir dréacht vótaíochta in eagar",
    "Delete poll draft" : "Scrios an dréacht vótaíochta",
    "Open poll" : "Vótaíocht oscailte",
    "Closed poll" : "Vótaíocht dúnta",
    "See results" : "Féach torthaí",
    "Reactions" : "Imoibrithe",
    "No permission to post reactions in this conversation" : "Níl cead frithghníomhartha a phostáil sa chomhrá seo",
    "and {participant}" : "agus {participant}",
    "_and %n other participant_::_and %n other participants_" : ["agus %n rannpháirtí eile","agus %n rannpháirtithe eile","agus %n rannpháirtithe eile","agus %n rannpháirtithe eile","agus %n rannpháirtithe eile"],
    "Show all reactions" : "Taispeáin gach imoibriú",
    "Add more reactions" : "Cuir tuilleadh imoibrithe leis",
    "Show or collapse system messages" : "Taispeáin nó laghdaigh teachtaireachtaí córais",
    "No messages" : "Gan teachtaireachtaí",
    "All messages have expired or have been deleted." : "Tá gach teachtaireacht imithe in éag nó scriosta.",
    "Generate summary with AI" : "Achoimre a ghiniúint le hintleacht shaorga",
    "{author} (pinned by you)" : "{author} (bioránta agatsa)",
    "{author} (pinned by {actor})" : "{author} (bioránta ag {actor})",
    "Unpin" : "Díbhioráil",
    "Cancel search" : "Cealaigh an cuardach",
    "Add a phone number" : "Cuir uimhir theileafóin leis",
    "Error: A password is required to create the conversation." : "Earráid: Tá pasfhocal ag teastáil chun an comhrá a chruthú.",
    "All set, the conversation \"{conversationName}\" was created." : "Gach socraithe, cruthaíodh an comhrá \"{conversationName}\".",
    "Create a new group conversation" : "Cruthaigh comhrá grúpa nua",
    "Add participants" : "Cuir rannpháirtithe leis",
    "Maximum length exceeded ({maxlength} characters)" : "Sáraíodh an t-uasfhad ({maxlength} carachtar)",
    "Conversation type" : "Cineál comhrá",
    "Default parameters are:" : "Is iad na paraiméadair réamhshocraithe ná:",
    "These settings can be changed once the conversation is created." : "Is féidir na socruithe seo a athrú a luaithe a chruthaítear an comhrá.",
    "Conversation visibility" : "Infheictheacht an chomhrá",
    "Allow guests to join via link" : "Lig do aíonna páirt a ghlacadh tríd an nasc",
    "Enter password" : "Cuir isteach pasfhocal",
    "This conversation has been locked" : "Tá an comhrá seo glasáilte",
    "No permission to post messages in this conversation" : "Níl cead teachtaireachtaí a phostáil sa chomhrá seo",
    "Joining conversation …" : "Ag glacadh páirte sa chomhrá…",
    "Write a message without notification" : "Scríobh teachtaireacht gan fógra",
    "Create a thread silently" : "Cruthaigh snáithe go ciúin",
    "Create a thread" : "Cruthaigh snáithe",
    "Send message silently" : "Seol teachtaireacht go ciúin",
    "Send message" : "Seol teachtaireacht",
    "Send without notification" : "Seol gan fógra",
    "The participant will not be notified about new messages" : "Ní thabharfar fógra don rannpháirtí faoi theachtaireachtaí nua",
    "Participants will not be notified about new messages" : "Ní thabharfar fógra do rannpháirtithe faoi theachtaireachtaí nua",
    "Message will be sent {datetimeString}" : "Seolfar an teachtaireacht chuig {datetimeString}",
    "Thread title is required" : "Tá teideal an tsnáithe riachtanach",
    "Message text is required" : "Tá téacs an teachtaireachta ag teastáil",
    "The message could not be edited" : "Níorbh fhéidir an teachtaireacht a chur in eagar",
    "File to share" : "Comhad le roinnt",
    "File upload is not available in this conversation" : "Níl uaslódáil comhad ar fáil sa chomhrá seo",
    "Message was successfully scheduled" : "Sceidealaíodh an teachtaireacht go rathúil",
    "Add emoji" : "Cuir emoji leis",
    "Adding a mention will only notify users who did not read the message." : "Má chuirtear tagairt leis, ní chuirfear in iúl ach d'úsáideoirí nár léigh an teachtaireacht.",
    "Thread title" : "Teideal an snáithe",
    "Send later" : "Seol níos déanaí",
    "Show scheduled messages" : "Taispeáin teachtaireachtaí sceidealaithe",
    "Cancel editing" : "Cealaigh eagarthóireacht",
    "Schedule message" : "Teachtaireacht sceidealaithe",
    "{user} is out of office and might not respond." : "Tá {user} as an oifig agus seans nach bhfreagróidh sé.",
    "Absence period: {startDate} - {endDate}" : "Tréimhse neamhláithreachta: {startDate} - {endDate}",
    "Replacement:" : "Athsholáthar:",
    "Share from {nextcloud}" : "Roinn ó {nextcloud}",
    "Share from Files" : "Comhroinn ó Chomhaid",
    "Share files to the conversation" : "Roinn comhaid leis an gcomhrá",
    "Upload from device" : "Íosluchtaigh ó gléas",
    "Create new poll" : "Cruthaigh vótaíocht nua",
    "Smart picker" : "Roghnóir cliste",
    "Record voice message" : "Taifead teachtaireacht gutha",
    "End recording and send" : "Cuir deireadh leis an taifeadadh agus seol",
    "Dismiss recording" : "Ruaig an taifeadadh",
    "Access to the microphone was denied" : "Diúltaíodh rochtain ar an micreafón",
    "Microphone either not available or disabled in settings" : "Níl an micreafón ar fáil nó díchumasaithe sna socruithe",
    "Error while recording audio" : "Earráid agus an fhuaim á taifeadadh",
    "Voice message {time} ({conversation})" : "Teachtaireacht ghutha {time} ({conversation})",
    "Generating summary of unread messages …" : "Achoimre ar theachtaireachtaí neamhléite á giniúint…",
    "Summary is AI generated and might contain mistakes" : "Gintear achoimre ar AI agus d’fhéadfadh botúin a bheith ann",
    "Error occurred during a summary generation" : "Tharla earráid le linn glúin achomair",
    "New file" : "Comhad nua",
    "Blank" : "Bán",
    "Error while creating file" : "Earráid agus comhad á chruthú",
    "Create and share a new file" : "Cruthaigh agus roinn comhad nua",
    "Name of the new file" : "Ainm an chomhaid nua",
    "Create file" : "Cruthaigh comhad",
    "Someone is typing …" : "Tá duine éigin ag clóscríobh…",
    "{user1} is typing …" : "Tá {user1} ag clóscríobh…",
    "{user1} and {user2} are typing …" : "Tá {user1} agus {user2} ag clóscríobh…",
    "{user1}, {user2} and {user3} are typing …" : "Tá {user1}, {user2} agus {user3} ag clóscríobh…",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["Tá {user1}, {user2}, {user3} agus %n eile ag clóscríobh…","Tá {user1}, {user2}, {user3} agus %n duine eile ag clóscríobh…","Tá {user1}, {user2}, {user3} agus %n duine eile ag clóscríobh…","Tá {user1}, {user2}, {user3} agus %n duine eile ag clóscríobh…","Tá {user1}, {user2}, {user3} agus %n duine eile ag clóscríobh…"],
    "Add more files" : "Cuir tuilleadh comhad leis",
    "Send" : "Seol",
    "In this conversation <strong>{user}</strong> can:" : "Sa chomhrá seo is féidir le<strong>{user}</strong>:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Cuir ceadanna réamhshocraithe do rannpháirtithe in <strong>{conversationName}</strong>in eagar",
    "Start a call" : "Cuir tús le glaoch",
    "Skip the lobby" : "Léim an stocaireacht",
    "Can post messages" : "Is féidir teachtaireachtaí a phostáil",
    "Can post messages and reactions" : "Is féidir teachtaireachtaí agus freagraí a phostáil",
    "Can add reactions" : "Is féidir imoibrithe a chur leis",
    "Enable the microphone" : "Cumasaigh an micreafón",
    "Enable the camera" : "Cumasaigh an ceamara",
    "Share the screen" : "Roinn an scáileán",
    "Update permissions" : "Nuashonraigh ceadanna",
    "Updating permissions" : "Ceadanna á nuashonrú",
    "No poll drafts" : "Uimh dréachtaí vótaíochta",
    "There is no poll drafts yet saved for this conversation" : "Níl aon dréachtaí vótaíochta sábháilte don chomhrá seo fós",
    "Create poll in {name}" : "Cruthaigh vótaíocht isteach{name}",
    "Create poll" : "Cruthaigh vótaíocht",
    "Error while importing poll" : "Earráid agus vótaíocht á hiompórtáil",
    "Question" : "Ceist",
    "Ask a question" : "Ceist a chur",
    "Import draft from file" : "Iompórtáil dréacht ó chomhad",
    "Answers" : "Freagraí",
    "Answer {option}" : "Freagair {option}",
    "Delete poll option" : "Scrios an rogha vótaíochta",
    "Add answer" : "Cuir freagra leis",
    "Settings" : "Socruithe",
    "Anonymous poll" : "Pobalbhreith gan ainm",
    "Multiple answers" : "Freagraí iolracha",
    "Save as draft" : "Sábháil mar dhréacht",
    "Export draft to file" : "Easpórtáil dréacht go comhad",
    "_Final results • %n vote_::_Final results • %n votes_" : ["Torthaí deiridh • %n vóta","Torthaí deiridh • %n vótaí","Torthaí deiridh • %n vótaí","Torthaí deiridh • %n vótaí","Torthaí deiridh • %n vótaí"],
    "_%n vote • Your vote is anonymous_::_%n votes • Your vote is anonymous_" : ["%n vóta • Tá do vóta gan ainm","%n vótaí • Tá do vóta gan ainm","%n vótaí • Tá do vóta gan ainm","%n vótaí • Tá do vóta gan ainm","%n vótaí • Tá do vóta gan ainm"],
    "Your vote is anonymous" : "Tá do vóta gan ainm",
    "You voted for this option" : "Vótáil tú ar son an rogha seo",
    "End poll" : "Deireadh vótaíocht",
    "Change your vote" : "Athraigh do vóta",
    "Withdraw vote" : "Tarraing siar vóta",
    "Results" : "Torthaí",
    "Download as spreadsheet" : "Íoslódáil mar scarbhileog",
    "Download as CSV" : "Íoslódáil mar CSV",
    "Voted participants" : "Rannpháirtithe vótáilte",
    "Send a message to \"{roomName}\"" : "Seol teachtaireacht chuig \"{roomName}\"",
    "Hide list of participants" : "Folaigh liosta na rannpháirtithe",
    "Show list of participants" : "Taispeáin liosta na rannpháirtithe",
    "Assistance requested in {roomName}" : "Iarradh cúnamh in {roomName}",
    "The message was sent to \"{roomName}\"" : "Seoladh an teachtaireacht chuig \"{roomName}\"",
    "Dismiss request for assistance" : "Déan iarratas ar chúnamh a dhíbhe",
    "Send message to room" : "Seol teachtaireacht chuig an seomra",
    "Back to main room" : "Ar ais go dtí an príomhsheomra",
    "Back to your room" : "Ar ais go dtí do sheomra",
    "Message all rooms" : "Cuir teachtaireacht chuig gach seomra",
    "Start session" : "Tosaigh seisiún",
    "Start a call before you start a breakout room session" : "Cuir tús le glao sula dtosaíonn tú ar sheisiún seomra ar leithligh",
    "Stop session" : "Stop seisiún",
    "The message was sent to all breakout rooms" : "Seoladh an teachtaireacht chuig gach seomra ar leithligh",
    "Send a message to all breakout rooms" : "Seol teachtaireacht chuig gach seomra ar leithligh",
    "Breakout rooms are not started" : "Níl seomraí ar leithligh tosaithe",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Is féidir le glaonna gan Inneall Ardfheidhmíochta a bheith ina gcúis le saincheisteanna nascachta agus ualach ard ar fheistí. {linkstart}Foghlaim tuilleadh{linkend}",
    "Talk setup incomplete" : "Níl an socrú cainte críochnaithe",
    "Disable lobby" : "Díchumasaigh an stocaireacht",
    "Settings for participant \"{user}\"" : "Socruithe don rannpháirtí \"{user}\"",
    "Participant \"{user}\"" : "Rannpháirtí \"{user}\"",
    "moderator" : "modhnóir",
    "bot" : "bota",
    "guest" : "aoi",
    "Ringing …" : "Ag glaoch…",
    "Call rejected" : "Glao diúltaithe",
    "{time} talking …" : "{time} ag caint…",
    "{time} talking time" : "{time} am cainte",
    "Raised their hand" : "Ardaíodh a lámh",
    "Joined with video" : "Glacadh le físeán",
    "Joined via phone" : "Glacadh leis ar an teileafón",
    "Joined with audio" : "Glacadh le fuaime",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Caithfidh an téacs a bheith níos lú ná nó cothrom le {maxLength} carachtair ar fad. Tá {charactersCount} carachtar fada sa téacs reatha.",
    "Remove group and members" : "Bain grúpa agus baill",
    "Remove team and members" : "Bain foireann agus baill",
    "Remove participant" : "Bain rannpháirtí",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "An bhfuil tú cinnte gur mhaith leat an grúpa \"{displayName}\" agus a bhaill a bhaint den chomhrá seo?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "An bhfuil tú cinnte gur mhaith leat foireann \"{displayName}\" agus a baill a bhaint den chomhrá seo?",
    "Do you really want to remove {displayName} from this conversation?" : "An bhfuil tú cinnte gur mhaith leat {displayName} a bhaint den chomhrá seo?",
    "Notification was sent to {displayName}" : "Seoladh fógra chuig {displayName}",
    "Could not send notification to {displayName}" : "Níorbh fhéidir fógra a sheoladh chuig {displayName}",
    "Permissions granted to {displayName}" : "Ceadanna tugtha do {displayName}",
    "Could not modify permissions for {displayName}" : "Níorbh fhéidir ceadanna {displayName} a mhionathrú",
    "Permissions removed for {displayName}" : "Baineadh ceadanna le haghaidh {displayName}",
    "Permissions set to default for {displayName}" : "Ceadanna socraithe mar réamhshocrú le haghaidh {displayName}",
    "Phone number could not be hung up" : "Níorbh fhéidir uimhir theileafóin a chrochadh",
    "Phone number could not be put on hold" : "Níorbh fhéidir uimhir theileafóin a chur ar fionraí",
    "Phone number could not be muted" : "Níorbh fhéidir an uimhir theileafóin a bhalbhú",
    "Phone number could not be unmuted" : "Níorbh fhéidir an uimhir theileafóin a dhíbhalbhú",
    "DTMF message could not be sent" : "Níorbh fhéidir an teachtaireacht DTMF a sheoladh",
    "Phone number copied to clipboard" : "Cóipeáladh an uimhir theileafóin chuig an ngearrthaisce",
    "Phone number could not be copied" : "Níorbh fhéidir uimhir theileafóin a chóipeáil",
    "in the lobby" : "sa stocaireacht",
    "Dial out phone" : "Diailigh fón",
    "Hang up phone" : "Croch suas fón",
    "Move back to lobby" : "Téigh ar ais chuig an stocaireacht",
    "Move to conversation" : "Bog go comhrá",
    "Dial-in PIN" : "UAP dhiailiú-i",
    "Demote from moderator" : "Léim as an modhnóir",
    "Promote to moderator" : "Cur chun cinn chuig modhnóir",
    "Resend invitation" : "Seol cuireadh arís",
    "Send call notification" : "Seol fógra glao",
    "Dial out phone number" : "Diailigh uimhir theileafóin",
    "Resume call for phone number" : "Lean glaoch ar uimhir theileafóin arís",
    "Put phone number on hold" : "Cuir uimhir theileafóin ar feitheamh",
    "Unmute phone number" : "Díbhalbhaigh uimhir theileafóin",
    "Mute phone number" : "Balbhaigh uimhir theileafóin",
    "Copy phone number" : "Cóipeáil uimhir theileafóin",
    "Reset custom permissions" : "Athshocraigh ceadanna saincheaptha",
    "Grant all permissions" : "Deonaigh gach cead",
    "Remove all permissions" : "Bain gach cead",
    "Also ban from this conversation" : "Cosc ón gcomhrá seo freisin",
    "Internal note (reason to ban)" : "Nóta inmheánach (cúis le cosc)",
    "Remove" : "Bain",
    "Permissions modified for {displayName}" : "Athraíodh na ceadanna le haghaidh {displayName}",
    "Add users, groups or teams" : "Cuir úsáideoirí, grúpaí nó foirne leis",
    "Add users or groups" : "Cuir úsáideoirí nó grúpaí leis",
    "Add users or teams" : "Cuir úsáideoirí nó foirne leis",
    "Add users" : "Cuir úsáideoirí leis",
    "Add groups or teams" : "Cuir grúpaí nó foirne leis",
    "Add groups" : "Cuir grúpaí leis",
    "Add teams" : "Cuir foirne leis",
    "Add other sources" : "Cuir foinsí eile leis",
    "Add emails" : "Cuir ríomhphoist leis",
    "Integrations" : "Comhtháthaithe",
    "Add federated users" : "Cuir úsáideoirí cónasctha leis",
    "Searching …" : "Ag cuardach…",
    "Search for more users" : "Cuardaigh le haghaidh níos mó úsáideoirí",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Is féidir leat rannpháirtithe a chuardach nó a chur leis trí ainm, ríomhphost nó ID Néal Cónaidhme",
    "Search or add participants" : "Cuardaigh nó cuir rannpháirtithe leis",
    "Invitation was sent to {actorId}" : "Seoladh cuireadh chuig {actorId}",
    "An error occurred while adding the participants" : "Tharla earráid agus na rannpháirtithe á gcur leis",
    "A new group conversation with selected participant will be created" : "Cruthófar comhrá grúpa nua le rannpháirtí roghnaithe",
    "Participants" : "Rannpháirtithe",
    "Pinned by a deleted user" : "Bioránta ag úsáideoir scriosta",
    "Participants ({count})" : "Rannpháirtithe ({count})",
    "Open chat" : "Oscail comhrá",
    "You have new unread messages in the chat." : "Tá teachtaireachtaí nua neamhléite agat sa chomhrá.",
    "You have been mentioned in the chat." : "Tá tú luaite sa chomhrá.",
    "Search messages" : "Cuardaigh teachtaireachtaí",
    "Chat" : "Comhrá",
    "Details" : "Sonraí",
    "Shared items" : "Míreanna roinnte",
    "Search in {name}" : "Cuardaigh isteach {name}",
    "Threads in {name}" : "Snáitheanna i {name}",
    "{actor} in {conversation}" : "{actor} i {conversation}",
    "Search messages …" : "Cuardaigh teachtaireachtaí…",
    "Search options" : "Roghanna cuardaigh",
    "From User" : "Ó Úsáideoir",
    "Since" : "Ós rud é",
    "Until" : "Go dtí",
    "No results found" : "Níor aimsíodh aon torthaí",
    "Load more results" : "Íoslódáil níos mó torthaí",
    "Recent threads" : "Snáitheanna le déanaí",
    "Projects" : "Tionscadail",
    "No shared items" : "Níl aon mhír roinnte",
    "Thread notifications" : "Fógraí snáithe",
    "Thread actions" : "Gníomhartha snáithe",
    "{actor}: {lastMessage}" : "{aisteoir}: {lastMessage}",
    "Link to a conversation" : "Nasc le comhrá",
    "No open conversations found" : "Níor aimsíodh aon chomhrá oscailte",
    "Either there are no open conversations or you joined all of them." : "Níl aon chomhráite oscailte ann nó chuir tú isteach orthu go léir.",
    "Check spelling or use complete words." : "Seiceáil an litriú nó bain úsáid as focail iomlána.",
    "Search conversations or users" : "Cuardaigh comhráite nó úsáideoirí",
    "Select conversation" : "Roghnaigh comhrá",
    "Number length is not valid" : "Níl fad uimhreach bailí",
    "Region code is not valid" : "Níl an cód réigiúin bailí",
    "Number length is too short" : "Tá fad uimhreach ró-ghearr",
    "Number length is too long" : "Tá fad uimhreach ró-fhada",
    "Number is not valid" : "Níl an uimhir bailí",
    "Phone numbers" : "Uimhreacha gutháin",
    "Display name: {name}" : "Ainm taispeána: {name}",
    "Edit display name" : "Cuir ainm taispeána in eagar",
    "Display name (required)" : "Ainm taispeána (riachtanach)",
    "Save name" : "Sábháil ainm",
    "I picked message bubbles" : "Roghnaigh mé boilgeoga teachtaireachta",
    "I picked the list style" : "Roghnaigh mé an stíl liosta",
    "Error while setting personal setting" : "Earráid agus socrú pearsanta á shocrú",
    "Error while saving sounds setting" : "Earráid agus socrú fuaimeanna á sábháil",
    "Compact conversations list" : "Liosta comhráite dlúth",
    "Chat appearance" : "Cuma comhrá",
    "Messages list" : "Liosta teachtaireachtaí",
    "Message bubbles" : "Bolgáin teachtaireachta",
    "Play sounds when participants join or leave a call" : "Seinn fuaimeanna nuair a thagann rannpháirtithe isteach nó nuair a fhágann siad glao",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "Níl sé ar fáil faoi láthair ar iPhone agus iPad mar gheall ar shrianta teicniúla ón monaróir",
    "Notification settings" : "Socruithe fógra",
    "Sounds for chat and call notifications" : "Fuaimeanna le haghaidh fógraí comhrá agus glaonna",
    "Invalid language ({languageId})" : "Teanga neamhbhailí ({languageId})",
    "Default language" : "Teanga réamhshocraithe",
    "Default language ({languageName})" : "Teanga réamhshocraithe ({languageName})",
    "Error when trying to load the available live translation languages" : "Earráid agus iarracht á déanamh na teangacha aistriúcháin bheo atá ar fáil a luchtú",
    "Error when trying to set live translation language" : "Earráid agus iarracht á déanamh teanga aistriúcháin bheo a shocrú",
    "Set language used to show the transcriptions" : "Socraigh an teanga a úsáidtear chun na trascríbhinní a thaispeáint",
    "Select location for attachments" : "Roghnaigh suíomh le haghaidh ceangaltán",
    "Error while setting attachment folder" : "Earráid agus fillteán ceangaltáin á shocrú",
    "Error while setting read status privacy" : "Earráid agus príobháideacht stádais léite á shocrú",
    "Error while setting typing status privacy" : "Earráid agus príobháideacht stádais á chlóscríobh",
    "Error while setting default media state" : "Earráid agus an stát meán réamhshocraithe á shocrú",
    "Turn camera and microphone off by default" : "Múch an ceamara agus an micreafón de réir réamhshocraithe",
    "Blur camera background by default" : "Doiléirigh cúlra an cheamara de réir réamhshocraithe",
    "Skip device preview before joining a call" : "Seachain réamhamharc gléis sula dtéann tú isteach i nglao",
    "Camera will be turned off when joining. Always shown if recording consent is required." : "Múchfar an ceamara nuair a bheidh tú ag glacadh páirte. Taispeántar i gcónaí é má tá toiliú taifeadta ag teastáil.",
    "Appearance & Sounds" : "Dealramh & Fuaimeanna",
    "Privacy" : "Príobháideacht",
    "Send read receipts" : "Seol admhálacha léite",
    "When off, all read statuses will be hidden" : "Nuair a bhíonn sé múchta, beidh gach stádas léite i bhfolach",
    "Share typing status" : "Comhroinn stádas clóscríofa",
    "When off, all typing indicators will be hidden" : "Nuair a bhíonn sé múchta, beidh na táscairí clóscríofa go léir i bhfolach",
    "Attachments folder" : "Fillteán ceangaltáin",
    "Toggle full screen" : "Scoránaigh scáileán iomlán",
    "Return to Home screen" : "Fill ar ais go dtí an scáileán baile",
    "Search" : "Cuardach",
    "Shortcuts while in a chat" : "Aicearraí agus tú i gcomhrá",
    "Focus the chat input" : "Dírigh an t-ionchur comhrá",
    "Unfocus the chat input to use shortcuts" : "Dífhócas an t-ionchur comhrá chun aicearraí a úsáid",
    "Edit your last message" : "Cuir do theachtaireacht dheireanach in eagar",
    "Shortcuts while in a call" : "Aicearraí agus tú ar ghlao",
    "Camera on and off" : "Ceamara ar siúl agus as",
    "Microphone on and off" : "Micreafón ar siúl agus as",
    "Raise or lower hand" : "Ardaigh nó lámh níos ísle",
    "Push to talk or push to mute" : "Brúigh chun cainte nó brú chun balbhaigh",
    "Zoom-in / zoom-out a screen share" : "Súmáil isteach / zúmáil amach sciar scáileáin",
    "Mouse wheel" : "Roth luiche",
    "Start call silently" : "Tosaigh glaoch go ciúin",
    "Start call" : "Tosaigh glao",
    "End call" : "Cuir deireadh leis an nglao",
    "The server was updated, you cannot start or join a call." : "Nuashonraíodh an freastalaí, ní féidir leat glao a thosú ná páirt a ghlacadh ann.",
    "This call has just ended" : "Tá deireadh leis an nglao seo",
    "You will be able to join the call only after a moderator starts it." : "Ní bheidh tú in ann páirt a ghlacadh sa ghlao ach amháin tar éis do mhodhnóir é a thosú.",
    "End call for everyone" : "Cuir deireadh leis an nglao do chách",
    "Starting the recording" : "An taifeadadh a thosú",
    "Recording" : "Taifeadadh",
    "The call has been running for one hour." : "Tá an glao ar siúl ar feadh uair an chloig.",
    "Cancel recording start" : "Cealaigh tús an taifeadta",
    "Stop recording" : "Stop taifeadadh",
    "Raise hand" : "Ardaigh lámh",
    "Raise hand (R)" : "Ardaigh lámh (R)",
    "Lower hand" : "Lámh íochtair",
    "Lower hand (R)" : "Lámh íochtair (R)",
    "Send a reaction" : "Seol imoibriú",
    "React with {reaction}" : "Freagair le {rection}",
    "All tasks done!" : "Gach tasc déanta!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} de %n tasc","{done}de %n tascanna","{done}de %n tascanna","{done}de %n tascanna","{done}de %n tascanna"],
    "Add participants to this call" : "Cuir rannpháirtithe leis an nglao seo",
    "_%n participant in call_::_%n participants in call_" : ["%n rannpháirtí sa ghlao","%n rannpháirtithe sa ghlao","%n rannpháirtithe sa ghlao","%n rannpháirtithe sa ghlao","%n rannpháirtithe sa ghlao"],
    "Scheduled messages" : "Teachtaireachtaí sceidealaithe",
    "You are not allowed to enable screensharing" : "Níl cead agat comhroinnt scáileáin a chumasú",
    "No screensharing" : "Gan comhroinnt scáileáin",
    "Screensharing options" : "Roghanna comhroinnte scáileáin",
    "Enable screensharing" : "Cumasaigh comhroinnt scáileáin",
    "Bad sent video and screen quality." : "Físeán seolta agus droch-chaighdeán scáileáin.",
    "Bad sent screen quality." : "Droch-chaighdeán scáileáin seolta.",
    "Bad sent video quality." : "Droch-chaighdeán físeán seolta.",
    "Bad sent audio, video and screen quality." : "Droch-chaighdeán fuaime, físeáin agus scáileáin seolta.",
    "Bad sent audio and screen quality." : "Droch-chaighdeán fuaime seolta agus scáileáin.",
    "Bad sent audio and video quality." : "Droch-chaighdeán fuaime agus físe seolta.",
    "Bad sent audio quality." : "Droch-chaighdeán fuaime seolta.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Tá do nasc idirlín nó ríomhaire gnóthach agus seans nach mbeidh rannpháirtithe eile in ann do scáileán a fheiceáil. Chun an scéal a fheabhsú déan iarracht doiléir an chúlra nó d'fhíseán a dhíchumasú agus comhroinnt scáileáin á dhéanamh agat.",
    "Disable background blur" : "Díchumasaigh geamhú an chúlra",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Tá do nasc idirlín nó ríomhaire gnóthach agus seans nach mbeidh rannpháirtithe eile in ann do scáileán a fheiceáil. Chun an scéal a fheabhsú déan iarracht d'fhíseán a dhíchumasú agus comhroinnt scáileáin á dhéanamh agat.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Tá do nasc idirlín nó ríomhaire gnóthach agus seans nach mbeidh rannpháirtithe eile in ann do scáileán a fheiceáil.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Tá do nasc idirlín nó ríomhaire gnóthach agus seans nach mbeidh rannpháirtithe eile in ann tú a fheiceáil.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Tá do nasc idirlín nó do ríomhaire gnóthach agus seans nach mbeidh rannpháirtithe eile in ann tú a thuiscint agus a fheiceáil. Chun an scéal a fheabhsú déan iarracht doiléir an chúlra nó d'fhíseán a dhíchumasú agus comhroinnt scáileáin á dhéanamh agat.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Tá do nasc idirlín nó do ríomhaire gnóthach agus seans nach mbeidh rannpháirtithe eile in ann tú a thuiscint agus a fheiceáil. Chun an scéal a fheabhsú déan iarracht d'fhíseán a dhíchumasú agus comhroinnt scáileáin á dhéanamh agat.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Tá do nasc idirlín nó do ríomhaire gnóthach agus seans nach mbeidh rannpháirtithe eile in ann tú a thuiscint agus do scáileán a fheiceáil. Chun an scéal a fheabhsú déan iarracht do chomhroinnt scáileáin a dhíchumasú.",
    "Disable screenshare" : "Díchumasaigh comhroinnt scáileáin",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Tá do nasc idirlín nó do ríomhaire gnóthach agus seans nach mbeidh rannpháirtithe eile in ann tú a thuiscint agus a fheiceáil. Chun an scéal a fheabhsú déan iarracht doiléir an chúlra nó d'fhíseán a dhíchumasú.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Tá do nasc idirlín nó do ríomhaire gnóthach agus seans nach mbeidh rannpháirtithe eile in ann tú a thuiscint agus a fheiceáil. Chun an scéal a fheabhsú déan iarracht do fhíseán a dhíchumasú.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Tá do nasc idirlín nó do ríomhaire gnóthach agus seans nach mbeidh rannpháirtithe eile in ann tú a thuiscint.",
    "Screen sharing is not supported by your browser." : "Ní thacaíonn do bhrabhsálaí le comhroinnt scáileáin.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Éilíonn comhroinnt scáileáin an leathanach a luchtú trí HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Éilíonn comhroinnt scáileáin an leathanach a luchtú trí HTTPS.",
    "An error occurred while starting screensharing." : "Tharla earráid agus comhroinnt scáileáin á thosú.",
    "Select virtual background" : "Roghnaigh cúlra fíorúil",
    "Show your screen" : "Taispeáin do scáileán",
    "Stop screensharing" : "Cuir stop le comhroinnt scáileáin",
    "Mute others" : "Balbhaigh daoine eile",
    "Start recording" : "Tosaigh taifeadadh",
    "Set up breakout rooms" : "Socraigh seomraí ar leithligh",
    "Download attendance list" : "Íoslódáil liosta freastalaithe",
    "Open Calendar" : "Oscail Féilire",
    "Remove participant {name}" : "Bain rannpháirtí {name}",
    "Would you like to delete this conversation?" : "Ar mhaith leat an comhrá seo a scriosadh?",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["Scriosfar an comhrá seo go huathoibríoch do gach duine tar éis %n lá neamhghníomhaíochta.","Scriosfar an comhrá seo go huathoibríoch do gach duine tar éis %n lá neamhghníomhaíochta.","Scriosfar an comhrá seo go huathoibríoch do gach duine tar éis %n lá neamhghníomhaíochta.","Scriosfar an comhrá seo go huathoibríoch do gach duine tar éis %n lá neamhghníomhaíochta.","Scriosfar an comhrá seo go huathoibríoch do gach duine tar éis %n lá neamhghníomhaíochta."],
    "Are you sure you want to delete this conversation?" : "An bhfuil tú cinnte gur mian leat an comhrá seo a scriosadh?",
    "Delete now" : "Scrios anois",
    "Keep" : "Coinnigh",
    "Open dialpad" : "Oscail dialpad",
    "Select a region" : "Roghnaigh réigiún",
    "Local time: {time}" : "Am áitiúil: {time}",
    "Scheduled {datetime}" : "Sceidealaithe {datetime}",
    "Scheduled for {datetime}" : "Sceidealaithe do {datetime}",
    "Search …" : "Cuardaigh…",
    "Message without mention" : "Teachtaireacht gan trácht",
    "Mention myself" : "Luaigh mé féin",
    "Mention everyone" : "Luaigh gach duine",
    "Select a conversation" : "Roghnaigh comhrá",
    "Select a mode" : "Roghnaigh mód",
    "You do not have permissions to access this conversation." : "Níl cead agat an comhrá seo a rochtain.",
    "Join a different conversation or start a new one." : "Glac páirt i gcomhrá eile nó cuir tús le ceann nua.",
    "The conversation does not exist" : "Níl an comhrá ann",
    "Join a conversation or start a new one!" : "Glac páirt i gcomhrá nó cuir tús le ceann nua!",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "Osclaíodh an comhrá seo i gcluaisín eile. Ní thacaíonn an leagan reatha den fhreastalaí le comhrá a oscailt i roinnt cluaisíní.",
    "Creating and joining a conversation with \"{userid}\"" : "Ag cruthú agus ag glacadh páirte i gcomhrá le \"{userid}\"",
    "Join a conversation or start a new one" : "Glac páirt i gcomhrá nó cuir tús le ceann nua",
    "Error while joining the conversation" : "Earráid agus tú páirteach sa chomhrá",
    "Another user" : "Úsáideoir eile",
    "Hey! Are you using the list style or message bubbles?" : "Haigh! An bhfuil tú ag úsáid an stíl liosta nó boilgeoga teachtaireachta?",
    "Nextcloud URL" : "URL Nextcloud",
    "Nextcloud user" : "Úsáideoir Nextcloud",
    "User password" : "Pasfhocal úsáideora",
    "Talk conversation" : "Labhair comhrá",
    "Skip TLS verification" : "Léim thar fhíorú TLS",
    "Matrix server URL" : "URL freastalaí maitrís",
    "User" : "Úsáideoir",
    "Matrix channel" : "Cainéal maitrís",
    "Mattermost server URL" : "URL an fhreastalaí is tábhachtaí",
    "Mattermost user" : "Úsáideoir is tábhachtaí",
    "Team name" : "Ainm foirne",
    "Channel name" : "Ainm an chainéil",
    "Rocket.Chat server URL" : "URL freastalaí Rocket.Chat",
    "User name or email address" : "Ainm úsáideora nó seoladh ríomhphoist",
    "Rocket.Chat channel" : "Rocket.Chat cainéal",
    "Zulip server URL" : "URL freastalaí Zulip",
    "Bot user name" : "Ainm úsáideora bot",
    "Bot API key" : "Eochair bot API",
    "Zulip channel" : "Cainéal Zulip",
    "API token" : "Comhartha API",
    "Slack channel" : "Cainéal caol",
    "Server ID or name" : "Aitheantas nó ainm an fhreastalaí",
    "Channel ID (prefixed with \"ID:\") or name" : "Aitheantas an chainéil (le \"ID:\") nó ainm",
    "Channel" : "Cainéal",
    "Login" : "Logáil isteach",
    "Chat ID" : "ID comhrá",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL an fhreastalaí IRC (m.sh. chat.freenode.net: 6667)",
    "Nickname" : "Leasainm",
    "Connection password" : "Pasfhocal ceangail",
    "IRC channel" : "Cainéal IRC",
    "Channel password" : "Pasfhocal cainéal",
    "NickServ nickname" : "leasainm Freastalaí",
    "NickServ password" : "Pasfhocal NickServ",
    "Use TLS" : "Úsáid TLS",
    "Use SASL" : "Úsáid SASL",
    "Tenant ID" : "ID an Tionónta",
    "Client ID" : "Aitheantas Cliant",
    "Team ID" : "Aitheantas foirne",
    "Thread ID" : "Aitheantas Snáithe",
    "XMPP/Jabber server URL" : "URL freastalaí XMPP/Jabber",
    "MUC server URL" : "URL freastalaí MUC",
    "Jabber ID" : "ID Jabber",
    "Pinned messages" : "Teachtaireachtaí bioránta",
    "Media" : "Meáin",
    "Polls" : "Pobalbhreith",
    "Deck cards" : "Cártaí deic",
    "Voice messages" : "Teachtaireachtaí gutha",
    "Locations" : "Suímh",
    "Call recordings" : "Taifeadtaí glaonna",
    "Audio" : "Fuaime",
    "Show all pinned messages" : "Taispeáin na teachtaireachtaí uile atá bioránta",
    "Show all media" : "Taispeáin na meáin go léir",
    "Show all files" : "Taispeáin gach comhad",
    "Show all polls" : "Taispeáin gach pobalbhreith",
    "Show all deck cards" : "Taispeáin gach cárta deic",
    "Show all voice messages" : "Taispeáin gach teachtaireacht gutha",
    "Show all locations" : "Taispeáin gach suíomh",
    "Show all call recordings" : "Taispeáin gach taifeadadh glaonna",
    "Show all audio" : "Taispeáin gach fuaime",
    "Show all other" : "Taispeáin gach ceann eile",
    "Follow conversation settings" : "Lean socruithe comhrá",
    "Group" : "Grúpa",
    "Team" : "Foireann",
    "You reconnected to the call" : "D'athcheangail tú leis an nglao",
    "{actor} reconnected to the call" : "D'athcheangail {actor} leis an nglao",
    "You added {user0} and {user1}" : "Chuir tú {user0} agus {user1} leis",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Chuir tú {user0}, {user1} agus %n rannpháirtí eile leis","Chuir tú {user0}, {user1} agus %n rannpháirtithe eile leis","Chuir tú {user0}, {user1} agus %n rannpháirtithe eile leis","Chuir tú {user0}, {user1} agus %n rannpháirtithe eile leis","Chuir tú {user0}, {user1} agus %n rannpháirtithe eile leis"],
    "An administrator added you and {user0}" : "Chuir riarthóir thú agus {user0} leis",
    "{actor} added you and {user0}" : "Chuir {actor} tú agus {user0} leis",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Chuir riarthóir thú, {user0} agus %n rannpháirtí eile leis","Chuir riarthóir tú féin, {user0} agus %n rannpháirtithe eile leis","Chuir riarthóir tú féin, {user0} agus %n rannpháirtithe eile leis","Chuir riarthóir tú féin, {user0} agus %n rannpháirtithe eile leis","Chuir riarthóir tú féin, {user0} agus %n rannpháirtithe eile leis"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["Chuir {actor} tú, {user0} agus %n rannpháirtí eile leis","Chuir {actor} tú, {user0} agus %n rannpháirtí sa bhreis","Chuir {actor} tú, {user0} agus %n rannpháirtí sa bhreis","Chuir {actor} tú, {user0} agus %n rannpháirtí sa bhreis","Chuir {actor} tú, {user0} agus %n rannpháirtí sa bhreis"],
    "An administrator added {user0} and {user1}" : "Chuir riarthóir {user0} agus {user1} leis",
    "{actor} added {user0} and {user1}" : "Chuir {actor} {user0} agus {user1} leis",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Chuir riarthóir {user0}, {user1} agus %n rannpháirtí eile leis","Chuir riarthóir {user0}, {user1} agus %n rannpháirtí sa bhreis leis","Chuir riarthóir {user0}, {user1} agus %n rannpháirtí sa bhreis leis","Chuir riarthóir {user0}, {user1} agus %n rannpháirtí sa bhreis leis","Chuir riarthóir {user0}, {user1} agus %n rannpháirtí sa bhreis leis"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["Chuir {actor} {user0}, {user1} agus %n rannpháirtí eile leis","Chuir {actor} {user0}, {user1} agus %n rannpháirtí eile leis","Chuir {actor} {user0}, {user1} agus %n rannpháirtí eile leis","Chuir {actor} {user0}, {user1} agus %n rannpháirtí eile leis","Chuir {actor} {user0}, {user1} agus %n rannpháirtí eile leis"],
    "You removed {user0} and {user1}" : "Bhain tú {user0} agus {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Bhain tú {user0}, {user1} agus %n rannpháirtí eile","Bhain tú {user0}, {user1} agus %n rannpháirtí eile","Bhain tú {user0}, {user1} agus %n rannpháirtí eile","Bhain tú {user0}, {user1} agus %n rannpháirtí eile","Bhain tú {user0}, {user1} agus %n rannpháirtí eile"],
    "An administrator removed you and {user0}" : "Bhain riarthóir thú agus {user0}",
    "{actor} removed you and {user0}" : "Bhain {actor} thú agus {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Bhain riarthóir thú, {user0} agus %n rannpháirtí eile","Bhain riarthóir thú, {user0} agus %n rannpháirtí eile","Bhain riarthóir thú, {user0} agus %n rannpháirtí eile","Bhain riarthóir thú, {user0} agus %n rannpháirtí eile","Bhain riarthóir thú, {user0} agus %n rannpháirtí eile"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["Bhain {actor} thú, {user0} agus %n rannpháirtí eile","Bhain {actor} thú, {user0} agus %n rannpháirtí eile","Bhain {actor} thú, {user0} agus %n rannpháirtí eile","Bhain {actor} thú, {user0} agus %n rannpháirtí eile","Bhain {actor} thú, {user0} agus %n rannpháirtí eile"],
    "An administrator removed {user0} and {user1}" : "Bhain riarthóir {user0} agus {user1}",
    "{actor} removed {user0} and {user1}" : "Bhain {actor} {user0} agus {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Bhain riarthóir {user0}, {user1} agus %n rannpháirtí eile","Bhain riarthóir {user0}, {user1} agus %n rannpháirtí sa bhreis","Bhain riarthóir {user0}, {user1} agus %n rannpháirtí sa bhreis","Bhain riarthóir {user0}, {user1} agus %n rannpháirtí sa bhreis","Bhain riarthóir {user0}, {user1} agus %n rannpháirtí sa bhreis"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["Bhain {actor} {user0}, {user1} agus %n rannpháirtí eile","Bhain {actor} {user0}, {user1} agus %n rannpháirtí sa bhreis","Bhain {actor} {user0}, {user1} agus %n rannpháirtí sa bhreis","Bhain {actor} {user0}, {user1} agus %n rannpháirtí sa bhreis","Bhain {actor} {user0}, {user1} agus %n rannpháirtí sa bhreis"],
    "You and {user0} joined the call" : "Ghlac tú féin agus {user0} páirt sa ghlao",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Tháinig tusa, {user0} agus %n rannpháirtí sa bhreis isteach sa ghlao","Tháinig tusa, {user0} agus %n rannpháirtí sa bhreis isteach sa ghlao","Tháinig tusa, {user0} agus %n rannpháirtí sa bhreis isteach sa ghlao","Tháinig tusa, {user0} agus %n rannpháirtí sa bhreis isteach sa ghlao","Tháinig tusa, {user0} agus %n rannpháirtí sa bhreis isteach sa ghlao"],
    "{user0} and {user1} joined the call" : "Tháinig {user0} agus {user1} isteach sa ghlao",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["Tháinig {user0}, {user1} agus %n rannpháirtí sa bhreis ar an nglao","Tháinig {user0}, {user1} agus %n rannpháirtí sa bhreis ar an nglao","Tháinig {user0}, {user1} agus %n rannpháirtí sa bhreis ar an nglao","Tháinig {user0}, {user1} agus %n rannpháirtí sa bhreis ar an nglao","Tháinig {user0}, {user1} agus %n rannpháirtí sa bhreis ar an nglao"],
    "You and {user0} left the call" : "D'fhág tú féin agus {user0} an glao",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["D'fhág tusa, {user0} agus %n rannpháirtí sa bhreis an glao","D'fhág tusa, {user0} agus %n rannpháirtí sa bhreis an glao","D'fhág tusa, {user0} agus %n rannpháirtí sa bhreis an glao","D'fhág tusa, {user0} agus %n rannpháirtí sa bhreis an glao","D'fhág tusa, {user0} agus %n rannpháirtí sa bhreis an glao"],
    "{user0} and {user1} left the call" : "D'fhág {user0} agus {user1} an glao",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["D'fhág {user0}, {user1} agus %n rannpháirtí sa bhreis an glao","D'fhág {user0}, {user1} agus %n rannpháirtí sa bhreis an glao","D'fhág {user0}, {user1} agus %n rannpháirtí sa bhreis an glao","D'fhág {user0}, {user1} agus %n rannpháirtí sa bhreis an glao","D'fhág {user0}, {user1} agus %n rannpháirtí sa bhreis an glao"],
    "You promoted {user0} and {user1} to moderators" : "Chuir tú {user0} agus {user1} chun cinn do mhodhnóirí",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Chuir tú {user0}, {user1} agus %n rannpháirtí eile chun cinn chuig modhnóirí","Chuir tú {user0}, {user1} agus %n rannpháirtí sa bhreis chun cinn do mhodhnóirí","Chuir tú {user0}, {user1} agus %n rannpháirtí sa bhreis chun cinn do mhodhnóirí","Chuir tú {user0}, {user1} agus %n rannpháirtí sa bhreis chun cinn do mhodhnóirí","Chuir tú {user0}, {user1} agus %n rannpháirtí sa bhreis chun cinn do mhodhnóirí"],
    "An administrator promoted you and {user0} to moderators" : "Chuir riarthóir thú agus {user0} chun cinn mar mhodhnóirí",
    "{actor} promoted you and {user0} to moderators" : "Chuir {actor} tú agus {user0} chun cinn mar mhodhnóirí",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Chuir riarthóir thú, {user0} agus %n rannpháirtí eile chun cinn mar mhodhnóirí","Chuir riarthóir thú, {user0} agus %n rannpháirtí eile chun cinn mar mhodhnóirí","Chuir riarthóir thú, {user0} agus %n rannpháirtí eile chun cinn mar mhodhnóirí","Chuir riarthóir thú, {user0} agus %n rannpháirtí eile chun cinn mar mhodhnóirí","Chuir riarthóir thú, {user0} agus %n rannpháirtí eile chun cinn mar mhodhnóirí"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["Chuir {actor} thú chun cinn, {user0} agus %n rannpháirtí eile chuig modhnóirí","Chuir {actor} thú, {user0} agus %n rannpháirtí eile chun cinn mar mhodhnóirí","Chuir {actor} thú, {user0} agus %n rannpháirtí eile chun cinn mar mhodhnóirí","Chuir {actor} thú, {user0} agus %n rannpháirtí eile chun cinn mar mhodhnóirí","Chuir {actor} thú, {user0} agus %n rannpháirtí eile chun cinn mar mhodhnóirí"],
    "An administrator promoted {user0} and {user1} to moderators" : "Chuir riarthóir {user0} agus {user1} chun cinn do mhodhnóirí",
    "{actor} promoted {user0} and {user1} to moderators" : "chuir {actor} {user0} agus {user1} chun cinn do mhodhnóirí",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Chuir riarthóir {user0}, {user1} agus %n rannpháirtí sa bhreis chun cinn chuig modhnóirí","Chuir riarthóir {user0}, {user1} agus %n rannpháirtí sa bhreis chun cinn chuig modhnóirí","Chuir riarthóir {user0}, {user1} agus %n rannpháirtí sa bhreis chun cinn chuig modhnóirí","Chuir riarthóir {user0}, {user1} agus %n rannpháirtí sa bhreis chun cinn chuig modhnóirí","Chuir riarthóir {user0}, {user1} agus %n rannpháirtí sa bhreis chun cinn chuig modhnóirí"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["Chuir {actor} {user0}, {user1} agus %n rannpháirtí sa bhreis chun cinn chuig modhnóirí","Chuir {actor} {user0}, {user1} agus %n rannpháirtí sa bhreis chun cinn chuig modhnóirí","Chuir {actor} {user0}, {user1} agus %n rannpháirtí sa bhreis chun cinn chuig modhnóirí","Chuir {actor} {user0}, {user1} agus %n rannpháirtí sa bhreis chun cinn chuig modhnóirí","Chuir {actor} {user0}, {user1} agus %n rannpháirtí sa bhreis chun cinn chuig modhnóirí"],
    "You demoted {user0} and {user1} from moderators" : "Bhain tú síos {user0} agus {user1} ó mhodhnóirí",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Bhain tú síos {user0}, {user1} agus %n rannpháirtí eile ó mhodhnóirí","Bhain tú {user0}, {user1} agus %n rannpháirtí eile ó mhodhnóirí","Bhain tú {user0}, {user1} agus %n rannpháirtí eile ó mhodhnóirí","Bhain tú {user0}, {user1} agus %n rannpháirtí eile ó mhodhnóirí","Bhain tú {user0}, {user1} agus %n rannpháirtí eile ó mhodhnóirí"],
    "An administrator demoted you and {user0} from moderators" : "Rinne riarthóir tú féin agus {user0} a dhíscriosadh ó mhodhnóirí",
    "{actor} demoted you and {user0} from moderators" : "Bhain {actor} tú féin agus {user0} ó mhodhnóirí",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Dhealraigh riarthóir tú, {user0} agus %n rannpháirtí eile ó mhodhnóirí","Dhealraigh riarthóir tú, {user0} agus %n rannpháirtí eile ó mhodhnóirí","Dhealraigh riarthóir tú, {user0} agus %n rannpháirtí eile ó mhodhnóirí","Dhealraigh riarthóir tú, {user0} agus %n rannpháirtí eile ó mhodhnóirí","Dhealraigh riarthóir tú, {user0} agus %n rannpháirtí eile ó mhodhnóirí"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["Bhain {actor} thú, {user0} agus %n rannpháirtí eile ó mhodhnóirí","Bhain {actor} thú, {user0} agus %n rannpháirtí eile ó mhodhnóirí","Bhain {actor} thú, {user0} agus %n rannpháirtí eile ó mhodhnóirí","Bhain {actor} thú, {user0} agus %n rannpháirtí eile ó mhodhnóirí","Bhain {actor} thú, {user0} agus %n rannpháirtí eile ó mhodhnóirí"],
    "An administrator demoted {user0} and {user1} from moderators" : "Bhain riarthóir {user0} agus {user1} ó mhodhnóirí",
    "{actor} demoted {user0} and {user1} from moderators" : "Bhain {actor} {user0} agus {user1} ó mhodhnóirí",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Bhain riarthóir {user0}, {user1} agus %n rannpháirtí breise ó mhodhnóirí","Bhain riarthóir {user0}, {user1} agus %n rannpháirtí breise ó mhodhnóirí","Bhain riarthóir {user0}, {user1} agus %n rannpháirtí breise ó mhodhnóirí","Bhain riarthóir {user0}, {user1} agus %n rannpháirtí breise ó mhodhnóirí","Bhain riarthóir {user0}, {user1} agus %n rannpháirtí breise ó mhodhnóirí"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["Bhain {actor} {user0}, {user1} agus %n rannpháirtí eile ó mhodhnóirí","Bhain {actor} {user0}, {user1} agus %n rannpháirtí breise ó mhodhnóirí","Bhain {actor} {user0}, {user1} agus %n rannpháirtí breise ó mhodhnóirí","Bhain {actor} {user0}, {user1} agus %n rannpháirtí breise ó mhodhnóirí","Bhain {actor} {user0}, {user1} agus %n rannpháirtí breise ó mhodhnóirí"],
    "You:" : "Tusa:",
    "You: {lastMessage}" : "Tusa: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The server was updated." : "Nuashonraíodh an freastalaí.",
    "(edited by you)" : "(arna chur in eagar ag tú)",
    "(edited by a deleted user)" : "(arna chur in eagar ag úsáideoir scriosta)",
    "(edited by {moderator})" : "(curtha in eagar ag {moderator})",
    "The recording failed. Please contact your administrator." : "Theip ar an taifeadadh. Déan teagmháil le do riarthóir le do thoil.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Tá tú ag iarraidh páirt a ghlacadh i gcomhrá agus seisiún gníomhach agat i bhfuinneog nó gléas eile. Ní thacaíonn Nextcloud Talk leis seo faoi láthair. Cad ba mhaith leat a dhéanamh?",
    "Leave this page" : "Fág an leathanach seo",
    "Join here" : "Glac páirt anseo",
    "Deck card has been posted to {conversation}" : "Postáladh cárta deic chuig {conversation}",
    "An error occurred while posting deck card to conversation" : "Tharla earráid agus cártaí deic á bpostáil chuig comhrá",
    "Post to a conversation" : "Postáil chuig comhrá",
    "Post to conversation" : "Postáil chuig an gcomhrá",
    "Location has been posted to {conversation}" : "Postáladh an suíomh chuig {conversation}",
    "An error occurred while posting location to conversation" : "Tharla earráid agus suíomh á phostáil chuig comhrá",
    "Share to a conversation" : "Comhroinn le comhrá",
    "Share to conversation" : "Roinn chuig an gcomhrá",
    "In conversation" : "I gcomhrá",
    "Search in conversation: {conversation}" : "Cuardaigh i gcomhrá: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Tá d’iarratais sáite faoi láthair mar gheall ar chosaint fórsa brúidiúil",
    "Error while clearing conversation history" : "Earráid agus an stair chomhrá á glanadh",
    "Error occurred while allowing guests" : "Tharla earráid agus aíonna á gceadú",
    "Error occurred while disallowing guests" : "Tharla earráid agus aíonna á ndícheadú",
    "Error occurred when restricting the conversation to moderator" : "Tharla earráid agus an comhrá á srianadh go modhnóir",
    "Error occurred when opening the conversation to everyone" : "Tharla earráid agus an comhrá á oscailt do gach duine",
    "Conversation password has been saved" : "Sábháladh pasfhocal an chomhrá",
    "Conversation password has been removed" : "Baineadh pasfhocal an chomhrá",
    "Error occurred while saving conversation password" : "Tharla earráid agus pasfhocal an chomhrá á shábháil",
    "Call recording is starting." : "Tá taifeadadh glaonna ag tosú.",
    "Call recording stopped while starting." : "Stopadh taifeadadh glaonna agus é ag tosú.",
    "Call recording stopped. You will be notified once the recording is available." : "Stopadh taifeadadh glaonna. Cuirfear ar an eolas tú nuair a bheidh an taifeadadh ar fáil.",
    "Conversation picture set" : "Sraith pictiúr comhrá",
    "Conversation picture deleted" : "Scriosadh pictiúr an chomhrá",
    "Could not delete the conversation picture" : "Níorbh fhéidir pictiúr an chomhrá a scriosadh",
    "Could not remove the automatic expiration" : "Níorbh fhéidir an dul in éag uathoibríoch a bhaint",
    "Could not post message: {errorMessage}" : "Níorbh fhéidir an teachtaireacht a phostáil: {errorMessage}",
    "Participant is banned successfully" : "Tá toirmeasc rathúil ar rannpháirtí",
    "Error while banning the participant" : "Earráid agus an rannpháirtí á thoirmeasc",
    "An error occurred while fetching the participants" : "Tharla earráid agus na rannpháirtithe á nglacadh",
    "Could not send invitation to {actorId}" : "Níorbh fhéidir cuireadh a sheoladh chuig {actorId}",
    "Invitations sent" : "Cuirí seolta",
    "Error occurred when sending invitations" : "Tharla earráid agus cuirí á seoladh",
    "Failed to join the conversation." : "Theip ar páirt a ghlacadh sa chomhrá.",
    "An error occurred while creating breakout rooms" : "Tharla earráid agus seomraí ar leithligh á gcruthú",
    "An error occurred while re-ordering the attendees" : "Tharla earráid agus an lucht freastail á athordú",
    "An error occurred while deleting breakout rooms" : "Tharla earráid agus seomraí ar leithligh á scriosadh",
    "An error occurred while starting breakout rooms" : "Tharla earráid agus seomraí ar leithligh á thosú",
    "An error occurred while stopping breakout rooms" : "Tharla earráid agus seomraí ar leithligh á stopadh",
    "An error occurred while sending a message to the breakout rooms" : "Tharla earráid agus teachtaireacht á seoladh chuig na seomraí ar leithligh",
    "An error occurred while requesting assistance" : "Tharla earráid agus cúnamh á iarraidh",
    "An error occurred while resetting the request for assistance" : "Tharla earráid agus an t-iarratas ar chúnamh á athshocrú",
    "An error occurred while joining breakout room" : "Tharla earráid agus tú ag glacadh páirte sa seomra ar leithligh",
    "Failed to rename the thread" : "Theip ar athainmniú an snáithe",
    "Error renaming tag" : "Earráid ag athainmniú an chlib",
    "Error deleting tag" : "Earráid ag scriosadh an chlib",
    "Error reordering tags" : "Earráid ag athordú na gclibeanna",
    "Error fetching upcoming events" : "Earráid ag fáil imeachtaí atá le teacht",
    "Error fetching upcoming reminders" : "Earráid ag fáil meabhrúcháin atá le teacht",
    "An error occurred while accepting an invitation" : "Tharla earráid agus cuireadh á ghlacadh",
    "An error occurred while rejecting an invitation" : "Tharla earráid agus cuireadh á dhiúltú",
    "{guest} (guest)" : "{guest} (aoi)",
    "Poll draft has been saved" : "Tá an dréacht vótaíochta sábháilte",
    "An error occurred while saving the draft" : "Tharla earráid agus an dréacht á shábháil",
    "An error occurred while submitting your vote" : "Tharla earráid agus do vóta á chur isteach",
    "An error occurred while ending the poll" : "Tharla earráid agus an pobalbhreith á críochnú",
    "An error occurred while deleting the poll draft" : "Tharla earráid agus an dréacht vótaíochta á scriosadh",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Chruthaigh {user} an vótaíocht \"{name}\". Cliceáil chun vótáil",
    "Failed to add reaction" : "Theip ar imoibriú a chur leis",
    "Failed to remove reaction" : "Theip ar an imoibriú a bhaint",
    "The server is in maintenance mode." : "Tá an freastalaí i mód cothabhála.",
    "Federated server was updated." : "Nuashonraíodh an freastalaí cónaidhme.",
    "Error while uploading file \"{fileName}\"" : "Earráid agus comhad \"{fileName}\" á uaslódáil",
    "Not enough free space to upload file \"{fileName}\"" : "Níl go leor spáis in aisce chun an comhad \"{fileName}\" a uaslódáil",
    "You are not allowed to share files" : "Níl cead agat comhaid a roinnt",
    "Error while sharing file" : "Earráid agus an comhad á roinnt",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Níl tacaíocht iomlán ag Nextcloud Talk don bhrabhsálaí atá in úsáid agat. Bain úsáid as an leagan is déanaí de Mozilla Firefox, Microsoft Edge, Google Chrome, Opera nó Apple Safari.",
    "_%n hour_::_%n hours_" : ["%n uair an chloig","%n uair an chloig","%n uair an chloig","%n uair an chloig","%n uair an chloig"],
    "_%n day_::_%n days_" : ["%n lá","%n laethanta","%n laethanta","%n laethanta","%n laethanta"],
    "_%n week_::_%n weeks_" : ["%n seachtain","%n seachtainí","%n seachtainí","%n seachtainí","%n seachtainí"],
    "_In %n hour_::_In %n hours_" : ["I %n uair","In %n hoursI %n uair","I %n uair","I %n uair","I %n uair"],
    "_%n minute _::_%n minutes_" : ["%n nóiméad","%n nóiméad","%n nóiméad","%n nóiméad","%n nóiméad"],
    "In {hours} and {minutes}" : "I {uair an chloig} agus {nóiméid}",
    "_In %n minute_::_In %n minutes_" : ["I %n nóiméad","I %n nóiméad","I %n nóiméad","I %n nóiméad","I %n nóiméad"],
    "Later today – {timeLocale}" : "Níos déanaí inniu - {timeLocale}",
    "Set time for later today" : "Socraigh am don lá atá inniu ann",
    "Tomorrow – {timeLocale}" : "Amárach - {timeLocale}",
    "Set time for tomorrow" : "Socraigh am don lá amárach",
    "This weekend – {timeLocale}" : "An deireadh seachtaine seo - {timeLocale}",
    "Set time for this weekend" : "Socraigh am don deireadh seachtaine seo",
    "Next week – {timeLocale}" : "An tseachtain seo chugainn – {timeLocale}An tseachtain seo chugainn – {timeLocale}",
    "Set time for next week" : "Socraigh am don tseachtain seo chugainn",
    "Message link copied to clipboard" : "Nasc teachtaireachta cóipeáilte chuig an ghearrthaisce",
    "Conversation link copied to clipboard" : "Cóipeáladh an nasc comhrá chuig an ngearrthaisce",
    "The link could not be copied" : "Níorbh fhéidir an nasc a chóipeáil",
    "Error while parsing a PROPFIND error" : "Earráid agus earráid PROPFIND á parsáil",
    "Sending signaling message has failed" : "Theip ar sheoladh na teachtaireachta comharthaíochta",
    "Lost connection to signaling server. Trying to reconnect." : "Ceangal caillte leis an bhfreastalaí comharthaíochta. Ag iarraidh a athcheangal.",
    "Lost connection to signaling server." : "Ceangal caillte leis an bhfreastalaí comharthaíochta.",
    "Connecting is taking longer than expected …" : "Tá an nasc ag glacadh níos faide ná mar a bhíothas ag súil leis …",
    "Failed to connect. Retrying …" : "Theip ar an nascadh. Ag iarraidh arís …",
    "Failed to connect. The signaling server may be set up incorrectly" : "Theip ar an nascadh. Seans go bhfuil an freastalaí comharthaíochta socraithe go mícheart.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Ní mór an freastalaí comharthaíochta cumraithe a nuashonrú le bheith comhoiriúnach leis an leagan seo de Talk. Déan teagmháil le do riarachán, le do thoil.",
    "Please restart the app." : "Atosaigh an aip le do thoil.",
    "Please reload the page." : "Athlódáil an leathanach le do thoil.",
    "Please try to restart the app." : "Déan iarracht an aip a atosú le do thoil.",
    "Please try to reload the page." : "Déan iarracht an leathanach a athlódáil.",
    "Do not disturb" : "Ná cur as",
    "Away" : "Amach",
    "Microphone {number}" : "Micreafón {uimhir}",
    "Camera {number}" : "{uimhir} ceamara",
    "Speaker {number}" : "Cainteoir {uimhir}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Is cosúil go bhfuil tú ag caint agus tú balbh, le do thoil díbhalbhaigh tú féin le go gcloisfidh daoine eile thú",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Níorbh fhéidir nasc a bhunú le rannpháirtí amháin ar a laghad. Seans go mbeidh freastalaí TURN ag teastáil le haghaidh do chás. Iarr ar do riarthóir ceann a shocrú tar éis {linkstart}an doiciméadú seo{linkend} le do thoil.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tá sé seo ag glacadh níos faide ná mar a ceapadh. An bhfuil na ceadanna meán tugtha (nó diúltaithe) cheana féin? Má tá, atosaigh do bhrabhsálaí le do thoil, toisc go bhfuil teipthe ar fhuaim agus ar fhís",
    "Access to microphone & camera is only possible with HTTPS" : "Ní féidir rochtain ar mhicreafón & ceamara ach amháin le HTTPS",
    "Please move your setup to HTTPS" : "Bog do shocrú go HTTPS le do thoil",
    "Access to microphone & camera was denied" : "Diúltaíodh rochtain ar mhicreafón & ceamara",
    "WebRTC is not supported in your browser" : "Ní thacaítear le WebRTC i do bhrabhsálaí",
    "Please use a different browser like Firefox or Chrome" : "Bain úsáid as brabhsálaí eile ar nós Firefox nó Chrome le do thoil",
    "Error while accessing microphone & camera" : "Earráid agus an micreafón agus an ceamara á rochtain",
    "%s Talk on your mobile devices" : "%s Labhair ar do ghléasanna móibíleacha",
    "Join conversations at any time, anywhere, on any device." : "Glac páirt i gcomhráite am ar bith, áit ar bith, ar ghléas ar bith.",
    "Android app" : "Aip Android",
    "iOS app" : "aip iOS",
    "__language_name__" : "__ainm_teanga__",
    "Webhook Demo" : "Taispeántas Webook",
    "Call summary (%s)" : "Achoimre ar an nglao (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Postálann an bot achoimre glaonna teachtaireacht forbhreathnú tar éis an ghlao ina liostaítear na rannpháirtithe go léir agus ag cur síos ar na tascanna",
    "Tasks" : "Tascanna",
    "Notes" : "Nótaí",
    "Reports" : "Tuairiscí",
    "Decisions" : "Cinntí",
    "Agenda" : "Clár oibre",
    "Call summary" : "Achoimre glaonna",
    "Call summary - {title}" : "Achoimre ar an nglao - {teideal}",
    "Talk to %s" : "Labhair le %s",
    "Talk conversation for event" : "Labhair comhrá don imeacht",
    "Client Push is installed, this improves the performance of desktop clients." : "Tá Client Push suiteáilte, feabhsaíonn sé seo feidhmíocht na gcliant deisce.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "Níl {notify_push}suiteáilte, d'fhéadfadh fadhbanna feidhmíochta a bheith mar thoradh air seo agus cliaint deisce in úsáid.",
    "Next meeting" : "An chéad chruinniú eile",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Sceideal cruinniú ó do fhéilire. Ní mór comhrá Talk a shocrú mar shuíomh le go dtaispeánfar é anseo.",
    "Join conversations from remote Nextcloud servers" : "Glac páirt i gcomhráite ó fhreastalaithe cianda Nextcloud",
    "Your default media state has been saved" : "Sábháladh do staid meán réamhshocraithe",
    "Set reminder for later today" : "Socraigh meabhrúchán le haghaidh níos déanaí inniu",
    "Set reminder for tomorrow" : "Socraigh meabhrúchán don lá amárach",
    "Set reminder for this weekend" : "Socraigh meabhrúchán don deireadh seachtaine seo",
    "Set reminder for next week" : "Socraigh meabhrúchán don tseachtain seo chugainn",
    "Generate summary" : "Gin achoimre",
    "Open poll • You voted already" : "Vótaíocht oscailte • Vótáil tú cheana féin",
    "Open poll • Click to vote" : "Oscail vótaíocht • Cliceáil chun vótáil",
    "Poll • Ended" : "• Tháinig deireadh leis an vótaíocht",
    "Talk recording from {time} ({conversation})" : "Taifeadadh cainte ó {time} ({ conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Torthaí na vótaíochta • %n vóta","Torthaí na vótaíochta • %n vótaí","Torthaí na vótaíochta • %n vótaí","Torthaí na vótaíochta • %n vótaí","Torthaí na vótaíochta • %n vótaí"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Vótaíocht oscailte • %n vóta","Vótaíocht oscailte • %n vótaí","Vótaíocht oscailte • %n vótaí","Vótaíocht oscailte • %n vótaí","Vótaíocht oscailte • %n vótaí"],
    "Submit vote" : "Cuir vóta isteach",
    "Your privacy setting has been saved" : "Sábháladh do shocrú príobháideachta",
    "Your personal setting has been saved" : "Sábháladh do shocrú pearsanta",
    "Failed to save sounds setting" : "Theip ar an socrú fuaimeanna a shábháil",
    "Sounds setting saved" : "Socrú fuaimeanna sábháilte",
    "Always shown if recording consent is required" : "Taispeántar i gcónaí má tá toiliú taifeadta ag teastáil",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nuashonraíodh Nextcloud Talk, ní féidir leat glao a thosú nó páirt a ghlacadh ann.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Chuaigh tú isteach sa chomhrá i bhfuinneog nó gléas eile. Ní thacaíonn Nextcloud Talk leis seo faoi láthair mar sin dúnadh an seisiún seo.",
    "Nextcloud Talk was updated." : "Nuashonraíodh Nextcloud Talk.",
    "Nextcloud is in maintenance mode." : "Tá Nextcloud i mód cothabhála.",
    "Nextcloud Talk Federation was updated." : "Nuashonraíodh Cónaidhm Nextcloud Talk.",
    "Enable live translation" : "Cumasaigh aistriúchán beo",
    "_Open poll • %n vote • Your vote is anonymous_::_Open poll • %n votes • Your vote is anonymous_" : ["Vótaíocht oscailte • %n vóta • Tá do vóta gan ainm","Vótaíocht oscailte • %n vótaí • Tá do vóta gan ainm","Vótaíocht oscailte • %n vótaí • Tá do vóta gan ainm","Vótaíocht oscailte • %n vótaí • Tá do vóta gan ainm","Vótaíocht oscailte • %n vótaí • Tá do vóta gan ainm"],
    "Open poll • You voted already • Your vote is anonymous" : "Vótaíocht oscailte • Vótáil tú cheana féin • Tá do vóta gan ainm",
    "Open poll • Your vote is anonymous" : "Vótaíocht oscailte • Tá do vóta gan ainm",
    "I picked list style" : "Roghnaigh mé stíl liosta",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Haigh! An bhfuil tú ag úsáid Talk i stíl liosta nó le boilgeoga teachtaireachta?"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
